@@ -47,8 +47,8 @@ import sqlalchemy as sa
 # Revision identifiers, used by Alembic.
 # =============================================================================
 
-revision = '0021'
-down_revision = '0020'
+revision = "0021"
+down_revision = "0020"
 branch_labels = None
 depends_on = None
 
@@ -59,10 +59,17 @@ depends_on = None
 
 # noinspection PyPep8,PyTypeChecker
 def upgrade():
-    with op.batch_alter_table('_special_notes', schema=None) as batch_op:
-        batch_op.add_column(sa.Column('hidden', sa.Boolean(), nullable=False, comment='Manually hidden (effectively: deleted)'))
+    with op.batch_alter_table("_special_notes", schema=None) as batch_op:
+        batch_op.add_column(
+            sa.Column(
+                "hidden",
+                sa.Boolean(),
+                nullable=False,
+                comment="Manually hidden (effectively: deleted)",
+            )
+        )
 
 
 def downgrade():
-    with op.batch_alter_table('_special_notes', schema=None) as batch_op:
-        batch_op.drop_column('hidden')
+    with op.batch_alter_table("_special_notes", schema=None) as batch_op:
+        batch_op.drop_column("hidden")
