@@ -47,8 +47,8 @@ import sqlalchemy as sa
 # Revision identifiers, used by Alembic.
 # =============================================================================
 
-revision = '0024'
-down_revision = '0023'
+revision = "0024"
+down_revision = "0023"
 branch_labels = None
 depends_on = None
 
@@ -59,11 +59,18 @@ depends_on = None
 
 # noinspection PyPep8,PyTypeChecker
 def upgrade():
-    with op.batch_alter_table('_security_users', schema=None) as batch_op:
-        batch_op.add_column(sa.Column('language', sa.String(length=6), nullable=True, comment='Language code preferred by this user'))
+    with op.batch_alter_table("_security_users", schema=None) as batch_op:
+        batch_op.add_column(
+            sa.Column(
+                "language",
+                sa.String(length=6),
+                nullable=True,
+                comment="Language code preferred by this user",
+            )
+        )
 
 
 # noinspection PyPep8,PyTypeChecker
 def downgrade():
-    with op.batch_alter_table('_security_users', schema=None) as batch_op:
-        batch_op.drop_column('language')
+    with op.batch_alter_table("_security_users", schema=None) as batch_op:
+        batch_op.drop_column("language")
