@@ -37,12 +37,10 @@ import logging
 from typing import TYPE_CHECKING
 import os
 
-# from alembic import command
 from alembic.config import Config
 from cardinal_pythonlib.fileops import preserve_cwd
 from cardinal_pythonlib.logs import BraceStyleAdapter
 from cardinal_pythonlib.sqlalchemy.alembic_func import (
-    # get_current_and_head_revision,
     downgrade_database,
     upgrade_database,
     stamp_allowing_unusual_version_table,
@@ -82,8 +80,9 @@ def upgrade_database_to_head(show_sql_only: bool = False) -> None:
     upgrade_database_to_revision(revision="head", show_sql_only=show_sql_only)
 
 
-def upgrade_database_to_revision(revision: str,
-                                 show_sql_only: bool = False) -> None:
+def upgrade_database_to_revision(
+    revision: str, show_sql_only: bool = False
+) -> None:
     """
     Upgrades the database to a specific revision. Modifies the database
     structure from where it is, stepwise through revisions, to the specified
@@ -94,18 +93,22 @@ def upgrade_database_to_revision(revision: str,
         show_sql_only: just show the SQL; don't execute it
     """
     import_all_models()  # delayed, for command-line interfaces
-    upgrade_database(alembic_base_dir=ALEMBIC_BASE_DIR,
-                     alembic_config_filename=ALEMBIC_CONFIG_FILENAME,
-                     destination_revision=revision,
-                     version_table=ALEMBIC_VERSION_TABLE,
-                     as_sql=show_sql_only)
+    upgrade_database(
+        alembic_base_dir=ALEMBIC_BASE_DIR,
+        alembic_config_filename=ALEMBIC_CONFIG_FILENAME,
+        destination_revision=revision,
+        version_table=ALEMBIC_VERSION_TABLE,
+        as_sql=show_sql_only,
+    )
     # ... will get its config information from the OS environment; see
     # run_alembic() in alembic/env.py
 
 
-def downgrade_database_to_revision(revision: str,
-                                   show_sql_only: bool = False,
-                                   confirm_downgrade_db: bool = False) -> None:
+def downgrade_database_to_revision(
+    revision: str,
+    show_sql_only: bool = False,
+    confirm_downgrade_db: bool = False,
+) -> None:
     """
     Developer option. Takes the database to a specific revision.
 
@@ -119,14 +122,18 @@ def downgrade_database_to_revision(revision: str,
         log.critical("Destructive action not confirmed! Refusing.")
         return
     if show_sql_only:
-        log.warning("Current Alembic v1.0.0 bug in downgrading with "
-                    "as_sql=True; may fail")
+        log.warning(
+            "Current Alembic v1.0.0 bug in downgrading with "
+            "as_sql=True; may fail"
+        )
     import_all_models()  # delayed, for command-line interfaces
-    downgrade_database(alembic_base_dir=ALEMBIC_BASE_DIR,
-                       alembic_config_filename=ALEMBIC_CONFIG_FILENAME,
-                       destination_revision=revision,
-                       version_table=ALEMBIC_VERSION_TABLE,
-                       as_sql=show_sql_only)
+    downgrade_database(
+        alembic_base_dir=ALEMBIC_BASE_DIR,
+        alembic_config_filename=ALEMBIC_CONFIG_FILENAME,
+        destination_revision=revision,
+        version_table=ALEMBIC_VERSION_TABLE,
+        as_sql=show_sql_only,
+    )
     # ... will get its config information from the OS environment; see
     # run_alembic() in alembic/env.py
 
@@ -160,6 +167,7 @@ def create_database_from_scratch(cfg: "CamcopsConfig") -> None:
     alembic_cfg = Config(ALEMBIC_CONFIG_FILENAME)
     os.chdir(ALEMBIC_BASE_DIR)
     # command.stamp(alembic_cfg, "head")
-    stamp_allowing_unusual_version_table(alembic_cfg, "head",
-                                         version_table=ALEMBIC_VERSION_TABLE)
+    stamp_allowing_unusual_version_table(
+        alembic_cfg, "head", version_table=ALEMBIC_VERSION_TABLE
+    )
     log.info("One-step database creation complete.")
