@@ -34,16 +34,20 @@ camcops_server/cc_modules/cc_ctvinfo.py
 # CtvInfo
 # =============================================================================
 
+
 class CtvInfo(object):
     """
     Snippet of information for incorporating into a CTV.
     """
-    def __init__(self,
-                 heading: str = None,
-                 subheading: str = None,
-                 description: str = None,
-                 content: str = None,
-                 skip_if_no_content: bool = True):
+
+    def __init__(
+        self,
+        heading: str = None,
+        subheading: str = None,
+        description: str = None,
+        content: str = None,
+        skip_if_no_content: bool = True,
+    ):
         """
         Args:
             heading: optional text used for heading
