@@ -45,7 +45,7 @@ STR_FORMAT_EXCEPTIONS = (
     # Exceptions that can be raised by str.format()
     IndexError,  # missing positional parameter: "{}, {}".format(1)
     KeyError,  # missing named parameter: "{x}".format(y=2)
-    ValueError  # e.g. unmatched brace: "{x".format(x=1)
+    ValueError,  # e.g. unmatched brace: "{x".format(x=1)
 )
 
 
@@ -53,6 +53,7 @@ STR_FORMAT_EXCEPTIONS = (
 # Exceptions
 # =============================================================================
 
+
 class FhirExportException(Exception):
     pass
 
@@ -61,6 +62,7 @@ class FhirExportException(Exception):
 # Exception functions
 # =============================================================================
 
+
 def raise_runtime_error(msg: str) -> NoReturn:
     """
     Reports an error message to the Python log and raises a
