@@ -65,6 +65,7 @@ class IdNumValidationMethod(object):
     """
     Constants representing ways that CamCOPS knows to validate ID numbers.
     """
+
     NONE = ""  # special
     UK_NHS_NUMBER = "uk_nhs_number"
 
@@ -76,8 +77,9 @@ ID_NUM_VALIDATION_METHOD_CHOICES = (
 )
 
 
-def validate_id_number(req: "CamcopsRequest",
-                       idnum: Optional[int], method: str) -> Tuple[bool, str]:
+def validate_id_number(
+    req: "CamcopsRequest", idnum: Optional[int], method: str
+) -> Tuple[bool, str]:
     """
     Validates an ID number according to a method (as per
     :class:`IdNumValidationMethod`).
@@ -113,52 +115,63 @@ def validate_id_number(req: "CamcopsRequest",
 # IdNumDefinition
 # =============================================================================
 
+
 class IdNumDefinition(Base):
     """
     Represents an ID number definition.
     """
+
     __tablename__ = "_idnum_definitions"
 
     which_idnum = Column(
-        "which_idnum", Integer, primary_key=True, index=True,
-        comment="Which of the server's ID numbers is this?"
+        "which_idnum",
+        Integer,
+        primary_key=True,
+        index=True,
+        comment="Which of the server's ID numbers is this?",
     )
     description = Column(
-        "description", IdDescriptorColType,
-        comment="Full description of the ID number"
+        "description",
+        IdDescriptorColType,
+        comment="Full description of the ID number",
     )
     short_description = Column(
-        "short_description", IdDescriptorColType,
-        comment="Short description of the ID number"
+        "short_description",
+        IdDescriptorColType,
+        comment="Short description of the ID number",
     )
     hl7_id_type = Column(
-        "hl7_id_type", HL7IdTypeType,
+        "hl7_id_type",
+        HL7IdTypeType,
         comment="HL7: Identifier Type code: 'a code corresponding to the type "
-                "of identifier. In some cases, this code may be used as a "
-                "qualifier to the \"Assigning Authority\" component.'"
+        "of identifier. In some cases, this code may be used as a "
+        'qualifier to the "Assigning Authority" component.\'',
     )
     hl7_assigning_authority = Column(
-        "hl7_assigning_authority", HL7AssigningAuthorityType,
+        "hl7_assigning_authority",
+        HL7AssigningAuthorityType,
         comment="HL7: Assigning Authority for ID number (unique name of the "
-                "system/organization/agency/department that creates the data)."
+        "system/organization/agency/department that creates the data).",
     )
     validation_method = Column(
-        "validation_method", String(length=ID_NUM_VALIDATION_METHOD_MAX_LEN),
-        comment="Optional validation method"
+        "validation_method",
+        String(length=ID_NUM_VALIDATION_METHOD_MAX_LEN),
+        comment="Optional validation method",
     )
     fhir_id_system = Column(
-        "fhir_id_system", UrlColType,
-        comment="FHIR external ID 'system' URL"
+        "fhir_id_system", UrlColType, comment="FHIR external ID 'system' URL"
     )
 
-    def __init__(self,
-                 which_idnum: int = None,
-                 description: str = "",
-                 short_description: str = "",
-                 hl7_id_type: str = "",
-                 hl7_assigning_authority: str = "",
-                 validation_method: str = "",
-                 fhir_id_system: str = ""):
+    def __init__(
+        self,
+        which_idnum: int = None,
+        description: str = "",
+        short_description: str = "",
+        hl7_id_type: str = "",
+        hl7_assigning_authority: str = "",
+        validation_method: str = "",
+        fhir_id_system: str = "",
+    ):
         # We permit a "blank" constructor for automatic copying, e.g. merge_db.
         self.which_idnum = which_idnum
         self.description = description
@@ -169,9 +182,11 @@ class IdNumDefinition(Base):
         self.fhir_id_system = fhir_id_system
 
     def __repr__(self) -> str:
-        return simple_repr(self,
-                           ["which_idnum", "description", "short_description"],
-                           with_addr=False)
+        return simple_repr(
+            self,
+            ["which_idnum", "description", "short_description"],
+            with_addr=False,
+        )
 
     def _camcops_default_fhir_id_system(self, req: "CamcopsRequest") -> str:
         """
@@ -179,8 +194,7 @@ class IdNumDefinition(Base):
         specified one for the selected ID number type.
         """
         return req.route_url(
-            Routes.FHIR_PATIENT_ID_SYSTEM,
-            which_idnum=self.which_idnum
+            Routes.FHIR_PATIENT_ID_SYSTEM, which_idnum=self.which_idnum
         )  # path will be e.g. /fhir_patient_id_system/3
 
     def effective_fhir_id_system(self, req: "CamcopsRequest") -> str:
@@ -209,11 +223,11 @@ class IdNumDefinition(Base):
 # Retrieving all IdNumDefinition objects
 # =============================================================================
 
+
 def get_idnum_definitions(dbsession: SqlASession) -> List[IdNumDefinition]:
     """
     Get all ID number definitions from the database, in order.
     """
     return list(
-        dbsession.query(IdNumDefinition)
-        .order_by(IdNumDefinition.which_idnum)
+        dbsession.query(IdNumDefinition).order_by(IdNumDefinition.which_idnum)
     )
