@@ -55,9 +55,7 @@ from camcops_server.cc_modules.cc_sqla_coltypes import (
 )
 from camcops_server.cc_modules.cc_sqlalchemy import Base, MutableDict
 from camcops_server.cc_modules.cc_taskfilter import TaskFilter
-from camcops_server.cc_modules.cc_user import (
-    User,
-)
+from camcops_server.cc_modules.cc_user import User
 
 if TYPE_CHECKING:
     from camcops_server.cc_modules.cc_request import CamcopsRequest
@@ -87,6 +85,7 @@ DEFAULT_NUMBER_OF_TASKS_TO_VIEW = 25
 # Security for web sessions
 # =============================================================================
 
+
 def generate_token(num_bytes: int = 16) -> str:
     """
     Make a new session token that's not in use.
@@ -103,64 +102,77 @@ def generate_token(num_bytes: int = 16) -> str:
 # Session class
 # =============================================================================
 
+
 class CamcopsSession(Base):
     """
     Class representing an HTTPS session.
     """
+
     __tablename__ = "_security_webviewer_sessions"
 
     # no TEXT fields here; this is a performance-critical table
     id = Column(
-        "id", Integer,
-        primary_key=True, autoincrement=True, index=True,
-        comment="Session ID (internal number for insertion speed)"
+        "id",
+        Integer,
+        primary_key=True,
+        autoincrement=True,
+        index=True,
+        comment="Session ID (internal number for insertion speed)",
     )
     token = Column(
-        "token", SessionTokenColType,
-        comment="Token (base 64 encoded random number)"
+        "token",
+        SessionTokenColType,
+        comment="Token (base 64 encoded random number)",
     )
     ip_address = Column(
-        "ip_address", IPAddressColType,
-        comment="IP address of user"
+        "ip_address", IPAddressColType, comment="IP address of user"
     )
     user_id = Column(
-        "user_id", Integer,
+        "user_id",
+        Integer,
         ForeignKey("_security_users.id", ondelete="CASCADE"),
-        # http://docs.sqlalchemy.org/en/latest/core/constraints.html#on-update-and-on-delete  # noqa
-        comment="User ID"
+        # https://docs.sqlalchemy.org/en/latest/core/constraints.html#on-update-and-on-delete  # noqa
+        comment="User ID",
     )
     last_activity_utc = Column(
-        "last_activity_utc", DateTime,
-        comment="Date/time of last activity (UTC)"
+        "last_activity_utc",
+        DateTime,
+        comment="Date/time of last activity (UTC)",
     )
     number_to_view = Column(
-        "number_to_view", Integer,
-        comment="Number of records to view"
+        "number_to_view", Integer, comment="Number of records to view"
     )
     task_filter_id = Column(
-        "task_filter_id", Integer,
+        "task_filter_id",
+        Integer,
         ForeignKey("_task_filters.id"),
-        comment="Task filter ID"
+        comment="Task filter ID",
     )
     is_api_session = Column(
-        "is_api_session", Boolean,
+        "is_api_session",
+        Boolean,
         default=False,
-        comment="This session is using the client API (not a human browsing)."
+        comment="This session is using the client API (not a human browsing).",
     )
     form_state = Column(
-        "form_state", MutableDict.as_mutable(JsonColType),
-        comment=("Any state that needs to be saved temporarily during "
-                 "wizard-style form submission")
+        "form_state",
+        MutableDict.as_mutable(JsonColType),
+        comment=(
+            "Any state that needs to be saved temporarily during "
+            "wizard-style form submission"
+        ),
     )
     user = relationship("User", lazy="joined", foreign_keys=[user_id])
     task_filter = relationship(
-        "TaskFilter", foreign_keys=[task_filter_id],
+        "TaskFilter",
+        foreign_keys=[task_filter_id],
         cascade="all, delete-orphan",
-        single_parent=True)
+        single_parent=True,
+    )
     # ... "save-update, merge" is the default. We are adding "delete", which
     # means that when this CamcopsSession is deleted, the corresponding
     # TaskFilter will be deleted as well. See
-    # http://docs.sqlalchemy.org/en/latest/orm/cascades.html#delete
+    # https://docs.sqlalchemy.org/en/latest/orm/cascades.html#delete
     # ... 2020-09-22: changed to "all, delete-orphan" and single_parent=True
     # https://docs.sqlalchemy.org/en/13/orm/cascades.html#cascade-delete-orphan
     # https://docs.sqlalchemy.org/en/13/errors.html#error-bbf0
@@ -172,9 +184,15 @@ class CamcopsSession(Base):
     def __repr__(self) -> str:
         return simple_repr(
             self,
-            ["id", "token", "ip_address", "user_id", "last_activity_utc_iso",
-             "user"],
-            with_addr=True
+            [
+                "id",
+                "token",
+                "ip_address",
+                "user_id",
+                "last_activity_utc_iso",
+                "user",
+            ],
+            with_addr=True,
         )
 
     @property
@@ -190,8 +208,9 @@ class CamcopsSession(Base):
     # -------------------------------------------------------------------------
 
     @classmethod
-    def get_session_using_cookies(cls,
-                                  req: "CamcopsRequest") -> "CamcopsSession":
+    def get_session_using_cookies(
+        cls, req: "CamcopsRequest"
+    ) -> "CamcopsSession":
         """
         Makes, or retrieves, a new
         :class:`camcops_server.cc_modules.cc_session.CamcopsSession` for this
@@ -202,9 +221,9 @@ class CamcopsSession(Base):
         """
         pyramid_session = req.session  # type: ISession
         # noinspection PyArgumentList
-        session_id_str = pyramid_session.get(CookieKey.SESSION_ID, '')
+        session_id_str = pyramid_session.get(CookieKey.SESSION_ID, "")
         # noinspection PyArgumentList
-        session_token = pyramid_session.get(CookieKey.SESSION_TOKEN, '')
+        session_token = pyramid_session.get(CookieKey.SESSION_TOKEN, "")
         return cls.get_session(req, session_id_str, session_token)
 
     @classmethod
@@ -220,9 +239,11 @@ class CamcopsSession(Base):
         User authentication is via the
         :class:`camcops_server.cc_modules.cc_session.CamcopsSession`.
         """
-        session = cls.get_session(req=ts.req,
-                                  session_id_str=ts.session_id,
-                                  session_token=ts.session_token)
+        session = cls.get_session(
+            req=ts.req,
+            session_id_str=ts.session_id,
+            session_token=ts.session_token,
+        )
         if not session.user:
             session._login_from_ts(ts)
         elif session.user and session.user.username != ts.username:
@@ -232,8 +253,9 @@ class CamcopsSession(Base):
             req = ts.req
             session.logout()
             # Create a fresh session.
-            session = cls.get_session(req=req, session_id_str=None,
-                                      session_token=None)
+            session = cls.get_session(
+                req=req, session_id_str=None, session_token=None
+            )
             session._login_from_ts(ts)
         return session
 
@@ -244,12 +266,15 @@ class CamcopsSession(Base):
         :class:`camcops_server.cc_modules.cc_tabletsession.TabletSession`.
         """
         if DEBUG_CAMCOPS_SESSION_CREATION:
-            log.debug("Considering login from tablet (with username: {!r}",
-                      ts.username)
+            log.debug(
+                "Considering login from tablet (with username: {!r}",
+                ts.username,
+            )
         self.is_api_session = True
         if ts.username:
             user = User.get_user_from_username_password(
-                ts.req, ts.username, ts.password)
+                ts.req, ts.username, ts.password
+            )
             if DEBUG_CAMCOPS_SESSION_CREATION:
                 log.debug("... looked up User: {!r}", user)
             if user:
@@ -262,18 +287,24 @@ class CamcopsSession(Base):
             log.debug("... final session user: {!r}", self.user)
 
     @classmethod
-    def get_session(cls,
-                    req: "CamcopsRequest",
-                    session_id_str: Optional[str],
-                    session_token: Optional[str]) -> 'CamcopsSession':
+    def get_session(
+        cls,
+        req: "CamcopsRequest",
+        session_id_str: Optional[str],
+        session_token: Optional[str],
+    ) -> "CamcopsSession":
         """
         Retrieves, or makes, a new
         :class:`camcops_server.cc_modules.cc_session.CamcopsSession` for this
         Pyramid Request, given a specific ``session_id`` and ``session_token``.
         """
         if DEBUG_CAMCOPS_SESSION_CREATION:
-            log.debug("CamcopsSession.get_session: session_id_str={!r}, "
-                      "session_token={!r}", session_id_str, session_token)
+            log.debug(
+                "CamcopsSession.get_session: session_id_str={!r}, "
+                "session_token={!r}",
+                session_id_str,
+                session_token,
+            )
         # ---------------------------------------------------------------------
         # Starting variables
         # ---------------------------------------------------------------------
@@ -289,12 +320,13 @@ class CamcopsSession(Base):
         # Fetch or create
         # ---------------------------------------------------------------------
         if session_id and session_token:
-            oldest_last_activity_allowed = \
-                cls.get_oldest_last_activity_allowed(req)
-            query = dbsession.query(cls).\
-                filter(cls.id == session_id).\
-                filter(cls.token == session_token).\
-                filter(cls.last_activity_utc >= oldest_last_activity_allowed)
+            oldest_permitted = cls.get_oldest_last_activity_allowed(req)
+            query = (
+                dbsession.query(cls)
+                .filter(cls.id == session_id)
+                .filter(cls.token == session_token)
+                .filter(cls.last_activity_utc >= oldest_permitted)
+            )
 
             if req.config.session_check_user_ip:
                 # Binding the session to the IP address can cause problems if
@@ -321,8 +353,9 @@ class CamcopsSession(Base):
             new_http_session = cls(ip_addr=ip_addr, last_activity_utc=now)
             dbsession.add(new_http_session)
             if DEBUG_CAMCOPS_SESSION_CREATION:
-                log.debug("Creating new CamcopsSession: {!r}",
-                          new_http_session)
+                log.debug(
+                    "Creating new CamcopsSession: {!r}", new_http_session
+                )
             # But we DO NOT FLUSH and we DO NOT SET THE COOKIES YET, because
             # we might hot-swap the session.
             # See complete_request_add_cookies().
@@ -331,7 +364,8 @@ class CamcopsSession(Base):
 
     @classmethod
     def get_oldest_last_activity_allowed(
-            cls, req: "CamcopsRequest") -> Pendulum:
+        cls, req: "CamcopsRequest"
+    ) -> Pendulum:
         """
         What is the latest time that the last activity (for a session) could
         have occurred, before the session would have timed out?
@@ -348,36 +382,35 @@ class CamcopsSession(Base):
         """
         Delete all expired sessions.
         """
-        oldest_last_activity_allowed = \
-            cls.get_oldest_last_activity_allowed(req)
+        oldest_last_activity_allowed = cls.get_oldest_last_activity_allowed(
+            req
+        )
         dbsession = req.dbsession
         log.debug("Deleting expired sessions")
-        dbsession.query(cls)\
-            .filter(cls.last_activity_utc < oldest_last_activity_allowed)\
-            .delete(synchronize_session=False)
+        dbsession.query(cls).filter(
+            cls.last_activity_utc < oldest_last_activity_allowed
+        ).delete(synchronize_session=False)
         # 2020-09-22: The cascade-delete to TaskFilter (see above) isn't
         # working, even without synchronize_session=False, and even after
         # adding delete-orphan and single_parent=True. So:
-        subquery_active_taskfilter_ids = (
-            dbsession.query(cls.task_filter_id)
-        )
-        dbsession.query(TaskFilter)\
-            .filter(TaskFilter.id.notin_(subquery_active_taskfilter_ids))\
-            .delete(synchronize_session=False)
+        subquery_active_taskfilter_ids = dbsession.query(cls.task_filter_id)
+        dbsession.query(TaskFilter).filter(
+            TaskFilter.id.notin_(subquery_active_taskfilter_ids)
+        ).delete(synchronize_session=False)
 
     @classmethod
-    def n_sessions_active_since(cls, req: "CamcopsRequest",
-                                when: Pendulum) -> int:
+    def n_sessions_active_since(
+        cls, req: "CamcopsRequest", when: Pendulum
+    ) -> int:
         when_utc = pendulum_to_utc_datetime_without_tz(when)
-        q = (
-            CountStarSpecializedQuery(cls, session=req.dbsession)
-            .filter(cls.last_activity_utc >= when_utc)
+        q = CountStarSpecializedQuery(cls, session=req.dbsession).filter(
+            cls.last_activity_utc >= when_utc
         )
         return q.count_star()
 
-    def __init__(self,
-                 ip_addr: str = None,
-                 last_activity_utc: Pendulum = None):
+    def __init__(
+        self, ip_addr: str = None, last_activity_utc: Pendulum = None
+    ):
         """
         Args:
             ip_addr: client IP address
@@ -405,7 +438,7 @@ class CamcopsSession(Base):
         Log out, wiping session details.
         """
         self.user_id = None
-        self.token = ''  # so there's no way this token can be re-used
+        self.token = ""  # so there's no way this token can be re-used
 
     def login(self, user: User) -> None:
         """
@@ -419,8 +452,9 @@ class CamcopsSession(Base):
         sessions).
         """
         if DEBUG_CAMCOPS_SESSION_CREATION:
-            log.debug("Session {} login: username={!r}",
-                      self.id, user.username)
+            log.debug(
+                "Session {} login: username={!r}", self.id, user.username
+            )
         self.user = user  # will set our user_id FK
         self.token = generate_token()
         # fresh token: https://www.owasp.org/index.php/Session_fixation
@@ -432,8 +466,9 @@ class CamcopsSession(Base):
             dbsession = SqlASession.object_session(self)
             assert dbsession, "No dbsession for a logged-in CamcopsSession"
             query = (
-                dbsession.query(CamcopsSession)
-                .filter(CamcopsSession.user_id == user.id)
+                dbsession.query(CamcopsSession).filter(
+                    CamcopsSession.user_id == user.id
+                )
                 # ... "same user"
                 .filter(CamcopsSession.is_api_session == False)  # noqa: E712
                 # ... "human webviewer sessions"
@@ -460,7 +495,8 @@ class CamcopsSession(Base):
             dbsession = SqlASession.object_session(self)
             assert dbsession, (
                 "CamcopsSession.get_task_filter() called on a CamcopsSession "
-                "that's not yet in a database session")
+                "that's not yet in a database session"
+            )
             self.task_filter = TaskFilter()
             dbsession.add(self.task_filter)
         return self.task_filter
