@@ -53,7 +53,10 @@ from camcops_server.cc_modules.cc_sqla_coltypes import (
     PendulumDurationAsIsoTextColType,
     TableNameColType,
 )
-from camcops_server.cc_modules.cc_task import Task, tablename_to_task_class_dict
+from camcops_server.cc_modules.cc_task import (
+    Task,
+    tablename_to_task_class_dict,
+)
 from camcops_server.cc_modules.cc_taskcollection import (
     TaskFilter,
     TaskCollection,
@@ -72,18 +75,22 @@ log = logging.getLogger(__name__)
 # ScheduledTaskInfo
 # =============================================================================
 
+
 class ScheduledTaskInfo(object):
     """
     Simple representation of a scheduled task (which may also contain the
     actual completed task, in its ``task`` member, if there is one).
     """
-    def __init__(self,
-                 shortname: str,
-                 tablename: str,
-                 is_anonymous: bool,
-                 task: Optional[Task] = None,
-                 start_datetime: Optional[Pendulum] = None,
-                 end_datetime: Optional[Pendulum] = None) -> None:
+
+    def __init__(
+        self,
+        shortname: str,
+        tablename: str,
+        is_anonymous: bool,
+        task: Optional[Task] = None,
+        start_datetime: Optional[Pendulum] = None,
+        end_datetime: Optional[Pendulum] = None,
+    ) -> None:
         self.shortname = shortname
         self.tablename = tablename
         self.is_anonymous = is_anonymous
@@ -131,52 +138,49 @@ class ScheduledTaskInfo(object):
 # PatientTaskSchedule
 # =============================================================================
 
+
 class PatientTaskSchedule(Base):
     """
     Joining table that associates a patient with a task schedule
     """
+
     __tablename__ = "_patient_task_schedule"
 
     id = Column("id", Integer, primary_key=True, autoincrement=True)
     patient_pk = Column(
-        "patient_pk", Integer,
-        ForeignKey("patient._pk"),
-        nullable=False,
+        "patient_pk", Integer, ForeignKey("patient._pk"), nullable=False
     )
     schedule_id = Column(
-        "schedule_id", Integer,
-        ForeignKey("_task_schedule.id"),
-        nullable=False,
+        "schedule_id", Integer, ForeignKey("_task_schedule.id"), nullable=False
     )
     start_datetime = Column(
-        "start_datetime", PendulumDateTimeAsIsoTextColType,
+        "start_datetime",
+        PendulumDateTimeAsIsoTextColType,
         comment=(
             "Schedule start date for the patient. Due from/within "
             "durations for a task schedule item are relative to this."
-        )
+        ),
     )
     settings = Column(
-        "settings", JsonColType,
-        comment="Task-specific settings for this patient"
+        "settings",
+        JsonColType,
+        comment="Task-specific settings for this patient",
     )
 
-    patient = relationship(
-        "Patient",
-        back_populates="task_schedules"
-    )
+    patient = relationship("Patient", back_populates="task_schedules")
     task_schedule = relationship(
-        "TaskSchedule",
-        back_populates="patient_task_schedules"
+        "TaskSchedule", back_populates="patient_task_schedules"
     )
 
     emails = relationship(
         "PatientTaskScheduleEmail",
         back_populates="patient_task_schedule",
-        cascade="all, delete"
+        cascade="all, delete",
     )
 
-    def get_list_of_scheduled_tasks(self, req: "CamcopsRequest") \
-            -> List[ScheduledTaskInfo]:
+    def get_list_of_scheduled_tasks(
+        self, req: "CamcopsRequest"
+    ) -> List[ScheduledTaskInfo]:
         """
         Tasks scheduled for this patient.
         """
@@ -194,9 +198,7 @@ class PatientTaskSchedule(Base):
                 start_datetime = self.start_datetime.add(
                     days=tsi.due_from.days
                 )
-                end_datetime = self.start_datetime.add(
-                    days=tsi.due_by.days
-                )
+                end_datetime = self.start_datetime.add(days=tsi.due_by.days)
 
                 task = self.find_scheduled_task(
                     req, tsi, start_datetime, end_datetime
@@ -217,19 +219,22 @@ class PatientTaskSchedule(Base):
 
         return task_list
 
-    def find_scheduled_task(self,
-                            req: "CamcopsRequest",
-                            tsi: "TaskScheduleItem",
-                            start_datetime: Pendulum,
-                            end_datetime: Pendulum) -> Optional[Task]:
+    def find_scheduled_task(
+        self,
+        req: "CamcopsRequest",
+        tsi: "TaskScheduleItem",
+        start_datetime: Pendulum,
+        end_datetime: Pendulum,
+    ) -> Optional[Task]:
         """
         Returns the most recently uploaded task that matches the patient (by
         any ID number, i.e. via OR), task type and timeframe
         """
         taskfilter = TaskFilter()
         for idnum in self.patient.idnums:
-            idnum_ref = IdNumReference(which_idnum=idnum.which_idnum,
-                                       idnum_value=idnum.idnum_value)
+            idnum_ref = IdNumReference(
+                which_idnum=idnum.which_idnum, idnum_value=idnum.idnum_value
+            )
             taskfilter.idnum_criteria.append(idnum_ref)
 
         taskfilter.task_types = [tsi.task_table_name]
@@ -252,7 +257,7 @@ class PatientTaskSchedule(Base):
         collection = TaskCollection(
             req=req,
             taskfilter=taskfilter,
-            sort_method_global=TaskSortMethod.CREATION_DATE_DESC
+            sort_method_global=TaskSortMethod.CREATION_DATE_DESC,
         )
 
         if len(collection.all_tasks) > 0:
@@ -275,8 +280,9 @@ class PatientTaskSchedule(Base):
         )
 
         formatter = TaskScheduleEmailTemplateFormatter()
-        return formatter.format(self.task_schedule.email_template,
-                                **template_dict)
+        return formatter.format(
+            self.task_schedule.email_template, **template_dict
+        )
 
     def launch_url(self, req: "CamcopsRequest", scheme: str) -> str:
         # Matches intent-filter in AndroidManifest.xml
@@ -323,10 +329,8 @@ def task_schedule_item_sort_order() -> Tuple["Cast", "Cast"]:
     consider storing Decimal numbers as strings or integers on this platform
     for lossless storage."
     """
-    due_from_order = cast(func.substr(TaskScheduleItem.due_from, 7),
-                          Numeric())
-    due_by_order = cast(func.substr(TaskScheduleItem.due_by, 7),
-                        Numeric())
+    due_from_order = cast(func.substr(TaskScheduleItem.due_from, 7), Numeric())
+    due_by_order = cast(func.substr(TaskScheduleItem.due_by, 7), Numeric())
 
     return due_from_order, due_by_order
 
@@ -335,30 +339,42 @@ def task_schedule_item_sort_order() -> Tuple["Cast", "Cast"]:
 # Emails sent to patient
 # =============================================================================
 
+
 class PatientTaskScheduleEmail(Base):
     """
     Represents an email send to a patient for a particular task schedule.
     """
+
     __tablename__ = "_patient_task_schedule_email"
 
     id = Column(
-        "id", Integer, primary_key=True, autoincrement=True,
-        comment="Arbitrary primary key"
+        "id",
+        Integer,
+        primary_key=True,
+        autoincrement=True,
+        comment="Arbitrary primary key",
     )
     patient_task_schedule_id = Column(
-        "patient_task_schedule_id", Integer, ForeignKey(PatientTaskSchedule.id),
+        "patient_task_schedule_id",
+        Integer,
+        ForeignKey(PatientTaskSchedule.id),
         nullable=False,
-        comment=(f"FK to {PatientTaskSchedule.__tablename__}."
-                 f"{PatientTaskSchedule.id.name}")
+        comment=(
+            f"FK to {PatientTaskSchedule.__tablename__}."
+            f"{PatientTaskSchedule.id.name}"
+        ),
     )
     email_id = Column(
-        "email_id", BigInteger, ForeignKey(Email.id),
+        "email_id",
+        BigInteger,
+        ForeignKey(Email.id),
         nullable=False,
-        comment=f"FK to {Email.__tablename__}.{Email.id.name}"
+        comment=f"FK to {Email.__tablename__}.{Email.id.name}",
     )
 
-    patient_task_schedule = relationship(PatientTaskSchedule,
-                                         back_populates="emails")
+    patient_task_schedule = relationship(
+        PatientTaskSchedule, back_populates="emails"
+    )
     email = relationship(Email, cascade="all, delete")
 
 
@@ -366,47 +382,65 @@ class PatientTaskScheduleEmail(Base):
 # Task schedule
 # =============================================================================
 
+
 class TaskSchedule(Base):
     """
     A named collection of task schedule items
     """
+
     __tablename__ = "_task_schedule"
 
     id = Column(
-        "id", Integer,
-        primary_key=True, autoincrement=True,
-        comment="Arbitrary primary key"
+        "id",
+        Integer,
+        primary_key=True,
+        autoincrement=True,
+        comment="Arbitrary primary key",
     )
 
     group_id = Column(
-        "group_id", Integer, ForeignKey(Group.id),
+        "group_id",
+        Integer,
+        ForeignKey(Group.id),
         nullable=False,
-        comment="FK to {}.{}".format(Group.__tablename__,
-                                     Group.id.name)
+        comment="FK to {}.{}".format(Group.__tablename__, Group.id.name),
     )
 
     name = Column("name", UnicodeText, comment="name")
 
-    email_subject = Column("email_subject", UnicodeText,
-                           comment="email subject", nullable=False, default="")
-    email_template = Column("email_template", UnicodeText,
-                            comment="email template", nullable=False,
-                            default="")
-    email_from = Column("email_from", EmailAddressColType,
-                        comment="Sender's e-mail address")
+    email_subject = Column(
+        "email_subject",
+        UnicodeText,
+        comment="email subject",
+        nullable=False,
+        default="",
+    )
+    email_template = Column(
+        "email_template",
+        UnicodeText,
+        comment="email template",
+        nullable=False,
+        default="",
+    )
+    email_from = Column(
+        "email_from", EmailAddressColType, comment="Sender's e-mail address"
+    )
     email_cc = Column(
-        "email_cc", UnicodeText,
-        comment="Send a carbon copy of the email to these addresses"
+        "email_cc",
+        UnicodeText,
+        comment="Send a carbon copy of the email to these addresses",
     )
     email_bcc = Column(
-        "email_bcc", UnicodeText,
-        comment="Send a blind carbon copy of the email to these addresses"
+        "email_bcc",
+        UnicodeText,
+        comment="Send a blind carbon copy of the email to these addresses",
     )
 
     items = relationship(
         "TaskScheduleItem",
+        back_populates="task_schedule",
         order_by=task_schedule_item_sort_order,
-        cascade="all, delete"
+        cascade="all, delete",
     )  # type: Iterable[TaskScheduleItem]
 
     group = relationship(Group)
@@ -414,7 +448,7 @@ class TaskSchedule(Base):
     patient_task_schedules = relationship(
         "PatientTaskSchedule",
         back_populates="task_schedule",
-        cascade="all, delete"
+        cascade="all, delete",
     )
 
     def user_may_edit(self, req: "CamcopsRequest") -> bool:
@@ -428,39 +462,54 @@ class TaskScheduleItem(Base):
     """
     An individual item in a task schedule
     """
+
     __tablename__ = "_task_schedule_item"
 
     id = Column(
-        "id", Integer,
-        primary_key=True, autoincrement=True,
-        comment="Arbitrary primary key"
+        "id",
+        Integer,
+        primary_key=True,
+        autoincrement=True,
+        comment="Arbitrary primary key",
     )
 
     schedule_id = Column(
-        "schedule_id", Integer, ForeignKey(TaskSchedule.id),
+        "schedule_id",
+        Integer,
+        ForeignKey(TaskSchedule.id),
         nullable=False,
-        comment="FK to {}.{}".format(TaskSchedule.__tablename__,
-                                     TaskSchedule.id.name)
+        comment="FK to {}.{}".format(
+            TaskSchedule.__tablename__, TaskSchedule.id.name
+        ),
     )
 
     task_table_name = Column(
-        "task_table_name", TableNameColType,
+        "task_table_name",
+        TableNameColType,
         index=True,
-        comment="Table name of the task's base table"
+        comment="Table name of the task's base table",
     )
 
     due_from = Column(
-        "due_from", PendulumDurationAsIsoTextColType,
-        comment=("Relative time from the start date by which the task may be "
-                 "started")
+        "due_from",
+        PendulumDurationAsIsoTextColType,
+        comment=(
+            "Relative time from the start date by which the task may be "
+            "started"
+        ),
     )  # type: Optional[Duration]
 
     due_by = Column(
-        "due_by", PendulumDurationAsIsoTextColType,
-        comment=("Relative time from the start date by which the task must be "
-                 "completed")
+        "due_by",
+        PendulumDurationAsIsoTextColType,
+        comment=(
+            "Relative time from the start date by which the task must be "
+            "completed"
+        ),
     )  # type: Optional[Duration]
 
+    task_schedule = relationship("TaskSchedule", back_populates="items")
+
     @property
     def task_shortname(self) -> str:
         """
@@ -498,8 +547,7 @@ class TaskScheduleItem(Base):
             due_days = self.due_from.in_days()
 
         return _("{task_name} @ {due_days} days").format(
-            task_name=self.task_shortname,
-            due_days=due_days
+            task_name=self.task_shortname, due_days=due_days
         )
 
 
@@ -507,12 +555,15 @@ class TaskScheduleEmailTemplateFormatter(SafeFormatter):
     """
     Safe template formatter for task schedule e-mails.
     """
+
     def __init__(self):
-        super().__init__([
-            "access_key",
-            "android_launch_url",
-            "forename",
-            "ios_launch_url",
-            "server_url",
-            "surname",
-        ])
+        super().__init__(
+            [
+                "access_key",
+                "android_launch_url",
+                "forename",
+                "ios_launch_url",
+                "server_url",
+                "surname",
+            ]
+        )
