@@ -67,9 +67,15 @@ import matplotlib.dates  # delayed until after the cc_plot import
 
 if TYPE_CHECKING:
     from camcops_server.cc_modules.cc_patient import Patient  # noqa: F401
-    from camcops_server.cc_modules.cc_patientidnum import PatientIdNum  # noqa: E501,F401
-    from camcops_server.cc_modules.cc_request import CamcopsRequest  # noqa: E501,F401
-    from camcops_server.cc_modules.cc_trackerhelpers import TrackerInfo  # noqa: E501,F401
+    from camcops_server.cc_modules.cc_patientidnum import (  # noqa: F401
+        PatientIdNum,
+    )
+    from camcops_server.cc_modules.cc_request import (  # noqa: F401
+        CamcopsRequest,
+    )
+    from camcops_server.cc_modules.cc_trackerhelpers import (  # noqa: F401
+        TrackerInfo,
+    )
 
 log = BraceStyleAdapter(logging.getLogger(__name__))
 
@@ -97,10 +103,13 @@ DEBUG_TRACKER_TASK_INCLUSION = False  # should be False for production system
 # =============================================================================
 # http://stackoverflow.com/questions/11788195
 
-def consistency(req: "CamcopsRequest",
-                values: List[Any],
-                servervalue: Any = None,
-                case_sensitive: bool = True) -> Tuple[bool, str]:
+
+def consistency(
+    req: "CamcopsRequest",
+    values: List[Any],
+    servervalue: Any = None,
+    case_sensitive: bool = True,
+) -> Tuple[bool, str]:
     """
     Checks for consistency in a set of values (e.g. names, dates of birth).
     (ID numbers are done separately via :func:`consistency_idnums`.)
@@ -131,19 +140,25 @@ def consistency(req: "CamcopsRequest",
         return True, f"{_('consistent')} ({unique[0]})"
     if len(unique) == 2:
         if None in unique:
-            return True, (
-                f"{_('consistent')} "
-                f"({_('all blank or')} {unique[1 - unique.index(None)]})"
+            return (
+                True,
+                (
+                    f"{_('consistent')} "
+                    f"({_('all blank or')} {unique[1 - unique.index(None)]})"
+                ),
             )
-    return False, (
-        f"<b>{_('INCONSISTENT')} "
-        f"({_('contains values')} {', '.join(unique)})</b>"
+    return (
+        False,
+        (
+            f"<b>{_('INCONSISTENT')} "
+            f"({_('contains values')} {', '.join(unique)})</b>"
+        ),
     )
 
 
-def consistency_idnums(req: "CamcopsRequest",
-                       idnum_lists: List[List["PatientIdNum"]]) \
-        -> Tuple[bool, str]:
+def consistency_idnums(
+    req: "CamcopsRequest", idnum_lists: List[List["PatientIdNum"]]
+) -> Tuple[bool, str]:
     """
     Checks the consistency of a set of :class:`PatientIdNum` objects.
     "Are all these records from the same patient?"
@@ -179,8 +194,10 @@ def consistency_idnums(req: "CamcopsRequest",
             # "For all tasks..."
             (
                 # "At least one ID number record relates to this which_idnum".
-                any(idnum.which_idnum == which_idnum
-                    and idnum.idnum_value is not None)
+                any(
+                    idnum.which_idnum == which_idnum
+                    and idnum.idnum_value is not None
+                )
                 for idnum in task_idnum_list
             )
             for task_idnum_list in idnum_lists
@@ -195,31 +212,40 @@ def consistency_idnums(req: "CamcopsRequest",
         value_str = ", ".join(str(v) for v in sorted(list(encountered_values)))
         if len(encountered_values) > 1:
             failures.append(
-                f"idnum{which_idnum} {_('contains values')} {value_str}")
+                f"idnum{which_idnum} {_('contains values')} {value_str}"
+            )
         else:
             if present_in_all[which_idnum]:
                 successes.append(
-                    f"idnum{which_idnum} {_('consistent')} ({value_str})")
+                    f"idnum{which_idnum} {_('consistent')} ({value_str})"
+                )
             else:
                 successes.append(
-                    f"idnum{which_idnum} {_('all blank or')} {value_str}")
+                    f"idnum{which_idnum} {_('all blank or')} {value_str}"
+                )
     if failures:
-        return False, (
-            f"<b>{_('INCONSISTENT')} ({'; '.join(failures + successes)})</b>"
+        return (
+            False,
+            (
+                f"<b>{_('INCONSISTENT')} "
+                f"({'; '.join(failures + successes)})</b>"
+            ),
         )
     else:
         return True, f"{_('consistent')} ({'; '.join(successes)})"
 
 
-def format_daterange(start: Optional[Pendulum],
-                     end: Optional[Pendulum]) -> str:
+def format_daterange(
+    start: Optional[Pendulum], end: Optional[Pendulum]
+) -> str:
     """
     Textual representation of an inclusive-to-exclusive date range.
 
     Arguments are datetime values.
     """
-    start_str = format_datetime(start, DateFormat.ISO8601_DATE_ONLY,
-                                default="−∞")
+    start_str = format_datetime(
+        start, DateFormat.ISO8601_DATE_ONLY, default="−∞"
+    )
     end_str = format_datetime(end, DateFormat.ISO8601_DATE_ONLY, default="+∞")
     return f"[{start_str}, {end_str})"
 
@@ -228,6 +254,7 @@ def format_daterange(start: Optional[Pendulum],
 # ConsistencyInfo class
 # =============================================================================
 
+
 class ConsistencyInfo(object):
     """
     Represents ID consistency information about a set of tasks.
@@ -241,26 +268,30 @@ class ConsistencyInfo(object):
         self.consistent_forename, self.msg_forename = consistency(
             req,
             [task.get_patient_forename() for task in tasklist],
-            servervalue=None, case_sensitive=False)
+            servervalue=None,
+            case_sensitive=False,
+        )
         self.consistent_surname, self.msg_surname = consistency(
             req,
             [task.get_patient_surname() for task in tasklist],
-            servervalue=None, case_sensitive=False)
+            servervalue=None,
+            case_sensitive=False,
+        )
         self.consistent_dob, self.msg_dob = consistency(
-            req,
-            [task.get_patient_dob_first11chars() for task in tasklist])
+            req, [task.get_patient_dob_first11chars() for task in tasklist]
+        )
         self.consistent_sex, self.msg_sex = consistency(
-            req,
-            [task.get_patient_sex() for task in tasklist])
+            req, [task.get_patient_sex() for task in tasklist]
+        )
         self.consistent_idnums, self.msg_idnums = consistency_idnums(
-            req,
-            [task.get_patient_idnum_objects() for task in tasklist])
+            req, [task.get_patient_idnum_objects() for task in tasklist]
+        )
         self.all_consistent = (
-            self.consistent_forename and
-            self.consistent_surname and
-            self.consistent_dob and
-            self.consistent_sex and
-            self.consistent_idnums
+            self.consistent_forename
+            and self.consistent_surname
+            and self.consistent_dob
+            and self.consistent_sex
+            and self.consistent_idnums
         )
 
     def are_all_consistent(self) -> bool:
@@ -293,14 +324,11 @@ class ConsistencyInfo(object):
             XmlElement(
                 name="all_consistent",
                 value=self.are_all_consistent(),
-                datatype="boolean"
+                datatype="boolean",
             )
         ]
         for c in self.get_description_list():
-            branches.append(XmlElement(
-                name="consistency_check",
-                value=c,
-            ))
+            branches.append(XmlElement(name="consistency_check", value=c))
         return XmlElement(name="_consistency", value=branches)
 
 
@@ -308,17 +336,20 @@ class ConsistencyInfo(object):
 # TrackerCtvCommon class:
 # =============================================================================
 
+
 class TrackerCtvCommon(object):
     """
     Base class for :class:`camcops_server.cc_modules.cc_tracker.Tracker` and
     :class:`camcops_server.cc_modules.cc_tracker.ClinicalTextView`.
     """
 
-    def __init__(self,
-                 req: "CamcopsRequest",
-                 taskfilter: TaskFilter,
-                 as_ctv: bool,
-                 via_index: bool = True) -> None:
+    def __init__(
+        self,
+        req: "CamcopsRequest",
+        taskfilter: TaskFilter,
+        as_ctv: bool,
+        via_index: bool = True,
+    ) -> None:
         """
         Initialize, fetching applicable tasks.
         """
@@ -334,7 +365,7 @@ class TrackerCtvCommon(object):
             taskfilter=taskfilter,
             sort_method_by_class=TaskSortMethod.CREATION_DATE_ASC,
             sort_method_global=TaskSortMethod.CREATION_DATE_ASC,
-            via_index=via_index
+            via_index=via_index,
         )
         all_tasks = self.collection.all_tasks
         if all_tasks:
@@ -364,14 +395,18 @@ class TrackerCtvCommon(object):
                     if DEBUG_TRACKER_TASK_INCLUSION:
                         self.summary += f" / PK {task.pk}"
             self.summary += " ~~~ "
-        self.summary += " — ".join([
-            "; ".join([
-                f"({task.tablename},{task.pk},"
-                f"{task.get_patient_server_pk()})"
-                for task in self.collection.tasks_for_task_class(cls)
-            ])
-            for cls in self.taskfilter.task_classes
-        ])
+        self.summary += " — ".join(
+            [
+                "; ".join(
+                    [
+                        f"({task.tablename},{task.pk},"
+                        f"{task.get_patient_server_pk()})"
+                        for task in self.collection.tasks_for_task_class(cls)
+                    ]
+                )
+                for cls in self.taskfilter.task_classes
+            ]
+        )
 
         # Consistency information
         self.consistency_info = ConsistencyInfo(req, all_tasks)
@@ -380,10 +415,12 @@ class TrackerCtvCommon(object):
     # Required for implementation
     # -------------------------------------------------------------------------
 
-    def get_xml(self,
-                indent_spaces: int = 4,
-                eol: str = '\n',
-                include_comments: bool = False) -> str:
+    def get_xml(
+        self,
+        indent_spaces: int = 4,
+        eol: str = "\n",
+        include_comments: bool = False,
+    ) -> str:
         """
         Returns an XML representation.
 
@@ -413,12 +450,14 @@ class TrackerCtvCommon(object):
     # XML view
     # -------------------------------------------------------------------------
 
-    def _get_xml(self,
-                 audit_string: str,
-                 xml_name: str,
-                 indent_spaces: int = 4,
-                 eol: str = '\n',
-                 include_comments: bool = False) -> str:
+    def _get_xml(
+        self,
+        audit_string: str,
+        xml_name: str,
+        indent_spaces: int = 4,
+        eol: str = "\n",
+        include_comments: bool = False,
+    ) -> str:
         """
         Returns an XML document representing this object.
 
@@ -434,8 +473,9 @@ class TrackerCtvCommon(object):
         """
         iddef = self.taskfilter.get_only_iddef()
         if not iddef:
-            raise ValueError("Tracker/CTV doesn't have a single ID number "
-                             "criterion")
+            raise ValueError(
+                "Tracker/CTV doesn't have a single ID number " "criterion"
+            )
         branches = [
             self.consistency_info.get_xml_root(),
             XmlElement(
@@ -443,36 +483,40 @@ class TrackerCtvCommon(object):
                 value=[
                     XmlElement(
                         name="task_tablename_list",
-                        value=",".join(self.taskfilter.task_tablename_list)
+                        value=",".join(self.taskfilter.task_tablename_list),
                     ),
                     XmlElement(
                         name=ViewParam.WHICH_IDNUM,
                         value=iddef.which_idnum,
-                        datatype=XmlDataTypes.INTEGER
+                        datatype=XmlDataTypes.INTEGER,
                     ),
                     XmlElement(
                         name=ViewParam.IDNUM_VALUE,
                         value=iddef.idnum_value,
-                        datatype=XmlDataTypes.INTEGER
+                        datatype=XmlDataTypes.INTEGER,
                     ),
                     XmlElement(
                         name=ViewParam.START_DATETIME,
-                        value=format_datetime(self.taskfilter.start_datetime,
-                                              DateFormat.ISO8601),
-                        datatype=XmlDataTypes.DATETIME
+                        value=format_datetime(
+                            self.taskfilter.start_datetime, DateFormat.ISO8601
+                        ),
+                        datatype=XmlDataTypes.DATETIME,
                     ),
                     XmlElement(
                         name=ViewParam.END_DATETIME,
-                        value=format_datetime(self.taskfilter.end_datetime,
-                                              DateFormat.ISO8601),
-                        datatype=XmlDataTypes.DATETIME
+                        value=format_datetime(
+                            self.taskfilter.end_datetime, DateFormat.ISO8601
+                        ),
+                        datatype=XmlDataTypes.DATETIME,
                     ),
-                ]
-            )
+                ],
+            ),
         ]
-        options = TaskExportOptions(xml_include_plain_columns=True,
-                                    xml_include_calculated=True,
-                                    include_blobs=False)
+        options = TaskExportOptions(
+            xml_include_plain_columns=True,
+            xml_include_calculated=True,
+            include_blobs=False,
+        )
         for t in self.collection.all_tasks:
             branches.append(t.get_xml_root(self.req, options))
             audit(
@@ -480,14 +524,14 @@ class TrackerCtvCommon(object):
                 audit_string,
                 table=t.tablename,
                 server_pk=t.pk,
-                patient_server_pk=t.get_patient_server_pk()
+                patient_server_pk=t.get_patient_server_pk(),
             )
         tree = XmlElement(name=xml_name, value=branches)
         return get_xml_document(
             tree,
             indent_spaces=indent_spaces,
             eol=eol,
-            include_comments=include_comments
+            include_comments=include_comments,
         )
 
     # -------------------------------------------------------------------------
@@ -526,21 +570,27 @@ class TrackerCtvCommon(object):
                 html=html,
                 header_html=render(
                     "wkhtmltopdf_header.mako",
-                    dict(inner_text=render("tracker_ctv_header.mako",
-                                           dict(tracker=self),
-                                           request=req)),
-                    request=req
+                    dict(
+                        inner_text=render(
+                            "tracker_ctv_header.mako",
+                            dict(tracker=self),
+                            request=req,
+                        )
+                    ),
+                    request=req,
                 ),
                 footer_html=render(
                     "wkhtmltopdf_footer.mako",
-                    dict(inner_text=render("tracker_ctv_footer.mako",
-                                           dict(tracker=self),
-                                           request=req)),
-                    request=req
+                    dict(
+                        inner_text=render(
+                            "tracker_ctv_footer.mako",
+                            dict(tracker=self),
+                            request=req,
+                        )
+                    ),
+                    request=req,
                 ),
-                extra_wkhtmltopdf_options={
-                    "orientation": "Portrait"
-                }
+                extra_wkhtmltopdf_options={"orientation": "Portrait"},
             )
 
     def suggested_pdf_filename(self) -> str:
@@ -552,17 +602,21 @@ class TrackerCtvCommon(object):
             req=self.req,
             patient_spec_if_anonymous=cfg.patient_spec_if_anonymous,
             patient_spec=cfg.patient_spec,
-            filename_spec=cfg.ctv_filename_spec if self.as_ctv else cfg.tracker_filename_spec,  # noqa
+            filename_spec=cfg.ctv_filename_spec
+            if self.as_ctv
+            else cfg.tracker_filename_spec,  # noqa
             filetype=ViewArg.PDF,
             is_anonymous=self.patient is None,
             surname=self.patient.get_surname() if self.patient else "",
             forename=self.patient.get_forename() if self.patient else "",
             dob=self.patient.get_dob() if self.patient else None,
             sex=self.patient.get_sex() if self.patient else None,
-            idnum_objects=self.patient.get_idnum_objects() if self.patient else None,  # noqa
+            idnum_objects=self.patient.get_idnum_objects()
+            if self.patient
+            else None,  # noqa
             creation_datetime=None,
             basetable=None,
-            serverpk=None
+            serverpk=None,
         )
 
 
@@ -570,46 +624,49 @@ class TrackerCtvCommon(object):
 # Tracker class
 # =============================================================================
 
+
 class Tracker(TrackerCtvCommon):
     """
     Class representing a numerical tracker.
     """
 
-    def __init__(self,
-                 req: "CamcopsRequest",
-                 taskfilter: TaskFilter,
-                 via_index: bool = True) -> None:
+    def __init__(
+        self,
+        req: "CamcopsRequest",
+        taskfilter: TaskFilter,
+        via_index: bool = True,
+    ) -> None:
         super().__init__(
-            req=req,
-            taskfilter=taskfilter,
-            as_ctv=False,
-            via_index=via_index
+            req=req, taskfilter=taskfilter, as_ctv=False, via_index=via_index
         )
 
-    def get_xml(self,
-                indent_spaces: int = 4,
-                eol: str = '\n',
-                include_comments: bool = False) -> str:
+    def get_xml(
+        self,
+        indent_spaces: int = 4,
+        eol: str = "\n",
+        include_comments: bool = False,
+    ) -> str:
         return self._get_xml(
             audit_string="Tracker XML accessed",
             xml_name="tracker",
             indent_spaces=indent_spaces,
             eol=eol,
-            include_comments=include_comments
+            include_comments=include_comments,
         )
 
     def _get_html(self) -> str:
-        return render("tracker.mako",
-                      dict(tracker=self,
-                           viewtype=ViewArg.HTML),
-                      request=self.req)
+        return render(
+            "tracker.mako",
+            dict(tracker=self, viewtype=ViewArg.HTML),
+            request=self.req,
+        )
 
     def _get_pdf_html(self) -> str:
-        return render("tracker.mako",
-                      dict(tracker=self,
-                           pdf_landscape=False,
-                           viewtype=ViewArg.PDF),
-                      request=self.req)
+        return render(
+            "tracker.mako",
+            dict(tracker=self, pdf_landscape=False, viewtype=ViewArg.PDF),
+            request=self.req,
+        )
 
     # -------------------------------------------------------------------------
     # Plotting
@@ -636,21 +693,24 @@ class Tracker(TrackerCtvCommon):
                 for tasknum in range(ntasks)
             ]
             html += self.get_single_plot_html(
-                datetimes, values,
-                specimen_tracker=alltrackers[0][tracker]
+                datetimes, values, specimen_tracker=alltrackers[0][tracker]
             )
         for task in tasks:
-            audit(self.req,
-                  "Tracker data accessed",
-                  table=task.tablename,
-                  server_pk=task.pk,
-                  patient_server_pk=task.get_patient_server_pk())
+            audit(
+                self.req,
+                "Tracker data accessed",
+                table=task.tablename,
+                server_pk=task.pk,
+                patient_server_pk=task.get_patient_server_pk(),
+            )
         return html
 
-    def get_single_plot_html(self,
-                             datetimes: List[Pendulum],
-                             values: List[Optional[float]],
-                             specimen_tracker: "TrackerInfo") -> str:
+    def get_single_plot_html(
+        self,
+        datetimes: List[Pendulum],
+        values: List[Optional[float]],
+        specimen_tracker: "TrackerInfo",
+    ) -> str:
         """
         HTML for a single figure.
         """
@@ -672,7 +732,7 @@ class Tracker(TrackerCtvCommon):
 
         figsize = (
             PlotDefaults.FULLWIDTH_PLOT_WIDTH,
-            (1.0 / float(aspect_ratio)) * PlotDefaults.FULLWIDTH_PLOT_WIDTH
+            (1.0 / float(aspect_ratio)) * PlotDefaults.FULLWIDTH_PLOT_WIDTH,
         )
         fig = self.req.create_figure(figsize=figsize)
         ax = fig.add_subplot(MatplotlibConstants.WHOLE_PANEL)
@@ -689,16 +749,18 @@ class Tracker(TrackerCtvCommon):
             markeredgecolor=MatplotlibConstants.COLOUR_RED,  # point colour
             markerfacecolor=MatplotlibConstants.COLOUR_RED,  # point colour
             label=None,
-            zorder=PlotDefaults.ZORDER_DATA_LINES_POINTS
+            zorder=PlotDefaults.ZORDER_DATA_LINES_POINTS,
         )
 
         # x axis
         ax.set_xlabel("Date/time", fontdict=self.req.fontdict)
         ax.set_xticks(x)
         ax.set_xticklabels(datelabels, fontdict=self.req.fontdict)
-        if (self.earliest is not None and
-                self.latest is not None and
-                self.earliest != self.latest):
+        if (
+            self.earliest is not None
+            and self.latest is not None
+            and self.earliest != self.latest
+        ):
             xlim = matplotlib.dates.date2num((self.earliest, self.latest))
             margin = (2.5 / 95.0) * (xlim[1] - xlim[0])
             xlim[0] -= margin
@@ -753,7 +815,7 @@ class Tracker(TrackerCtvCommon):
                     [y, y + stupid_jitter],  # y
                     color=MatplotlibConstants.COLOUR_GREY_50,
                     linestyle=MatplotlibConstants.LINESTYLE_DOTTED,
-                    zorder=PlotDefaults.ZORDER_PRESET_LINES
+                    zorder=PlotDefaults.ZORDER_PRESET_LINES,
                 )
                 # PROBLEM: horizontal lines becoming invisible
                 # (whether from ax.axhline or plot)
@@ -779,7 +841,7 @@ class Tracker(TrackerCtvCommon):
                     # opacity=0.5 with SVG lines
                     color=MatplotlibConstants.COLOUR_GREY_50,
                     fontdict=self.req.fontdict,
-                    zorder=PlotDefaults.ZORDER_PRESET_LABELS
+                    zorder=PlotDefaults.ZORDER_PRESET_LABELS,
                 )
 
         self.req.set_figure_font_sizes(ax)
@@ -801,43 +863,46 @@ class Tracker(TrackerCtvCommon):
 # ClinicalTextView class
 # =============================================================================
 
+
 class ClinicalTextView(TrackerCtvCommon):
     """
     Class representing a clinical text view.
     """
 
-    def __init__(self,
-                 req: "CamcopsRequest",
-                 taskfilter: TaskFilter,
-                 via_index: bool = True) -> None:
+    def __init__(
+        self,
+        req: "CamcopsRequest",
+        taskfilter: TaskFilter,
+        via_index: bool = True,
+    ) -> None:
         super().__init__(
-            req=req,
-            taskfilter=taskfilter,
-            as_ctv=True,
-            via_index=via_index
+            req=req, taskfilter=taskfilter, as_ctv=True, via_index=via_index
         )
 
-    def get_xml(self,
-                indent_spaces: int = 4,
-                eol: str = '\n',
-                include_comments: bool = False) -> str:
+    def get_xml(
+        self,
+        indent_spaces: int = 4,
+        eol: str = "\n",
+        include_comments: bool = False,
+    ) -> str:
         return self._get_xml(
             audit_string="Clinical text view XML accessed",
             xml_name="ctv",
             indent_spaces=indent_spaces,
             eol=eol,
-            include_comments=include_comments
+            include_comments=include_comments,
         )
 
     def _get_html(self) -> str:
-        return render("ctv.mako",
-                      dict(tracker=self,
-                           viewtype=ViewArg.HTML),
-                      request=self.req)
+        return render(
+            "ctv.mako",
+            dict(tracker=self, viewtype=ViewArg.HTML),
+            request=self.req,
+        )
 
     def _get_pdf_html(self) -> str:
-        return render("ctv.mako",
-                      dict(tracker=self,
-                           pdf_landscape=False,
-                           viewtype=ViewArg.PDF),
-                      request=self.req)
+        return render(
+            "ctv.mako",
+            dict(tracker=self, pdf_landscape=False, viewtype=ViewArg.PDF),
+            request=self.req,
+        )
