@@ -29,8 +29,6 @@ camcops_server/cc_modules/tests/cc_config_tests.py
 import configparser
 from unittest import TestCase
 
-from cardinal_pythonlib.sqlalchemy.logs import pre_disable_sqlalchemy_extra_echo_log  # noqa
-
 from camcops_server.cc_modules.cc_config import CamcopsConfig, get_demo_config
 
 
@@ -38,8 +36,8 @@ from camcops_server.cc_modules.cc_config import CamcopsConfig, get_demo_config
 # Unit tests
 # =============================================================================
 
-class EmailConfigTests(TestCase):
 
+class EmailConfigTests(TestCase):
     def setUp(self):
         super().setUp()
 
@@ -51,24 +49,32 @@ class EmailConfigTests(TestCase):
         self.parser.read_string(config_text)
 
         self.parser.set("export", "RECIPIENTS", "recipient_A")
-        self.parser.set("recipient:recipient_A", "TRANSMISSION_METHOD", "email")
+        self.parser.set(
+            "recipient:recipient_A", "TRANSMISSION_METHOD", "email"
+        )
 
         self.parser.set("site", "EMAIL_HOST", "smtp.example.com")
         self.parser.set("site", "EMAIL_PORT", "587")
         self.parser.set("site", "EMAIL_USE_TLS", "true")
         self.parser.set("site", "EMAIL_HOST_USERNAME", "username")
         self.parser.set("site", "EMAIL_HOST_PASSWORD", "mypassword")
-        self.parser.set("site", "EMAIL_FROM",
-                        "CamCOPS computer <from@example.com>")
-        self.parser.set("site", "EMAIL_SENDER",
-                        "CamCOPS computer <sender@example.com>")
-        self.parser.set("site", "EMAIL_REPLY_TO",
-                        "CamCOPS clinical administrator <admin@example.com>")
+        self.parser.set(
+            "site", "EMAIL_FROM", "CamCOPS computer <from@example.com>"
+        )
+        self.parser.set(
+            "site", "EMAIL_SENDER", "CamCOPS computer <sender@example.com>"
+        )
+        self.parser.set(
+            "site",
+            "EMAIL_REPLY_TO",
+            "CamCOPS clinical administrator <admin@example.com>",
+        )
 
         with StringIO() as buffer:
             self.parser.write(buffer)
-            self.config = CamcopsConfig(config_filename="",
-                                        config_text=buffer.getvalue())
+            self.config = CamcopsConfig(
+                config_filename="", config_text=buffer.getvalue()
+            )
 
     def test_export_recipients_use_site_email_config(self) -> None:
         recipient = self.config._export_recipients[0]
@@ -79,9 +85,13 @@ class EmailConfigTests(TestCase):
         self.assertTrue(recipient.email_use_tls)
         self.assertEqual(recipient.email_host_username, "username")
         self.assertEqual(recipient.email_host_password, "mypassword")
-        self.assertEqual(recipient.email_from,
-                         "CamCOPS computer <from@example.com>")
-        self.assertEqual(recipient.email_sender,
-                         "CamCOPS computer <sender@example.com>")
-        self.assertEqual(recipient.email_reply_to,
-                         "CamCOPS clinical administrator <admin@example.com>")
+        self.assertEqual(
+            recipient.email_from, "CamCOPS computer <from@example.com>"
+        )
+        self.assertEqual(
+            recipient.email_sender, "CamCOPS computer <sender@example.com>"
+        )
+        self.assertEqual(
+            recipient.email_reply_to,
+            "CamCOPS clinical administrator <admin@example.com>",
+        )
