@@ -41,25 +41,27 @@ from camcops_server.cc_modules.cc_unittest import BasicDatabaseTestCase
 # Unit tests
 # =============================================================================
 
+
 class TaskCollectionTests(BasicDatabaseTestCase):
     def test_it_can_be_serialized(self) -> None:
         taskfilter = TaskFilter()
-        taskfilter.task_types = ['task1', 'task2', 'task3']
+        taskfilter.task_types = ["task1", "task2", "task3"]
         taskfilter.group_ids = [1, 2, 3]
 
         coll = TaskCollection(
             self.req,
             taskfilter=taskfilter,
             as_dump=True,
-            sort_method_by_class=TaskSortMethod.CREATION_DATE_ASC
+            sort_method_by_class=TaskSortMethod.CREATION_DATE_ASC,
         )
         content_type, encoding, data = dumps(coll, serializer="json")
         new_coll = loads(data, content_type, encoding)
 
         self.assertEqual(new_coll._as_dump, True)
-        self.assertEqual(new_coll._sort_method_by_class,
-                         TaskSortMethod.CREATION_DATE_ASC)
-        self.assertEqual(new_coll._filter.task_types,
-                         ['task1', 'task2', 'task3'])
-        self.assertEqual(new_coll._filter.group_ids,
-                         [1, 2, 3])
+        self.assertEqual(
+            new_coll._sort_method_by_class, TaskSortMethod.CREATION_DATE_ASC
+        )
+        self.assertEqual(
+            new_coll._filter.task_types, ["task1", "task2", "task3"]
+        )
+        self.assertEqual(new_coll._filter.group_ids, [1, 2, 3])
