@@ -50,6 +50,7 @@ from camcops_server.cc_modules.cc_unittest import (
 # Unit tests
 # =============================================================================
 
+
 class TaskScheduleTests(DemoDatabaseTestCase):
     def test_deleting_deletes_related_objects(self) -> None:
         schedule = TaskSchedule()
@@ -83,32 +84,54 @@ class TaskScheduleTests(DemoDatabaseTestCase):
         self.dbsession.add(pts_email)
         self.dbsession.commit()
 
-        self.assertIsNotNone(self.dbsession.query(TaskScheduleItem).filter(
-            TaskScheduleItem.id == item.id).one_or_none())
-        self.assertIsNotNone(self.dbsession.query(PatientTaskSchedule).filter(
-            PatientTaskSchedule.id == pts.id).one_or_none())
         self.assertIsNotNone(
-            self.dbsession.query(PatientTaskScheduleEmail).filter(
+            self.dbsession.query(TaskScheduleItem)
+            .filter(TaskScheduleItem.id == item.id)
+            .one_or_none()
+        )
+        self.assertIsNotNone(
+            self.dbsession.query(PatientTaskSchedule)
+            .filter(PatientTaskSchedule.id == pts.id)
+            .one_or_none()
+        )
+        self.assertIsNotNone(
+            self.dbsession.query(PatientTaskScheduleEmail)
+            .filter(
                 PatientTaskScheduleEmail.patient_task_schedule_id == pts.id
-            ).one_or_none()
+            )
+            .one_or_none()
+        )
+        self.assertIsNotNone(
+            self.dbsession.query(Email)
+            .filter(Email.id == email.id)
+            .one_or_none()
         )
-        self.assertIsNotNone(self.dbsession.query(Email).filter(
-            Email.id == email.id).one_or_none())
 
         self.dbsession.delete(schedule)
         self.dbsession.commit()
 
-        self.assertIsNone(self.dbsession.query(TaskScheduleItem).filter(
-            TaskScheduleItem.id == item.id).one_or_none())
-        self.assertIsNone(self.dbsession.query(PatientTaskSchedule).filter(
-            PatientTaskSchedule.id == pts.id).one_or_none())
         self.assertIsNone(
-            self.dbsession.query(PatientTaskScheduleEmail).filter(
+            self.dbsession.query(TaskScheduleItem)
+            .filter(TaskScheduleItem.id == item.id)
+            .one_or_none()
+        )
+        self.assertIsNone(
+            self.dbsession.query(PatientTaskSchedule)
+            .filter(PatientTaskSchedule.id == pts.id)
+            .one_or_none()
+        )
+        self.assertIsNone(
+            self.dbsession.query(PatientTaskScheduleEmail)
+            .filter(
                 PatientTaskScheduleEmail.patient_task_schedule_id == pts.id
-            ).one_or_none()
+            )
+            .one_or_none()
+        )
+        self.assertIsNone(
+            self.dbsession.query(Email)
+            .filter(Email.id == email.id)
+            .one_or_none()
         )
-        self.assertIsNone(self.dbsession.query(Email).filter(
-            Email.id == email.id).one_or_none())
 
 
 class TaskScheduleItemTests(DemoRequestTestCase):
@@ -156,9 +179,14 @@ class PatientTaskScheduleTests(DemoDatabaseTestCase):
         self.dbsession.add(self.schedule)
 
         self.patient = self.create_patient(
-            id=1, forename="Jo", surname="Patient",
+            id=1,
+            forename="Jo",
+            surname="Patient",
             dob=datetime.date(1958, 4, 19),
-            sex="F", address="Address", gp="GP", other="Other"
+            sex="F",
+            address="Address",
+            gp="GP",
+            other="Other",
         )
 
         self.pts = PatientTaskSchedule()
@@ -172,8 +200,9 @@ class PatientTaskScheduleTests(DemoDatabaseTestCase):
         self.dbsession.add(self.schedule)
         self.dbsession.flush()
 
-        self.assertIn(f"{self.patient.uuid_as_proquint}",
-                      self.pts.email_body(self.req))
+        self.assertIn(
+            f"{self.patient.uuid_as_proquint}", self.pts.email_body(self.req)
+        )
 
     def test_email_body_contains_server_url(self) -> None:
         self.schedule.email_template = "{server_url}"
@@ -189,16 +218,18 @@ class PatientTaskScheduleTests(DemoDatabaseTestCase):
         self.dbsession.add(self.schedule)
         self.dbsession.flush()
 
-        self.assertIn(f"{self.pts.patient.forename}",
-                      self.pts.email_body(self.req))
+        self.assertIn(
+            f"{self.pts.patient.forename}", self.pts.email_body(self.req)
+        )
 
     def test_email_body_contains_patient_surname(self) -> None:
         self.schedule.email_template = "{surname}"
         self.dbsession.add(self.schedule)
         self.dbsession.flush()
 
-        self.assertIn(f"{self.pts.patient.surname}",
-                      self.pts.email_body(self.req))
+        self.assertIn(
+            f"{self.pts.patient.surname}", self.pts.email_body(self.req)
+        )
 
     def test_email_body_contains_android_launch_url(self) -> None:
         self.schedule.email_template = "{android_launch_url}"
@@ -212,10 +243,13 @@ class PatientTaskScheduleTests(DemoDatabaseTestCase):
         self.assertEqual(path, "/register/")
         query_dict = parse_qs(query)
         self.assertEqual(query_dict["default_single_user_mode"], ["true"])
-        self.assertEqual(query_dict["default_server_location"],
-                         [self.req.route_url(Routes.CLIENT_API)])
-        self.assertEqual(query_dict["default_access_key"],
-                         [self.patient.uuid_as_proquint])
+        self.assertEqual(
+            query_dict["default_server_location"],
+            [self.req.route_url(Routes.CLIENT_API)],
+        )
+        self.assertEqual(
+            query_dict["default_access_key"], [self.patient.uuid_as_proquint]
+        )
 
     def test_email_body_contains_ios_launch_url(self) -> None:
         self.schedule.email_template = "{ios_launch_url}"
@@ -229,10 +263,13 @@ class PatientTaskScheduleTests(DemoDatabaseTestCase):
         self.assertEqual(path, "/register/")
         query_dict = parse_qs(query)
         self.assertEqual(query_dict["default_single_user_mode"], ["true"])
-        self.assertEqual(query_dict["default_server_location"],
-                         [self.req.route_url(Routes.CLIENT_API)])
-        self.assertEqual(query_dict["default_access_key"],
-                         [self.patient.uuid_as_proquint])
+        self.assertEqual(
+            query_dict["default_server_location"],
+            [self.req.route_url(Routes.CLIENT_API)],
+        )
+        self.assertEqual(
+            query_dict["default_access_key"], [self.patient.uuid_as_proquint]
+        )
 
     def test_email_body_disallows_invalid_template(self) -> None:
         self.schedule.email_template = "{foobar}"
