@@ -53,14 +53,16 @@ from camcops_server.cc_modules.cc_sqlalchemy import (
 
 if TYPE_CHECKING:
     from sqlalchemy.engine.base import Engine
+
     # Should not need to import from _pytest in later versions of pytest
     # https://github.com/pytest-dev/pytest/issues/7469
     from _pytest.config.argparsing import Parser
     from _pytest.fixtures import FixtureRequest
 
 
-TEST_DATABASE_FILENAME = os.path.join(CAMCOPS_SERVER_DIRECTORY,
-                                      "camcops_test.sqlite")
+TEST_DATABASE_FILENAME = os.path.join(
+    CAMCOPS_SERVER_DIRECTORY, "camcops_test.sqlite"
+)
 
 
 def pytest_addoption(parser: "Parser"):
@@ -69,7 +71,7 @@ def pytest_addoption(parser: "Parser"):
         action="store_false",
         dest="database_on_disk",
         default=True,
-        help="Make SQLite database in memory"
+        help="Make SQLite database in memory",
     )
 
     # Borrowed from pytest-django
@@ -78,7 +80,7 @@ def pytest_addoption(parser: "Parser"):
         action="store_true",
         dest="create_db",
         default=False,
-        help="Create the database even if it already exists"
+        help="Create the database even if it already exists",
     )
 
     parser.addoption(
@@ -86,15 +88,17 @@ def pytest_addoption(parser: "Parser"):
         action="store_true",
         dest="mysql",
         default=False,
-        help="Use MySQL database instead of SQLite"
+        help="Use MySQL database instead of SQLite",
     )
 
     parser.addoption(
         "--db-url",
         dest="db_url",
-        default=("mysql+mysqldb://camcops:camcops@localhost:3306/test_camcops"
-                 "?charset=utf8"),
-        help="SQLAlchemy test database URL (MySQL only)"
+        default=(
+            "mysql+mysqldb://camcops:camcops@localhost:3306/test_camcops"
+            "?charset=utf8"
+        ),
+        help="SQLAlchemy test database URL (MySQL only)",
     )
 
     parser.addoption(
@@ -102,7 +106,7 @@ def pytest_addoption(parser: "Parser"):
         action="store_true",
         dest="echo",
         default=False,
-        help="Log all SQL statments to the default log handler"
+        help="Log all SQL statments to the default log handler",
     )
 
 
@@ -146,8 +150,9 @@ def db_url(request: "FixtureRequest") -> bool:
 
 
 @pytest.fixture(scope="session")
-def tmpdir_obj(request: "FixtureRequest") -> Generator[
-        tempfile.TemporaryDirectory, None, None]:
+def tmpdir_obj(
+    request: "FixtureRequest",
+) -> Generator[tempfile.TemporaryDirectory, None, None]:
     tmpdir_obj = tempfile.TemporaryDirectory()
 
     yield tmpdir_obj
@@ -156,14 +161,14 @@ def tmpdir_obj(request: "FixtureRequest") -> Generator[
 
 
 @pytest.fixture(scope="session")
-def config_file(request: "FixtureRequest",
-                tmpdir_obj: tempfile.TemporaryDirectory) -> str:
+def config_file(
+    request: "FixtureRequest", tmpdir_obj: tempfile.TemporaryDirectory
+) -> str:
     # We're going to be using a test (SQLite) database, but we want to
     # be very sure that nothing writes to a real database! Also, we will
     # want to read from this dummy config at some point.
 
-    tmpconfigfilename = os.path.join(tmpdir_obj.name,
-                                     "dummy_config.conf")
+    tmpconfigfilename = os.path.join(tmpdir_obj.name, "dummy_config.conf")
     with open(tmpconfigfilename, "w") as file:
         file.write(get_config_text())
 
@@ -186,29 +191,25 @@ def get_config_text() -> str:
 # Author says "no [license], feel free to use it"
 # noinspection PyUnusedLocal
 @pytest.fixture(scope="session")
-def engine(request: "FixtureRequest",
-           create_db: bool,
-           database_on_disk: bool,
-           echo: bool,
-           mysql: bool,
-           db_url: str) -> Generator["Engine", None, None]:
+def engine(
+    request: "FixtureRequest",
+    create_db: bool,
+    database_on_disk: bool,
+    echo: bool,
+    mysql: bool,
+    db_url: str,
+) -> Generator["Engine", None, None]:
 
     if mysql:
-        engine = create_engine_mysql(db_url,
-                                     create_db,
-                                     echo)
+        engine = create_engine_mysql(db_url, create_db, echo)
     else:
-        engine = create_engine_sqlite(create_db,
-                                      echo,
-                                      database_on_disk)
+        engine = create_engine_sqlite(create_db, echo, database_on_disk)
 
     yield engine
     engine.dispose()
 
 
-def create_engine_mysql(db_url: str,
-                        create_db: bool,
-                        echo: bool):
+def create_engine_mysql(db_url: str, create_db: bool, echo: bool):
 
     # The database and the user with the given password from db_url
     # need to exist.
@@ -223,9 +224,7 @@ def create_engine_mysql(db_url: str,
     return engine
 
 
-def create_engine_sqlite(create_db: bool,
-                         echo: bool,
-                         database_on_disk: bool):
+def create_engine_sqlite(create_db: bool, echo: bool, database_on_disk: bool):
     if create_db and database_on_disk:
         try:
             os.remove(TEST_DATABASE_FILENAME)
@@ -233,8 +232,7 @@ def create_engine_sqlite(create_db: bool,
             pass
 
     if database_on_disk:
-        engine = make_file_sqlite_engine(TEST_DATABASE_FILENAME,
-                                         echo=echo)
+        engine = make_file_sqlite_engine(TEST_DATABASE_FILENAME, echo=echo)
     else:
         engine = make_memory_sqlite_engine(echo=echo)
 
@@ -245,9 +243,9 @@ def create_engine_sqlite(create_db: bool,
 
 # noinspection PyUnusedLocal
 @pytest.fixture(scope="session")
-def tables(request: "FixtureRequest",
-           engine: "Engine",
-           create_db: bool) -> Generator[None, None, None]:
+def tables(
+    request: "FixtureRequest", engine: "Engine", create_db: bool
+) -> Generator[None, None, None]:
     if create_db:
         Base.metadata.create_all(engine)
     yield
@@ -261,9 +259,9 @@ def tables(request: "FixtureRequest",
 
 # noinspection PyUnusedLocal
 @pytest.fixture
-def dbsession(request: "FixtureRequest",
-              engine: "Engine",
-              tables: None) -> Generator[Session, None, None]:
+def dbsession(
+    request: "FixtureRequest", engine: "Engine", tables: None
+) -> Generator[Session, None, None]:
     """
     Returns an sqlalchemy session, and after the test tears down everything
     properly.
@@ -285,13 +283,15 @@ def dbsession(request: "FixtureRequest",
 
 
 @pytest.fixture
-def setup(request: "FixtureRequest",
-          engine: "Engine",
-          database_on_disk: bool,
-          mysql: bool,
-          dbsession: Session,
-          tmpdir_obj: tempfile.TemporaryDirectory,
-          config_file: str) -> None:
+def setup(
+    request: "FixtureRequest",
+    engine: "Engine",
+    database_on_disk: bool,
+    mysql: bool,
+    dbsession: Session,
+    tmpdir_obj: tempfile.TemporaryDirectory,
+    config_file: str,
+) -> None:
     # Pytest prefers function-based tests over unittest.TestCase subclasses and
     # methods, but it still supports the latter perfectly well.
     # We use this fixture in cc_unittest.py to store these values into
