@@ -36,12 +36,7 @@ from sqlalchemy.sql.sqltypes import Integer
 from camcops_server.cc_modules.cc_constants import CssClass
 from camcops_server.cc_modules.cc_ctvinfo import CTV_INCOMPLETE, CtvInfo
 from camcops_server.cc_modules.cc_db import add_multiple_columns
-from camcops_server.cc_modules.cc_html import (
-    answer,
-    get_yes_no,
-    tr,
-    tr_qa,
-)
+from camcops_server.cc_modules.cc_html import answer, get_yes_no, tr, tr_qa
 from camcops_server.cc_modules.cc_request import CamcopsRequest
 from camcops_server.cc_modules.cc_snomed import SnomedExpression, SnomedLookup
 from camcops_server.cc_modules.cc_summaryelement import SummaryElement
@@ -58,30 +53,44 @@ from camcops_server.cc_modules.cc_trackerhelpers import TrackerInfo
 # AUDIT
 # =============================================================================
 
+
 class AuditMetaclass(DeclarativeMeta):
     # noinspection PyInitNewSignature
-    def __init__(cls: Type['Audit'],
-                 name: str,
-                 bases: Tuple[Type, ...],
-                 classdict: Dict[str, Any]) -> None:
+    def __init__(
+        cls: Type["Audit"],
+        name: str,
+        bases: Tuple[Type, ...],
+        classdict: Dict[str, Any],
+    ) -> None:
         add_multiple_columns(
-            cls, "q", 1, cls.NQUESTIONS,
-            minimum=0, maximum=4,
+            cls,
+            "q",
+            1,
+            cls.NQUESTIONS,
+            minimum=0,
+            maximum=4,
             comment_fmt="Q{n}, {s} (0-4, higher worse)",
             comment_strings=[
-                "how often drink", "drinks per day", "how often six drinks",
-                "unable to stop", "unable to do what was expected",
-                "eye opener", "guilt", "unable to remember", "injuries",
-                "others concerned"]
+                "how often drink",
+                "drinks per day",
+                "how often six drinks",
+                "unable to stop",
+                "unable to do what was expected",
+                "eye opener",
+                "guilt",
+                "unable to remember",
+                "injuries",
+                "others concerned",
+            ],
         )
         super().__init__(name, bases, classdict)
 
 
-class Audit(TaskHasPatientMixin, Task,
-            metaclass=AuditMetaclass):
+class Audit(TaskHasPatientMixin, Task, metaclass=AuditMetaclass):
     """
     Server implementation of the AUDIT task.
     """
+
     __tablename__ = "audit"
     shortname = "AUDIT"
     provides_trackers = True
@@ -97,28 +106,30 @@ class Audit(TaskHasPatientMixin, Task,
         return _("WHO Alcohol Use Disorders Identification Test")
 
     def get_trackers(self, req: CamcopsRequest) -> List[TrackerInfo]:
-        return [TrackerInfo(
-            value=self.total_score(),
-            plot_label="AUDIT total score",
-            axis_label="Total score (out of 40)",
-            axis_min=-0.5,
-            axis_max=40.5,
-            horizontal_lines=[7.5]
-        )]
+        return [
+            TrackerInfo(
+                value=self.total_score(),
+                plot_label="AUDIT total score",
+                axis_label="Total score (out of 40)",
+                axis_min=-0.5,
+                axis_max=40.5,
+                horizontal_lines=[7.5],
+            )
+        ]
 
     def get_clinical_text(self, req: CamcopsRequest) -> List[CtvInfo]:
         if not self.is_complete():
             return CTV_INCOMPLETE
-        return [CtvInfo(
-            content=f"AUDIT total score {self.total_score()}/40"
-        )]
+        return [CtvInfo(content=f"AUDIT total score {self.total_score()}/40")]
 
     def get_summaries(self, req: CamcopsRequest) -> List[SummaryElement]:
         return self.standard_task_summary_fields() + [
-            SummaryElement(name="total",
-                           coltype=Integer(),
-                           value=self.total_score(),
-                           comment="Total score (/40)"),
+            SummaryElement(
+                name="total",
+                coltype=Integer(),
+                value=self.total_score(),
+                comment="Total score (/40)",
+            )
         ]
 
     # noinspection PyUnresolvedReferences
@@ -130,9 +141,11 @@ class Audit(TaskHasPatientMixin, Task,
         if self.q1 == 0:
             # Special limited-information completeness
             return True
-        if self.q2 is not None \
-                and self.q3 is not None \
-                and (self.q2 + self.q3 == 0):
+        if (
+            self.q2 is not None
+            and self.q3 is not None
+            and (self.q2 + self.q3 == 0)
+        ):
             # Special limited-information completeness
             return True
         # Otherwise, any null values cause problems
@@ -150,29 +163,45 @@ class Audit(TaskHasPatientMixin, Task,
         q3_to_8_dict = {None: None}
         q9_to_10_dict = {None: None}
         for option in range(0, 5):
-            q1_dict[option] = str(option) + " – " + \
-                self.wxstring(req, "q1_option" + str(option))
-            q2_dict[option] = str(option) + " – " + \
-                self.wxstring(req, "q2_option" + str(option))
-            q3_to_8_dict[option] = str(option) + " – " + \
-                self.wxstring(req, "q3to8_option" + str(option))
+            q1_dict[option] = (
+                str(option)
+                + " – "
+                + self.wxstring(req, "q1_option" + str(option))
+            )
+            q2_dict[option] = (
+                str(option)
+                + " – "
+                + self.wxstring(req, "q2_option" + str(option))
+            )
+            q3_to_8_dict[option] = (
+                str(option)
+                + " – "
+                + self.wxstring(req, "q3to8_option" + str(option))
+            )
             if option != 1 and option != 3:
-                q9_to_10_dict[option] = str(option) + " – " + \
-                    self.wxstring(req, "q9to10_option" + str(option))
+                q9_to_10_dict[option] = (
+                    str(option)
+                    + " – "
+                    + self.wxstring(req, "q9to10_option" + str(option))
+                )
 
-        q_a = tr_qa(self.wxstring(req, "q1_s"),
-                    get_from_dict(q1_dict, self.q1))
-        q_a += tr_qa(self.wxstring(req, "q2_s"),
-                     get_from_dict(q2_dict, self.q2))
+        q_a = tr_qa(
+            self.wxstring(req, "q1_s"), get_from_dict(q1_dict, self.q1)
+        )
+        q_a += tr_qa(
+            self.wxstring(req, "q2_s"), get_from_dict(q2_dict, self.q2)
+        )
         for q in range(3, 8 + 1):
             q_a += tr_qa(
                 self.wxstring(req, "q" + str(q) + "_s"),
-                get_from_dict(q3_to_8_dict, getattr(self, "q" + str(q)))
+                get_from_dict(q3_to_8_dict, getattr(self, "q" + str(q))),
             )
-        q_a += tr_qa(self.wxstring(req, "q9_s"),
-                     get_from_dict(q9_to_10_dict, self.q9))
-        q_a += tr_qa(self.wxstring(req, "q10_s"),
-                     get_from_dict(q9_to_10_dict, self.q10))
+        q_a += tr_qa(
+            self.wxstring(req, "q9_s"), get_from_dict(q9_to_10_dict, self.q9)
+        )
+        q_a += tr_qa(
+            self.wxstring(req, "q10_s"), get_from_dict(q9_to_10_dict, self.q10)
+        )
 
         return f"""
             <div class="{CssClass.SUMMARY}">
@@ -200,14 +229,18 @@ class Audit(TaskHasPatientMixin, Task,
         """
 
     def get_snomed_codes(self, req: CamcopsRequest) -> List[SnomedExpression]:
-        codes = [SnomedExpression(req.snomed(SnomedLookup.AUDIT_PROCEDURE_ASSESSMENT))]  # noqa
+        codes = [
+            SnomedExpression(
+                req.snomed(SnomedLookup.AUDIT_PROCEDURE_ASSESSMENT)
+            )
+        ]
         if self.is_complete():
-            codes.append(SnomedExpression(
-                req.snomed(SnomedLookup.AUDIT_SCALE),
-                {
-                    req.snomed(SnomedLookup.AUDIT_SCORE): self.total_score(),
-                }
-            ))
+            codes.append(
+                SnomedExpression(
+                    req.snomed(SnomedLookup.AUDIT_SCALE),
+                    {req.snomed(SnomedLookup.AUDIT_SCORE): self.total_score()},
+                )
+            )
         return codes
 
 
@@ -215,25 +248,33 @@ class Audit(TaskHasPatientMixin, Task,
 # AUDIT-C
 # =============================================================================
 
+
 class AuditCMetaclass(DeclarativeMeta):
     # noinspection PyInitNewSignature
-    def __init__(cls: Type['AuditC'],
-                 name: str,
-                 bases: Tuple[Type, ...],
-                 classdict: Dict[str, Any]) -> None:
+    def __init__(
+        cls: Type["AuditC"],
+        name: str,
+        bases: Tuple[Type, ...],
+        classdict: Dict[str, Any],
+    ) -> None:
         add_multiple_columns(
-            cls, "q", 1, cls.NQUESTIONS,
-            minimum=0, maximum=4,
+            cls,
+            "q",
+            1,
+            cls.NQUESTIONS,
+            minimum=0,
+            maximum=4,
             comment_fmt="Q{n}, {s} (0-4, higher worse)",
             comment_strings=[
-                "how often drink", "drinks per day", "how often six drinks"
-            ]
+                "how often drink",
+                "drinks per day",
+                "how often six drinks",
+            ],
         )
         super().__init__(name, bases, classdict)
 
 
-class AuditC(TaskHasPatientMixin, Task,
-             metaclass=AuditMetaclass):
+class AuditC(TaskHasPatientMixin, Task, metaclass=AuditMetaclass):
     __tablename__ = "audit_c"
     shortname = "AUDIT-C"
     extrastring_taskname = "audit"  # shares strings with AUDIT
@@ -250,27 +291,31 @@ class AuditC(TaskHasPatientMixin, Task,
         return _("AUDIT Alcohol Consumption Questions")
 
     def get_trackers(self, req: CamcopsRequest) -> List[TrackerInfo]:
-        return [TrackerInfo(
-            value=self.total_score(),
-            plot_label="AUDIT-C total score",
-            axis_label="Total score (out of 12)",
-            axis_min=-0.5,
-            axis_max=12.5,
-        )]
+        return [
+            TrackerInfo(
+                value=self.total_score(),
+                plot_label="AUDIT-C total score",
+                axis_label="Total score (out of 12)",
+                axis_min=-0.5,
+                axis_max=12.5,
+            )
+        ]
 
     def get_clinical_text(self, req: CamcopsRequest) -> List[CtvInfo]:
         if not self.is_complete():
             return CTV_INCOMPLETE
-        return [CtvInfo(
-            content=f"AUDIT-C total score {self.total_score()}/12"
-        )]
+        return [
+            CtvInfo(content=f"AUDIT-C total score {self.total_score()}/12")
+        ]
 
     def get_summaries(self, req: CamcopsRequest) -> List[SummaryElement]:
         return self.standard_task_summary_fields() + [
-            SummaryElement(name="total",
-                           coltype=Integer(),
-                           value=self.total_score(),
-                           comment="Total score (/12)"),
+            SummaryElement(
+                name="total",
+                coltype=Integer(),
+                value=self.total_score(),
+                comment="Total score (/12)",
+            )
         ]
 
     def is_complete(self) -> bool:
@@ -285,16 +330,26 @@ class AuditC(TaskHasPatientMixin, Task,
         q2_dict = {None: None}
         q3_dict = {None: None}
         for option in range(0, 5):
-            q1_dict[option] = str(option) + " – " + \
-                self.wxstring(req, "q1_option" + str(option))
+            q1_dict[option] = (
+                str(option)
+                + " – "
+                + self.wxstring(req, "q1_option" + str(option))
+            )
             if option == 0:  # special!
-                q2_dict[option] = str(option) + " – " + \
-                    self.wxstring(req, "c_q2_option0")
+                q2_dict[option] = (
+                    str(option) + " – " + self.wxstring(req, "c_q2_option0")
+                )
             else:
-                q2_dict[option] = str(option) + " – " + \
-                    self.wxstring(req, "q2_option" + str(option))
-            q3_dict[option] = str(option) + " – " + \
-                self.wxstring(req, "q3to8_option" + str(option))
+                q2_dict[option] = (
+                    str(option)
+                    + " – "
+                    + self.wxstring(req, "q2_option" + str(option))
+                )
+            q3_dict[option] = (
+                str(option)
+                + " – "
+                + self.wxstring(req, "q3to8_option" + str(option))
+            )
 
         # noinspection PyUnresolvedReferences
         return f"""
@@ -328,12 +383,20 @@ class AuditC(TaskHasPatientMixin, Task,
         """
 
     def get_snomed_codes(self, req: CamcopsRequest) -> List[SnomedExpression]:
-        codes = [SnomedExpression(req.snomed(SnomedLookup.AUDITC_PROCEDURE_ASSESSMENT))]  # noqa
+        codes = [
+            SnomedExpression(
+                req.snomed(SnomedLookup.AUDITC_PROCEDURE_ASSESSMENT)
+            )
+        ]
         if self.is_complete():
-            codes.append(SnomedExpression(
-                req.snomed(SnomedLookup.AUDITC_SCALE),
-                {
-                    req.snomed(SnomedLookup.AUDITC_SCORE): self.total_score(),
-                }
-            ))
+            codes.append(
+                SnomedExpression(
+                    req.snomed(SnomedLookup.AUDITC_SCALE),
+                    {
+                        req.snomed(
+                            SnomedLookup.AUDITC_SCORE
+                        ): self.total_score()
+                    },
+                )
+            )
         return codes
