@@ -53,34 +53,60 @@ from camcops_server.cc_modules.cc_trackerhelpers import TrackerInfo
 # BPRS-E
 # =============================================================================
 
+
 class BprseMetaclass(DeclarativeMeta):
     # noinspection PyInitNewSignature
-    def __init__(cls: Type['Bprse'],
-                 name: str,
-                 bases: Tuple[Type, ...],
-                 classdict: Dict[str, Any]) -> None:
+    def __init__(
+        cls: Type["Bprse"],
+        name: str,
+        bases: Tuple[Type, ...],
+        classdict: Dict[str, Any],
+    ) -> None:
         add_multiple_columns(
-            cls, "q", 1, cls.NQUESTIONS,
-            minimum=0, maximum=7,
+            cls,
+            "q",
+            1,
+            cls.NQUESTIONS,
+            minimum=0,
+            maximum=7,
             comment_fmt="Q{n}, {s} (1-7, higher worse, or 0 for not assessed)",
             comment_strings=[
-                "somatic concern", "anxiety", "depression", "suicidality",
-                "guilt", "hostility", "elevated mood", "grandiosity",
-                "suspiciousness", "hallucinations", "unusual thought content",
-                "bizarre behaviour", "self-neglect", "disorientation",
-                "conceptual disorganisation", "blunted affect",
-                "emotional withdrawal", "motor retardation", "tension",
-                "uncooperativeness", "excitement", "distractibility",
-                "motor hyperactivity", "mannerisms and posturing"]
+                "somatic concern",
+                "anxiety",
+                "depression",
+                "suicidality",
+                "guilt",
+                "hostility",
+                "elevated mood",
+                "grandiosity",
+                "suspiciousness",
+                "hallucinations",
+                "unusual thought content",
+                "bizarre behaviour",
+                "self-neglect",
+                "disorientation",
+                "conceptual disorganisation",
+                "blunted affect",
+                "emotional withdrawal",
+                "motor retardation",
+                "tension",
+                "uncooperativeness",
+                "excitement",
+                "distractibility",
+                "motor hyperactivity",
+                "mannerisms and posturing",
+            ],
         )
         super().__init__(name, bases, classdict)
 
 
-class Bprse(TaskHasPatientMixin, TaskHasClinicianMixin, Task,
-            metaclass=BprseMetaclass):
+class Bprse(
+    TaskHasPatientMixin, TaskHasClinicianMixin, Task, metaclass=BprseMetaclass
+):
     """
     Server implementation of the BPRS-E task.
     """
+
     __tablename__ = "bprse"
     shortname = "BPRS-E"
     provides_trackers = True
@@ -95,33 +121,40 @@ class Bprse(TaskHasPatientMixin, TaskHasClinicianMixin, Task,
         return _("Brief Psychiatric Rating Scale, Expanded")
 
     def get_trackers(self, req: CamcopsRequest) -> List[TrackerInfo]:
-        return [TrackerInfo(
-            value=self.total_score(),
-            plot_label="BPRS-E total score",
-            axis_label=f"Total score (out of {self.MAX_SCORE})",
-            axis_min=-0.5,
-            axis_max=self.MAX_SCORE + 0.5,
-        )]
+        return [
+            TrackerInfo(
+                value=self.total_score(),
+                plot_label="BPRS-E total score",
+                axis_label=f"Total score (out of {self.MAX_SCORE})",
+                axis_min=-0.5,
+                axis_max=self.MAX_SCORE + 0.5,
+            )
+        ]
 
     def get_clinical_text(self, req: CamcopsRequest) -> List[CtvInfo]:
         if not self.is_complete():
             return CTV_INCOMPLETE
-        return [CtvInfo(
-            content=f"BPRS-E total score {self.total_score()}/{self.MAX_SCORE}"
-        )]
+        return [
+            CtvInfo(
+                content=f"BPRS-E total score "
+                f"{self.total_score()}/{self.MAX_SCORE}"
+            )
+        ]
 
     def get_summaries(self, req: CamcopsRequest) -> List[SummaryElement]:
         return self.standard_task_summary_fields() + [
-            SummaryElement(name="total",
-                           coltype=Integer(),
-                           value=self.total_score(),
-                           comment=f"Total score (/{self.MAX_SCORE})"),
+            SummaryElement(
+                name="total",
+                coltype=Integer(),
+                value=self.total_score(),
+                comment=f"Total score (/{self.MAX_SCORE})",
+            )
         ]
 
     def is_complete(self) -> bool:
         return (
-            self.all_fields_not_none(self.TASK_FIELDS) and
-            self.field_contents_valid()
+            self.all_fields_not_none(self.TASK_FIELDS)
+            and self.field_contents_valid()
         )
 
     def total_score(self) -> int:
@@ -140,20 +173,20 @@ class Bprse(TaskHasPatientMixin, TaskHasClinicianMixin, Task,
             4: "4 — " + bprs_string("old_option4"),
             5: "5 — " + bprs_string("old_option5"),
             6: "6 — " + bprs_string("old_option6"),
-            7: "7 — " + bprs_string("old_option7")
+            7: "7 — " + bprs_string("old_option7"),
         }
 
         q_a = ""
         for i in range(1, self.NQUESTIONS + 1):
             q_a += tr_qa(
                 self.wxstring(req, "q" + str(i) + "_s"),
-                get_from_dict(main_dict, getattr(self, "q" + str(i)))
+                get_from_dict(main_dict, getattr(self, "q" + str(i))),
             )
 
         total_score = tr(
-            req.sstring(SS.TOTAL_SCORE) +
-            f" (0–{self.MAX_SCORE}; 24–{self.MAX_SCORE} if all rated)",
-            answer(self.total_score())
+            req.sstring(SS.TOTAL_SCORE)
+            + f" (0–{self.MAX_SCORE}; 24–{self.MAX_SCORE} if all rated)",
+            answer(self.total_score()),
         )
         return f"""
             <div class="{CssClass.SUMMARY}">
