@@ -53,63 +53,97 @@ from camcops_server.cc_modules.cc_trackerhelpers import TrackerInfo
 # =============================================================================
 
 QUESTION_SNIPPETS = [
-    "sounds loud", "presence of another", "heard thoughts echoed",
-    "see shapes/lights/colours", "burning or other bodily sensations",
-    "hear noises/sounds", "thoughts spoken aloud", "unexplained smells",
-    "body changing shape", "limbs not own", "voices commenting",
-    "feeling a touch", "hearing words or sentences", "unexplained tastes",
-    "sensations flooding", "sounds distorted",
-    "hard to distinguish sensations", "odours strong",
-    "shapes/people distorted", "hypersensitive to touch/temperature",
-    "tastes stronger than normal", "face looks different",
-    "lights/colours more intense", "feeling of being uplifted",
-    "common smells seem different", "everyday things look abnormal",
-    "altered perception of time", "hear voices conversing",
+    "sounds loud",
+    "presence of another",
+    "heard thoughts echoed",
+    "see shapes/lights/colours",
+    "burning or other bodily sensations",
+    "hear noises/sounds",
+    "thoughts spoken aloud",
+    "unexplained smells",
+    "body changing shape",
+    "limbs not own",
+    "voices commenting",
+    "feeling a touch",
+    "hearing words or sentences",
+    "unexplained tastes",
+    "sensations flooding",
+    "sounds distorted",
+    "hard to distinguish sensations",
+    "odours strong",
+    "shapes/people distorted",
+    "hypersensitive to touch/temperature",
+    "tastes stronger than normal",
+    "face looks different",
+    "lights/colours more intense",
+    "feeling of being uplifted",
+    "common smells seem different",
+    "everyday things look abnormal",
+    "altered perception of time",
+    "hear voices conversing",
     "smells or odours that others are unaware of",
-    "food/drink tastes unusual", "see things that others cannot",
-    "hear sounds/music that others cannot"
+    "food/drink tastes unusual",
+    "see things that others cannot",
+    "hear sounds/music that others cannot",
 ]
 
 
 class CapsMetaclass(DeclarativeMeta):
     # noinspection PyInitNewSignature
-    def __init__(cls: Type['Caps'],
-                 name: str,
-                 bases: Tuple[Type, ...],
-                 classdict: Dict[str, Any]) -> None:
+    def __init__(
+        cls: Type["Caps"],
+        name: str,
+        bases: Tuple[Type, ...],
+        classdict: Dict[str, Any],
+    ) -> None:
         add_multiple_columns(
-            cls, "endorse", 1, cls.NQUESTIONS,
+            cls,
+            "endorse",
+            1,
+            cls.NQUESTIONS,
             pv=PV.BIT,
             comment_fmt="Q{n} ({s}): endorsed? (0 no, 1 yes)",
-            comment_strings=QUESTION_SNIPPETS
+            comment_strings=QUESTION_SNIPPETS,
         )
         add_multiple_columns(
-            cls, "distress", 1, cls.NQUESTIONS,
-            minimum=1, maximum=5,
+            cls,
+            "distress",
+            1,
+            cls.NQUESTIONS,
+            minimum=1,
+            maximum=5,
             comment_fmt="Q{n} ({s}): distress (1 low - 5 high), if endorsed",
-            comment_strings=QUESTION_SNIPPETS
+            comment_strings=QUESTION_SNIPPETS,
         )
         add_multiple_columns(
-            cls, "intrusiveness", 1, cls.NQUESTIONS,
-            minimum=1, maximum=5,
+            cls,
+            "intrusiveness",
+            1,
+            cls.NQUESTIONS,
+            minimum=1,
+            maximum=5,
             comment_fmt="Q{n} ({s}): intrusiveness (1 low - 5 high), "
-                        "if endorsed",
-            comment_strings=QUESTION_SNIPPETS
+            "if endorsed",
+            comment_strings=QUESTION_SNIPPETS,
         )
         add_multiple_columns(
-            cls, "frequency", 1, cls.NQUESTIONS,
-            minimum=1, maximum=5,
+            cls,
+            "frequency",
+            1,
+            cls.NQUESTIONS,
+            minimum=1,
+            maximum=5,
             comment_fmt="Q{n} ({s}): frequency (1 low - 5 high), if endorsed",
-            comment_strings=QUESTION_SNIPPETS
+            comment_strings=QUESTION_SNIPPETS,
         )
         super().__init__(name, bases, classdict)
 
 
-class Caps(TaskHasPatientMixin, Task,
-           metaclass=CapsMetaclass):
+class Caps(TaskHasPatientMixin, Task, metaclass=CapsMetaclass):
     """
     Server implementation of the CAPS task.
     """
+
     __tablename__ = "caps"
     shortname = "CAPS"
     provides_trackers = True
@@ -125,32 +159,42 @@ class Caps(TaskHasPatientMixin, Task,
         return _("Cardiff Anomalous Perceptions Scale")
 
     def get_trackers(self, req: CamcopsRequest) -> List[TrackerInfo]:
-        return [TrackerInfo(
-            value=self.total_score(),
-            plot_label="CAPS total score",
-            axis_label="Total score (out of 32)",
-            axis_min=-0.5,
-            axis_max=32.5
-        )]
+        return [
+            TrackerInfo(
+                value=self.total_score(),
+                plot_label="CAPS total score",
+                axis_label="Total score (out of 32)",
+                axis_min=-0.5,
+                axis_max=32.5,
+            )
+        ]
 
     def get_summaries(self, req: CamcopsRequest) -> List[SummaryElement]:
         return self.standard_task_summary_fields() + [
             SummaryElement(
-                name="total", coltype=Integer(),
+                name="total",
+                coltype=Integer(),
                 value=self.total_score(),
-                comment="Total score (/32)"),
+                comment="Total score (/32)",
+            ),
             SummaryElement(
-                name="distress", coltype=Integer(),
+                name="distress",
+                coltype=Integer(),
                 value=self.distress_score(),
-                comment="Distress score (/160)"),
+                comment="Distress score (/160)",
+            ),
             SummaryElement(
-                name="intrusiveness", coltype=Integer(),
+                name="intrusiveness",
+                coltype=Integer(),
                 value=self.intrusiveness_score(),
-                comment="Intrusiveness score (/160)"),
+                comment="Intrusiveness score (/160)",
+            ),
             SummaryElement(
-                name="frequency", coltype=Integer(),
+                name="frequency",
+                coltype=Integer(),
                 value=self.frequency_score(),
-                comment="Frequency score (/160)"),
+                comment="Frequency score (/160)",
+            ),
         ]
 
     def is_question_complete(self, q: int) -> bool:
@@ -179,24 +223,30 @@ class Caps(TaskHasPatientMixin, Task,
     def distress_score(self) -> int:
         score = 0
         for q in range(1, Caps.NQUESTIONS + 1):
-            if getattr(self, "endorse" + str(q)) \
-                    and getattr(self, "distress" + str(q)) is not None:
+            if (
+                getattr(self, "endorse" + str(q))
+                and getattr(self, "distress" + str(q)) is not None
+            ):
                 score += self.sum_fields(["distress" + str(q)])
         return score
 
     def intrusiveness_score(self) -> int:
         score = 0
         for q in range(1, Caps.NQUESTIONS + 1):
-            if getattr(self, "endorse" + str(q)) \
-                    and getattr(self, "intrusiveness" + str(q)) is not None:
+            if (
+                getattr(self, "endorse" + str(q))
+                and getattr(self, "intrusiveness" + str(q)) is not None
+            ):
                 score += self.sum_fields(["intrusiveness" + str(q)])
         return score
 
     def frequency_score(self) -> int:
         score = 0
         for q in range(1, Caps.NQUESTIONS + 1):
-            if getattr(self, "endorse" + str(q)) \
-                    and getattr(self, "frequency" + str(q)) is not None:
+            if (
+                getattr(self, "endorse" + str(q))
+                and getattr(self, "frequency" + str(q)) is not None
+            ):
                 score += self.sum_fields(["frequency" + str(q)])
         return score
 
@@ -210,31 +260,42 @@ class Caps(TaskHasPatientMixin, Task,
         for q in range(1, Caps.NQUESTIONS + 1):
             q_a += tr(
                 self.wxstring(req, "q" + str(q)),
-                answer(get_yes_no_none(req,
-                                       getattr(self, "endorse" + str(q)))),
-                answer(getattr(self, "distress" + str(q))
-                       if getattr(self, "endorse" + str(q)) else ""),
-                answer(getattr(self, "intrusiveness" + str(q))
-                       if getattr(self, "endorse" + str(q)) else ""),
-                answer(getattr(self, "frequency" + str(q))
-                       if getattr(self, "endorse" + str(q)) else "")
+                answer(
+                    get_yes_no_none(req, getattr(self, "endorse" + str(q)))
+                ),
+                answer(
+                    getattr(self, "distress" + str(q))
+                    if getattr(self, "endorse" + str(q))
+                    else ""
+                ),
+                answer(
+                    getattr(self, "intrusiveness" + str(q))
+                    if getattr(self, "endorse" + str(q))
+                    else ""
+                ),
+                answer(
+                    getattr(self, "frequency" + str(q))
+                    if getattr(self, "endorse" + str(q))
+                    else ""
+                ),
             )
 
         tr_total_score = tr_qa(
-            f"{req.sstring(SS.TOTAL_SCORE)} <sup>[1]</sup> (0–32)",
-            total
+            f"{req.sstring(SS.TOTAL_SCORE)} <sup>[1]</sup> (0–32)", total
+        )
+        tr_distress = (
+            tr_qa(
+                "{} (0–160)".format(self.wxstring(req, "distress")), distress
+            ),
+        )
+        tr_intrusiveness = (
+            tr_qa(
+                "{} (0–160)".format(self.wxstring(req, "intrusiveness")),
+                intrusiveness,
+            ),
         )
-        tr_distress = tr_qa(
-            "{} (0–160)".format(self.wxstring(req, "distress")),
-            distress
-        ),
-        tr_intrusiveness = tr_qa(
-            "{} (0–160)".format(self.wxstring(req, "intrusiveness")),
-            intrusiveness
-        ),
         tr_frequency = tr_qa(
-            "{} (0–160)".format(self.wxstring(req, "frequency")),
-            frequency
+            "{} (0–160)".format(self.wxstring(req, "frequency")), frequency
         )
         return f"""
             <div class="{CssClass.SUMMARY}">
