@@ -48,10 +48,7 @@ from camcops_server.cc_modules.cc_db import (
     GenericTabletRecordMixin,
     TaskDescendant,
 )
-from camcops_server.cc_modules.cc_html import (
-    get_yes_no_none,
-    tr_qa,
-)
+from camcops_server.cc_modules.cc_html import get_yes_no_none, tr_qa
 from camcops_server.cc_modules.cc_request import CamcopsRequest
 from camcops_server.cc_modules.cc_sqla_coltypes import (
     CamcopsColumn,
@@ -79,69 +76,68 @@ DP = 3
 # CardinalExpDetThreshold
 # =============================================================================
 
-class CardinalExpDetThresholdTrial(GenericTabletRecordMixin, TaskDescendant,
-                                   Base):
+
+class CardinalExpDetThresholdTrial(
+    GenericTabletRecordMixin, TaskDescendant, Base
+):
     __tablename__ = "cardinal_expdetthreshold_trials"
 
     cardinal_expdetthreshold_id = Column(
-        "cardinal_expdetthreshold_id", Integer,
+        "cardinal_expdetthreshold_id",
+        Integer,
         nullable=False,
-        comment="FK to CardinalExpDetThreshold"
+        comment="FK to CardinalExpDetThreshold",
     )
     trial = Column(
-        "trial", Integer,
-        nullable=False,
-        comment="Trial number (0-based)"
+        "trial", Integer, nullable=False, comment="Trial number (0-based)"
     )
 
     # Results
     trial_ignoring_catch_trials = Column(
-        "trial_ignoring_catch_trials", Integer,
-        comment="Trial number, ignoring catch trials (0-based)"
+        "trial_ignoring_catch_trials",
+        Integer,
+        comment="Trial number, ignoring catch trials (0-based)",
     )
     target_presented = Column(
-        "target_presented", Integer,
-        comment="Target presented? (0 no, 1 yes)"
+        "target_presented", Integer, comment="Target presented? (0 no, 1 yes)"
     )
     target_time = Column(
-        "target_time", PendulumDateTimeAsIsoTextColType,
-        comment="Target presentation time (ISO-8601)"
+        "target_time",
+        PendulumDateTimeAsIsoTextColType,
+        comment="Target presentation time (ISO-8601)",
     )
     intensity = Column(
-        "intensity", Float,
-        comment="Target intensity (0.0-1.0)"
+        "intensity", Float, comment="Target intensity (0.0-1.0)"
     )
     choice_time = Column(
-        "choice_time", PendulumDateTimeAsIsoTextColType,
-        comment="Time choice offered (ISO-8601)"
+        "choice_time",
+        PendulumDateTimeAsIsoTextColType,
+        comment="Time choice offered (ISO-8601)",
     )
     responded = Column(
-        "responded", Integer,
-        comment="Responded? (0 no, 1 yes)"
+        "responded", Integer, comment="Responded? (0 no, 1 yes)"
     )
     response_time = Column(
-        "response_time", PendulumDateTimeAsIsoTextColType,
-        comment="Time of response (ISO-8601)"
+        "response_time",
+        PendulumDateTimeAsIsoTextColType,
+        comment="Time of response (ISO-8601)",
     )
     response_latency_ms = Column(
-        "response_latency_ms", Integer,
-        comment="Response latency (ms)"
+        "response_latency_ms", Integer, comment="Response latency (ms)"
     )
     yes = Column(
-        "yes", Integer,
-        comment="Subject chose YES? (0 didn't, 1 did)"
-    )
-    no = Column(
-        "no", Integer,
-        comment="Subject chose NO? (0 didn't, 1 did)"
+        "yes", Integer, comment="Subject chose YES? (0 didn't, 1 did)"
     )
+    no = Column("no", Integer, comment="Subject chose NO? (0 didn't, 1 did)")
     caught_out_reset = Column(
-        "caught_out_reset", Integer,
-        comment="Caught out on catch trial, thus reset? (0 no, 1 yes)"
+        "caught_out_reset",
+        Integer,
+        comment="Caught out on catch trial, thus reset? (0 no, 1 yes)",
     )
     trial_num_in_calculation_sequence = Column(
-        "trial_num_in_calculation_sequence", Integer,
-        comment="Trial number as used for threshold calculation"
+        "trial_num_in_calculation_sequence",
+        Integer,
+        comment="Trial number as used for threshold calculation",
     )
 
     @classmethod
@@ -179,7 +175,7 @@ class CardinalExpDetThresholdTrial(GenericTabletRecordMixin, TaskDescendant,
             self.yes,
             self.no,
             ws.webify(self.caught_out_reset),
-            ws.webify(self.trial_num_in_calculation_sequence)
+            ws.webify(self.trial_num_in_calculation_sequence),
         )
 
     # -------------------------------------------------------------------------
@@ -192,98 +188,97 @@ class CardinalExpDetThresholdTrial(GenericTabletRecordMixin, TaskDescendant,
 
     def task_ancestor(self) -> Optional["CardinalExpDetThreshold"]:
         return CardinalExpDetThreshold.get_linked(
-            self.cardinal_expdetthreshold_id, self)
+            self.cardinal_expdetthreshold_id, self
+        )
 
 
 class CardinalExpDetThreshold(TaskHasPatientMixin, Task):
     """
     Server implementation of the Cardinal_ExpDetThreshold task.
     """
+
     __tablename__ = "cardinal_expdetthreshold"
     shortname = "Cardinal_ExpDetThreshold"
     use_landscape_for_pdf = True
 
     # Config
     modality = Column(
-        "modality", Integer,
-        comment="Modality (0 auditory, 1 visual)"
+        "modality", Integer, comment="Modality (0 auditory, 1 visual)"
     )
     target_number = Column(
-        "target_number", Integer,
-        comment="Target number (within available targets of that modality)"
+        "target_number",
+        Integer,
+        comment="Target number (within available targets of that modality)",
     )
     background_filename = CamcopsColumn(
-        "background_filename", Text,
+        "background_filename",
+        Text,
         exempt_from_anonymisation=True,
-        comment="Filename of media used for background"
+        comment="Filename of media used for background",
     )
     target_filename = CamcopsColumn(
-        "target_filename", Text,
+        "target_filename",
+        Text,
         exempt_from_anonymisation=True,
-        comment="Filename of media used for target"
+        comment="Filename of media used for target",
     )
     visual_target_duration_s = Column(
-        "visual_target_duration_s", Float,
-        comment="Visual target duration (s)"
+        "visual_target_duration_s", Float, comment="Visual target duration (s)"
     )
     background_intensity = Column(
-        "background_intensity", Float,
-        comment="Intensity of background (0.0-1.0)"
+        "background_intensity",
+        Float,
+        comment="Intensity of background (0.0-1.0)",
     )
     start_intensity_min = Column(
-        "start_intensity_min", Float,
-        comment="Minimum starting intensity (0.0-1.0)"
+        "start_intensity_min",
+        Float,
+        comment="Minimum starting intensity (0.0-1.0)",
     )
     start_intensity_max = Column(
-        "start_intensity_max", Float,
-        comment="Maximum starting intensity (0.0-1.0)"
+        "start_intensity_max",
+        Float,
+        comment="Maximum starting intensity (0.0-1.0)",
     )
     initial_large_intensity_step = Column(
-        "initial_large_intensity_step", Float,
-        comment="Initial, large, intensity step (0.0-1.0)"
+        "initial_large_intensity_step",
+        Float,
+        comment="Initial, large, intensity step (0.0-1.0)",
     )
     main_small_intensity_step = Column(
-        "main_small_intensity_step", Float,
-        comment="Main, small, intensity step (0.0-1.0)"
+        "main_small_intensity_step",
+        Float,
+        comment="Main, small, intensity step (0.0-1.0)",
     )
     num_trials_in_main_sequence = Column(
-        "num_trials_in_main_sequence", Integer,
-        comment="Number of trials required in main sequence"
+        "num_trials_in_main_sequence",
+        Integer,
+        comment="Number of trials required in main sequence",
     )
     p_catch_trial = Column(
-        "p_catch_trial", Float,
-        comment="Probability of catch trial"
+        "p_catch_trial", Float, comment="Probability of catch trial"
     )
     prompt = CamcopsColumn(
-        "prompt", UnicodeText,
+        "prompt",
+        UnicodeText,
         exempt_from_anonymisation=True,
-        comment="Prompt given to subject"
-    )
-    iti_s = Column(
-        "iti_s", Float,
-        comment="Intertrial interval (s)"
+        comment="Prompt given to subject",
     )
+    iti_s = Column("iti_s", Float, comment="Intertrial interval (s)")
 
     # Results
     finished = Column(
-        "finished", Integer,
-        comment="Subject finished successfully (0 no, 1 yes)"
-    )
-    intercept = Column(
-        "intercept", Float,
-        comment=EQUATION_COMMENT
-    )
-    slope = Column(
-        "slope", Float,
-        comment=EQUATION_COMMENT
-    )
-    k = Column(
-        "k", Float,
-        comment=EQUATION_COMMENT + "; k = slope"
+        "finished",
+        Integer,
+        comment="Subject finished successfully (0 no, 1 yes)",
     )
+    intercept = Column("intercept", Float, comment=EQUATION_COMMENT)
+    slope = Column("slope", Float, comment=EQUATION_COMMENT)
+    k = Column("k", Float, comment=EQUATION_COMMENT + "; k = slope")
     theta = Column(
-        "theta", Float,
-        comment=EQUATION_COMMENT + "; theta = -intercept/k = -intercept/slope"
+        "theta",
+        Float,
+        comment=EQUATION_COMMENT + "; theta = -intercept/k = -intercept/slope",
     )
 
     # Relationships
@@ -291,20 +286,23 @@ class CardinalExpDetThreshold(TaskHasPatientMixin, Task):
         parent_class_name="CardinalExpDetThreshold",
         ancillary_class_name="CardinalExpDetThresholdTrial",
         ancillary_fk_to_parent_attr_name="cardinal_expdetthreshold_id",
-        ancillary_order_by_attr_name="trial"
+        ancillary_order_by_attr_name="trial",
     )  # type: List[CardinalExpDetThresholdTrial]
 
     @staticmethod
     def longname(req: "CamcopsRequest") -> str:
         _ = req.gettext
-        return _("Cardinal RN – Threshold determination for "
-                 "Expectation–Detection task")
+        return _(
+            "Cardinal RN – Threshold determination for "
+            "Expectation–Detection task"
+        )
 
     def is_complete(self) -> bool:
         return bool(self.finished)
 
-    def _get_figures(self,
-                     req: CamcopsRequest) -> Tuple[Figure, Optional[Figure]]:
+    def _get_figures(
+        self, req: CamcopsRequest
+    ) -> Tuple[Figure, Optional[Figure]]:
         """
         Create and return figures. Returns ``trialfig, fitfig``.
         """
@@ -317,7 +315,7 @@ class CardinalExpDetThreshold(TaskHasPatientMixin, Task):
         x_extra_space = 0.02
         figsize = (
             PlotDefaults.FULLWIDTH_PLOT_WIDTH / 2,
-            PlotDefaults.FULLWIDTH_PLOT_WIDTH / 2
+            PlotDefaults.FULLWIDTH_PLOT_WIDTH / 2,
         )
 
         # Figure and axes
@@ -373,53 +371,60 @@ class CardinalExpDetThreshold(TaskHasPatientMixin, Task):
 
         # Create trialfig plots
         trialax.plot(
-            all_x, all_y,
+            all_x,
+            all_y,
             marker=MatplotlibConstants.MARKER_NONE,
             color=MatplotlibConstants.COLOUR_GREY_50,
             linestyle=MatplotlibConstants.LINESTYLE_SOLID,
-            label=None
+            label=None,
         )
         trialax.plot(
-            notcalc_missed_x, notcalc_missed_y,
+            notcalc_missed_x,
+            notcalc_missed_y,
             marker=MatplotlibConstants.MARKER_CIRCLE,
             color=MatplotlibConstants.COLOUR_BLACK,
             linestyle=MatplotlibConstants.LINESTYLE_NONE,
-            label="miss"
+            label="miss",
         )
         trialax.plot(
-            notcalc_detected_x, notcalc_detected_y,
+            notcalc_detected_x,
+            notcalc_detected_y,
             marker=MatplotlibConstants.MARKER_PLUS,
             color=MatplotlibConstants.COLOUR_BLACK,
             linestyle=MatplotlibConstants.LINESTYLE_NONE,
-            label="hit"
+            label="hit",
         )
         trialax.plot(
-            calc_missed_x, calc_missed_y,
+            calc_missed_x,
+            calc_missed_y,
             marker=MatplotlibConstants.MARKER_CIRCLE,
             color=MatplotlibConstants.COLOUR_RED,
             linestyle=MatplotlibConstants.LINESTYLE_NONE,
-            label="miss, scored"
+            label="miss, scored",
         )
         trialax.plot(
-            calc_detected_x, calc_detected_y,
+            calc_detected_x,
+            calc_detected_y,
             marker=MatplotlibConstants.MARKER_PLUS,
             color=MatplotlibConstants.COLOUR_BLUE,
             linestyle=MatplotlibConstants.LINESTYLE_NONE,
-            label="hit, scored"
+            label="hit, scored",
         )
         trialax.plot(
-            catch_missed_x, catch_missed_y,
+            catch_missed_x,
+            catch_missed_y,
             marker=MatplotlibConstants.MARKER_CIRCLE,
             color=MatplotlibConstants.COLOUR_GREEN,
             linestyle=MatplotlibConstants.LINESTYLE_NONE,
-            label="CR"
+            label="CR",
         )
         trialax.plot(
-            catch_detected_x, catch_detected_y,
+            catch_detected_x,
+            catch_detected_y,
             marker=MatplotlibConstants.MARKER_STAR,
             color=MatplotlibConstants.COLOUR_GREEN,
             linestyle=MatplotlibConstants.LINESTYLE_NONE,
-            label="FA"
+            label="FA",
         )
         leg = trialax.legend(
             numpoints=1,
@@ -427,7 +432,7 @@ class CardinalExpDetThreshold(TaskHasPatientMixin, Task):
             loc="best",  # bbox_to_anchor=(0.75, 1.05)
             labelspacing=0,
             handletextpad=0,
-            prop=req.fontprops
+            prop=req.fontprops,
         )
         leg.get_frame().set_alpha(0.5)
         trialax.set_xlabel("Trial number (0-based)", fontdict=req.fontdict)
@@ -453,16 +458,17 @@ class CardinalExpDetThreshold(TaskHasPatientMixin, Task):
         for t in trialarray:
             if t.trial_num_in_calculation_sequence is not None:
                 all_x.append(t.intensity)
-                approx_x = f"{t.intensity:.{dp_to_consider_same_for_jitter}f}"  # noqa
+                approx_x = f"{t.intensity:.{dp_to_consider_same_for_jitter}f}"
                 if t.yes:
                     detected_y.append(
-                        1 -
-                        detected_x_approx.count(approx_x) * jitter_step)
+                        1 - detected_x_approx.count(approx_x) * jitter_step
+                    )
                     detected_x.append(t.intensity)
                     detected_x_approx.append(approx_x)
                 else:
                     missed_y.append(
-                        0 + missed_x_approx.count(approx_x) * jitter_step)
+                        0 + missed_x_approx.count(approx_x) * jitter_step
+                    )
                     missed_x.append(t.intensity)
                     missed_x_approx.append(approx_x)
 
@@ -473,25 +479,29 @@ class CardinalExpDetThreshold(TaskHasPatientMixin, Task):
         fit_x = np.arange(0.0 - x_extra_space, 1.0 + x_extra_space, 0.001)
         fit_y = logistic(fit_x, self.k, self.theta)
         fitax.plot(
-            fit_x, fit_y,
+            fit_x,
+            fit_y,
             color=MatplotlibConstants.COLOUR_GREEN,
-            linestyle=MatplotlibConstants.LINESTYLE_SOLID
+            linestyle=MatplotlibConstants.LINESTYLE_SOLID,
         )
         fitax.plot(
-            missed_x, missed_y,
+            missed_x,
+            missed_y,
             marker=MatplotlibConstants.MARKER_CIRCLE,
             color=MatplotlibConstants.COLOUR_RED,
-            linestyle=MatplotlibConstants.LINESTYLE_NONE
+            linestyle=MatplotlibConstants.LINESTYLE_NONE,
         )
         fitax.plot(
-            detected_x, detected_y,
+            detected_x,
+            detected_y,
             marker=MatplotlibConstants.MARKER_PLUS,
             color=MatplotlibConstants.COLOUR_BLUE,
-            linestyle=MatplotlibConstants.LINESTYLE_NONE
+            linestyle=MatplotlibConstants.LINESTYLE_NONE,
         )
         fitax.set_ylim(0 - y_extra_space, 1 + y_extra_space)
-        fitax.set_xlim(np.amin(all_x) - x_extra_space,
-                       np.amax(all_x) + x_extra_space)
+        fitax.set_xlim(
+            np.amin(all_x) - x_extra_space, np.amax(all_x) + x_extra_space
+        )
         marker_points = []
         for y in (LOWER_MARKER, 0.5, UPPER_MARKER):
             x = inv_logistic(y, self.k, self.theta)
@@ -501,17 +511,18 @@ class CardinalExpDetThreshold(TaskHasPatientMixin, Task):
                 [p[0], p[0]],  # x
                 [-1, p[1]],  # y
                 color=MatplotlibConstants.COLOUR_GREY_50,
-                linestyle=MatplotlibConstants.LINESTYLE_DOTTED
+                linestyle=MatplotlibConstants.LINESTYLE_DOTTED,
             )
             fitax.plot(
                 [-1, p[0]],  # x
                 [p[1], p[1]],  # y
                 color=MatplotlibConstants.COLOUR_GREY_50,
-                linestyle=MatplotlibConstants.LINESTYLE_DOTTED
+                linestyle=MatplotlibConstants.LINESTYLE_DOTTED,
             )
         fitax.set_xlabel("Intensity", fontdict=req.fontdict)
-        fitax.set_ylabel("Detected? (0=no, 1=yes; jittered)",
-                         fontdict=req.fontdict)
+        fitax.set_ylabel(
+            "Detected? (0=no, 1=yes; jittered)", fontdict=req.fontdict
+        )
         req.set_figure_font_sizes(fitax)
 
         # Done
@@ -601,16 +612,22 @@ class CardinalExpDetThreshold(TaskHasPatientMixin, Task):
         h += tr_qa("Background filename", ws.webify(self.background_filename))
         h += tr_qa("Background intensity", self.background_intensity)
         h += tr_qa("Target filename", ws.webify(self.target_filename))
-        h += tr_qa("(For visual targets) Target duration (s)",
-                   self.visual_target_duration_s)
+        h += tr_qa(
+            "(For visual targets) Target duration (s)",
+            self.visual_target_duration_s,
+        )
         h += tr_qa("Start intensity (minimum)", self.start_intensity_min)
         h += tr_qa("Start intensity (maximum)", self.start_intensity_max)
-        h += tr_qa("Initial (large) intensity step",
-                   self.initial_large_intensity_step)
-        h += tr_qa("Main (small) intensity step",
-                   self.main_small_intensity_step)
-        h += tr_qa("Number of trials in main sequence",
-                   self.num_trials_in_main_sequence)
+        h += tr_qa(
+            "Initial (large) intensity step", self.initial_large_intensity_step
+        )
+        h += tr_qa(
+            "Main (small) intensity step", self.main_small_intensity_step
+        )
+        h += tr_qa(
+            "Number of trials in main sequence",
+            self.num_trials_in_main_sequence,
+        )
         h += tr_qa("Probability of a catch trial", self.p_catch_trial)
         h += tr_qa("Prompt", self.prompt)
         h += tr_qa("Intertrial interval (ITI) (s)", self.iti_s)
@@ -620,22 +637,24 @@ class CardinalExpDetThreshold(TaskHasPatientMixin, Task):
                 <tr><th width="50%">Measure</th><th width="50%">Value</th></tr>
         """
         h += tr_qa("Finished?", get_yes_no_none(req, self.finished))
-        h += tr_qa("Logistic intercept",
-                   ws.number_to_dp(self.intercept,
-                                   DP))
-        h += tr_qa("Logistic slope",
-                   ws.number_to_dp(self.slope, DP))
-        h += tr_qa("Logistic k (= slope)",
-                   ws.number_to_dp(self.k, DP))
-        h += tr_qa("Logistic theta (= –intercept/slope)",
-                   ws.number_to_dp(self.theta, DP))
-        h += tr_qa(f"Intensity for {100 * LOWER_MARKER}% detection",
-                   ws.number_to_dp(self.logistic_x_from_p(LOWER_MARKER),
-                                   DP))
-        h += tr_qa("Intensity for 50% detection",
-                   ws.number_to_dp(self.theta, DP))
-        h += tr_qa(f"Intensity for {100 * UPPER_MARKER}% detection",
-                   ws.number_to_dp(self.logistic_x_from_p(UPPER_MARKER), DP))
+        h += tr_qa("Logistic intercept", ws.number_to_dp(self.intercept, DP))
+        h += tr_qa("Logistic slope", ws.number_to_dp(self.slope, DP))
+        h += tr_qa("Logistic k (= slope)", ws.number_to_dp(self.k, DP))
+        h += tr_qa(
+            "Logistic theta (= –intercept/slope)",
+            ws.number_to_dp(self.theta, DP),
+        )
+        h += tr_qa(
+            f"Intensity for {100 * LOWER_MARKER}% detection",
+            ws.number_to_dp(self.logistic_x_from_p(LOWER_MARKER), DP),
+        )
+        h += tr_qa(
+            "Intensity for 50% detection", ws.number_to_dp(self.theta, DP)
+        )
+        h += tr_qa(
+            f"Intensity for {100 * UPPER_MARKER}% detection",
+            ws.number_to_dp(self.logistic_x_from_p(UPPER_MARKER), DP),
+        )
         h += """
             </table>
         """
