@@ -69,30 +69,45 @@ from camcops_server.cc_modules.cc_trackerhelpers import (
 # CIWA
 # =============================================================================
 
+
 class CiwaMetaclass(DeclarativeMeta):
     # noinspection PyInitNewSignature
-    def __init__(cls: Type['Ciwa'],
-                 name: str,
-                 bases: Tuple[Type, ...],
-                 classdict: Dict[str, Any]) -> None:
+    def __init__(
+        cls: Type["Ciwa"],
+        name: str,
+        bases: Tuple[Type, ...],
+        classdict: Dict[str, Any],
+    ) -> None:
         add_multiple_columns(
-            cls, "q", 1, cls.NSCOREDQUESTIONS - 1,
-            minimum=0, maximum=7,
+            cls,
+            "q",
+            1,
+            cls.NSCOREDQUESTIONS - 1,
+            minimum=0,
+            maximum=7,
             comment_fmt="Q{n}, {s} (0-7, higher worse)",
             comment_strings=[
-                "nausea/vomiting", "tremor", "paroxysmal sweats", "anxiety",
-                "agitation", "tactile disturbances", "auditory disturbances",
-                "visual disturbances", "headache/fullness in head"
-            ]
+                "nausea/vomiting",
+                "tremor",
+                "paroxysmal sweats",
+                "anxiety",
+                "agitation",
+                "tactile disturbances",
+                "auditory disturbances",
+                "visual disturbances",
+                "headache/fullness in head",
+            ],
         )
         super().__init__(name, bases, classdict)
 
 
-class Ciwa(TaskHasPatientMixin, TaskHasClinicianMixin, Task,
-           metaclass=CiwaMetaclass):
+class Ciwa(
+    TaskHasPatientMixin, TaskHasClinicianMixin, Task, metaclass=CiwaMetaclass
+):
     """
     Server implementation of the CIWA-Ar task.
     """
+
     __tablename__ = "ciwa"
     shortname = "CIWA-Ar"
     provides_trackers = True
@@ -101,33 +116,35 @@ class Ciwa(TaskHasPatientMixin, TaskHasClinicianMixin, Task,
     SCORED_QUESTIONS = strseq("q", 1, NSCOREDQUESTIONS)
 
     q10 = CamcopsColumn(
-        "q10", Integer,
+        "q10",
+        Integer,
         permitted_value_checker=PermittedValueChecker(minimum=0, maximum=4),
-        comment="Q10, orientation/clouding of sensorium (0-4, higher worse)"
-    )
-    t = Column(
-        "t", Float,
-        comment="Temperature (degrees C)"
+        comment="Q10, orientation/clouding of sensorium (0-4, higher worse)",
     )
+    t = Column("t", Float, comment="Temperature (degrees C)")
     hr = CamcopsColumn(
-        "hr", Integer,
+        "hr",
+        Integer,
         permitted_value_checker=MIN_ZERO_CHECKER,
-        comment="Heart rate (beats/minute)"
+        comment="Heart rate (beats/minute)",
     )
     sbp = CamcopsColumn(
-        "sbp", Integer,
+        "sbp",
+        Integer,
         permitted_value_checker=MIN_ZERO_CHECKER,
-        comment="Systolic blood pressure (mmHg)"
+        comment="Systolic blood pressure (mmHg)",
     )
     dbp = CamcopsColumn(
-        "dbp", Integer,
+        "dbp",
+        Integer,
         permitted_value_checker=MIN_ZERO_CHECKER,
-        comment="Diastolic blood pressure (mmHg)"
+        comment="Diastolic blood pressure (mmHg)",
     )
     rr = CamcopsColumn(
-        "rr", Integer,
+        "rr",
+        Integer,
         permitted_value_checker=MIN_ZERO_CHECKER,
-        comment="Respiratory rate (breaths/minute)"
+        comment="Respiratory rate (breaths/minute)",
     )
 
     MAX_SCORE = 67
@@ -135,46 +152,59 @@ class Ciwa(TaskHasPatientMixin, TaskHasClinicianMixin, Task,
     @staticmethod
     def longname(req: "CamcopsRequest") -> str:
         _ = req.gettext
-        return _("Clinical Institute Withdrawal Assessment for Alcohol "
-                 "Scale, Revised")
+        return _(
+            "Clinical Institute Withdrawal Assessment for Alcohol "
+            "Scale, Revised"
+        )
 
     def get_trackers(self, req: CamcopsRequest) -> List[TrackerInfo]:
-        return [TrackerInfo(
-            value=self.total_score(),
-            plot_label="CIWA total score",
-            axis_label=f"Total score (out of {self.MAX_SCORE})",
-            axis_min=-0.5,
-            axis_max=self.MAX_SCORE + 0.5,
-            horizontal_lines=[14.5, 7.5],
-            horizontal_labels=[
-                TrackerLabel(17, req.sstring(SS.SEVERE)),
-                TrackerLabel(11, req.sstring(SS.MODERATE)),
-                TrackerLabel(3.75, req.sstring(SS.MILD)),
-            ]
-        )]
+        return [
+            TrackerInfo(
+                value=self.total_score(),
+                plot_label="CIWA total score",
+                axis_label=f"Total score (out of {self.MAX_SCORE})",
+                axis_min=-0.5,
+                axis_max=self.MAX_SCORE + 0.5,
+                horizontal_lines=[14.5, 7.5],
+                horizontal_labels=[
+                    TrackerLabel(17, req.sstring(SS.SEVERE)),
+                    TrackerLabel(11, req.sstring(SS.MODERATE)),
+                    TrackerLabel(3.75, req.sstring(SS.MILD)),
+                ],
+            )
+        ]
 
     def get_clinical_text(self, req: CamcopsRequest) -> List[CtvInfo]:
         if not self.is_complete():
             return CTV_INCOMPLETE
-        return [CtvInfo(
-            content=f"CIWA total score: {self.total_score()}/{self.MAX_SCORE}"
-        )]
+        return [
+            CtvInfo(
+                content=f"CIWA total score: "
+                f"{self.total_score()}/{self.MAX_SCORE}"
+            )
+        ]
 
     def get_summaries(self, req: CamcopsRequest) -> List[SummaryElement]:
         return self.standard_task_summary_fields() + [
-            SummaryElement(name="total",
-                           coltype=Integer(),
-                           value=self.total_score(),
-                           comment=f"Total score (/{self.MAX_SCORE})"),
-            SummaryElement(name="severity",
-                           coltype=SummaryCategoryColType,
-                           value=self.severity(req),
-                           comment="Likely severity"),
+            SummaryElement(
+                name="total",
+                coltype=Integer(),
+                value=self.total_score(),
+                comment=f"Total score (/{self.MAX_SCORE})",
+            ),
+            SummaryElement(
+                name="severity",
+                coltype=SummaryCategoryColType,
+                value=self.severity(req),
+                comment="Likely severity",
+            ),
         ]
 
     def is_complete(self) -> bool:
-        return (self.all_fields_not_none(self.SCORED_QUESTIONS) and
-                self.field_contents_valid())
+        return (
+            self.all_fields_not_none(self.SCORED_QUESTIONS)
+            and self.field_contents_valid()
+        )
 
     def total_score(self) -> int:
         return self.sum_fields(self.SCORED_QUESTIONS)
@@ -204,16 +234,16 @@ class Ciwa(TaskHasPatientMixin, TaskHasClinicianMixin, Task,
         for q in range(1, Ciwa.NSCOREDQUESTIONS + 1):
             q_a += tr_qa(
                 self.wxstring(req, "q" + str(q) + "_s"),
-                get_from_dict(answer_dicts_dict["q" + str(q)],
-                              getattr(self, "q" + str(q)))
+                get_from_dict(
+                    answer_dicts_dict["q" + str(q)],
+                    getattr(self, "q" + str(q)),
+                ),
             )
         tr_total_score = tr(
-            req.sstring(SS.TOTAL_SCORE),
-            answer(score) + f" / {self.MAX_SCORE}"
+            req.sstring(SS.TOTAL_SCORE), answer(score) + f" / {self.MAX_SCORE}"
         )
         tr_severity = tr_qa(
-            self.wxstring(req, "severity") + " <sup>[1]</sup>",
-            severity
+            self.wxstring(req, "severity") + " <sup>[1]</sup>", severity
         )
         return f"""
             <div class="{CssClass.SUMMARY}">
@@ -244,12 +274,20 @@ class Ciwa(TaskHasPatientMixin, TaskHasClinicianMixin, Task,
         """
 
     def get_snomed_codes(self, req: CamcopsRequest) -> List[SnomedExpression]:
-        codes = [SnomedExpression(req.snomed(SnomedLookup.CIWA_AR_PROCEDURE_ASSESSMENT))]  # noqa
+        codes = [
+            SnomedExpression(
+                req.snomed(SnomedLookup.CIWA_AR_PROCEDURE_ASSESSMENT)
+            )
+        ]
         if self.is_complete():
-            codes.append(SnomedExpression(
-                req.snomed(SnomedLookup.CIWA_AR_SCALE),
-                {
-                    req.snomed(SnomedLookup.CIWA_AR_SCORE): self.total_score(),
-                }
-            ))
+            codes.append(
+                SnomedExpression(
+                    req.snomed(SnomedLookup.CIWA_AR_SCALE),
+                    {
+                        req.snomed(
+                            SnomedLookup.CIWA_AR_SCORE
+                        ): self.total_score()
+                    },
+                )
+            )
         return codes
