@@ -54,14 +54,20 @@ from camcops_server.cc_modules.cc_task import Task, TaskHasPatientMixin
 # Distress Thermometer
 # =============================================================================
 
+
 class DistressThermometerMetaclass(DeclarativeMeta):
     # noinspection PyInitNewSignature
-    def __init__(cls: Type['DistressThermometer'],
-                 name: str,
-                 bases: Tuple[Type, ...],
-                 classdict: Dict[str, Any]) -> None:
+    def __init__(
+        cls: Type["DistressThermometer"],
+        name: str,
+        bases: Tuple[Type, ...],
+        classdict: Dict[str, Any],
+    ) -> None:
         add_multiple_columns(
-            cls, "q", 1, cls.NQUESTIONS,
+            cls,
+            "q",
+            1,
+            cls.NQUESTIONS,
             pv=PV.BIT,
             comment_fmt="{n}. {s} (0 no, 1 yes)",
             comment_strings=[
@@ -101,23 +107,26 @@ class DistressThermometerMetaclass(DeclarativeMeta):
                 "skin dry/itchy",
                 "sleep",
                 "tingling in hands/feet",
-            ]
+            ],
         )
         super().__init__(name, bases, classdict)
 
 
-class DistressThermometer(TaskHasPatientMixin, Task,
-                          metaclass=DistressThermometerMetaclass):
+class DistressThermometer(
+    TaskHasPatientMixin, Task, metaclass=DistressThermometerMetaclass
+):
     """
     Server implementation of the DistressThermometer task.
     """
+
     __tablename__ = "distressthermometer"
     shortname = "Distress Thermometer"
 
     distress = CamcopsColumn(
-        "distress", Integer,
+        "distress",
+        Integer,
         permitted_value_checker=PermittedValueChecker(minimum=0, maximum=10),
-        comment="Distress (0 none - 10 extreme)"
+        comment="Distress (0 none - 10 extreme)",
     )
     other = Column("other", UnicodeText, comment="Other problems")
 
@@ -132,14 +141,12 @@ class DistressThermometer(TaskHasPatientMixin, Task,
     def get_clinical_text(self, req: CamcopsRequest) -> List[CtvInfo]:
         if self.distress is None:
             return CTV_INCOMPLETE
-        return [CtvInfo(
-            content=f"Overall distress: {self.distress}/10"
-        )]
+        return [CtvInfo(content=f"Overall distress: {self.distress}/10")]
 
     def is_complete(self) -> bool:
         return (
-            self.all_fields_not_none(self.COMPLETENESS_FIELDS) and
-            self.field_contents_valid()
+            self.all_fields_not_none(self.COMPLETENESS_FIELDS)
+            and self.field_contents_valid()
         )
 
     def get_task_html(self, req: CamcopsRequest) -> str:
@@ -160,37 +167,38 @@ class DistressThermometer(TaskHasPatientMixin, Task,
                     <th width="50%">Answer</th>
                 </tr>
         """
-        h += tr_qa("Distress (0 no distress – 10 extreme distress)",
-                   self.distress)
+        h += tr_qa(
+            "Distress (0 no distress – 10 extreme distress)", self.distress
+        )
         h += subheading_spanning_two_columns("Practical problems")
         for i in range(1, 5 + 1):
             h += tr_qa(
                 f"{i}. {self.wxstring(req, 'q' + str(i))}",
-                get_yes_no_none(req, getattr(self, "q" + str(i)))
+                get_yes_no_none(req, getattr(self, "q" + str(i))),
             )
         h += subheading_spanning_two_columns("Family problems")
         for i in range(6, 8 + 1):
             h += tr_qa(
                 f"{i}. {self.wxstring(req, 'q' + str(i))}",
-                get_yes_no_none(req, getattr(self, "q" + str(i)))
+                get_yes_no_none(req, getattr(self, "q" + str(i))),
             )
         h += subheading_spanning_two_columns("Emotional problems")
         for i in range(9, 14 + 1):
             h += tr_qa(
                 f"{i}. {self.wxstring(req, 'q' + str(i))}",
-                get_yes_no_none(req, getattr(self, "q" + str(i)))
+                get_yes_no_none(req, getattr(self, "q" + str(i))),
             )
         h += subheading_spanning_two_columns("Spiritual problems")
         for i in range(15, 15 + 1):
             h += tr_qa(
                 f"{i}. {self.wxstring(req, 'q' + str(i))}",
-                get_yes_no_none(req, getattr(self, "q" + str(i)))
+                get_yes_no_none(req, getattr(self, "q" + str(i))),
             )
         h += subheading_spanning_two_columns("Physical problems")
         for i in range(16, self.NQUESTIONS + 1):
             h += tr_qa(
                 f"{i}. {self.wxstring(req, 'q' + str(i))}",
-                get_yes_no_none(req, getattr(self, "q" + str(i)))
+                get_yes_no_none(req, getattr(self, "q" + str(i))),
             )
         h += subheading_spanning_two_columns("Other problems")
         h += tr_qa(self.wxstring(req, "other_s"), self.other)
