@@ -57,32 +57,50 @@ from camcops_server.cc_modules.cc_trackerhelpers import (
 # HAM-A
 # =============================================================================
 
+
 class HamaMetaclass(DeclarativeMeta):
     # noinspection PyInitNewSignature
-    def __init__(cls: Type['Hama'],
-                 name: str,
-                 bases: Tuple[Type, ...],
-                 classdict: Dict[str, Any]) -> None:
+    def __init__(
+        cls: Type["Hama"],
+        name: str,
+        bases: Tuple[Type, ...],
+        classdict: Dict[str, Any],
+    ) -> None:
         add_multiple_columns(
-            cls, "q", 1, cls.NQUESTIONS,
+            cls,
+            "q",
+            1,
+            cls.NQUESTIONS,
             comment_fmt="Q{n}, {s} (0-4, higher worse)",
-            minimum=0, maximum=4,
+            minimum=0,
+            maximum=4,
             comment_strings=[
-                "anxious mood", "tension", "fears", "insomnia",
-                "concentration/memory", "depressed mood", "somatic, muscular",
-                "somatic, sensory", "cardiovascular", "respiratory",
-                "gastrointestinal", "genitourinary", "other autonomic",
-                "behaviour in interview"
-            ]
+                "anxious mood",
+                "tension",
+                "fears",
+                "insomnia",
+                "concentration/memory",
+                "depressed mood",
+                "somatic, muscular",
+                "somatic, sensory",
+                "cardiovascular",
+                "respiratory",
+                "gastrointestinal",
+                "genitourinary",
+                "other autonomic",
+                "behaviour in interview",
+            ],
         )
         super().__init__(name, bases, classdict)
 
 
-class Hama(TaskHasPatientMixin, TaskHasClinicianMixin, Task,
-           metaclass=HamaMetaclass):
+class Hama(
+    TaskHasPatientMixin, TaskHasClinicianMixin, Task, metaclass=HamaMetaclass
+):
     """
     Server implementation of the HAM-A task.
     """
+
     __tablename__ = "hama"
     shortname = "HAM-A"
     provides_trackers = True
@@ -97,45 +115,55 @@ class Hama(TaskHasPatientMixin, TaskHasClinicianMixin, Task,
         return _("Hamilton Rating Scale for Anxiety")
 
     def get_trackers(self, req: CamcopsRequest) -> List[TrackerInfo]:
-        return [TrackerInfo(
-            value=self.total_score(),
-            plot_label="HAM-A total score",
-            axis_label=f"Total score (out of {self.MAX_SCORE})",
-            axis_min=-0.5,
-            axis_max=self.MAX_SCORE + 0.5,
-            horizontal_lines=[30.5, 24.5, 17.5],
-            horizontal_labels=[
-                TrackerLabel(33, req.sstring(SS.VERY_SEVERE)),
-                TrackerLabel(27.5, req.sstring(SS.MODERATE_TO_SEVERE)),
-                TrackerLabel(21, req.sstring(SS.MILD_TO_MODERATE)),
-                TrackerLabel(8.75, req.sstring(SS.MILD)),
-            ]
-        )]
+        return [
+            TrackerInfo(
+                value=self.total_score(),
+                plot_label="HAM-A total score",
+                axis_label=f"Total score (out of {self.MAX_SCORE})",
+                axis_min=-0.5,
+                axis_max=self.MAX_SCORE + 0.5,
+                horizontal_lines=[30.5, 24.5, 17.5],
+                horizontal_labels=[
+                    TrackerLabel(33, req.sstring(SS.VERY_SEVERE)),
+                    TrackerLabel(27.5, req.sstring(SS.MODERATE_TO_SEVERE)),
+                    TrackerLabel(21, req.sstring(SS.MILD_TO_MODERATE)),
+                    TrackerLabel(8.75, req.sstring(SS.MILD)),
+                ],
+            )
+        ]
 
     def get_clinical_text(self, req: CamcopsRequest) -> List[CtvInfo]:
         if not self.is_complete():
             return CTV_INCOMPLETE
-        return [CtvInfo(content=(
-            f"HAM-A total score {self.total_score()}/{self.MAX_SCORE} "
-            f"({self.severity(req)})"
-        ))]
+        return [
+            CtvInfo(
+                content=(
+                    f"HAM-A total score {self.total_score()}/{self.MAX_SCORE} "
+                    f"({self.severity(req)})"
+                )
+            )
+        ]
 
     def get_summaries(self, req: CamcopsRequest) -> List[SummaryElement]:
         return self.standard_task_summary_fields() + [
-            SummaryElement(name="total",
-                           coltype=Integer(),
-                           value=self.total_score(),
-                           comment=f"Total score (/{self.MAX_SCORE})"),
-            SummaryElement(name="severity",
-                           coltype=SummaryCategoryColType,
-                           value=self.severity(req),
-                           comment="Severity"),
+            SummaryElement(
+                name="total",
+                coltype=Integer(),
+                value=self.total_score(),
+                comment=f"Total score (/{self.MAX_SCORE})",
+            ),
+            SummaryElement(
+                name="severity",
+                coltype=SummaryCategoryColType,
+                value=self.severity(req),
+                comment="Severity",
+            ),
         ]
 
     def is_complete(self) -> bool:
         return (
-            self.all_fields_not_none(self.TASK_FIELDS) and
-            self.field_contents_valid()
+            self.all_fields_not_none(self.TASK_FIELDS)
+            and self.field_contents_valid()
         )
 
     def total_score(self) -> int:
@@ -159,15 +187,19 @@ class Hama(TaskHasPatientMixin, TaskHasClinicianMixin, Task,
         for q in range(1, self.NQUESTIONS + 1):
             d = {None: None}
             for option in range(0, 4 + 1):
-                d[option] = self.wxstring(req, "q" + str(q) + "_option" +
-                                          str(option))
+                d[option] = self.wxstring(
+                    req, "q" + str(q) + "_option" + str(option)
+                )
             answer_dicts.append(d)
         q_a = ""
         for q in range(1, self.NQUESTIONS + 1):
             q_a += tr_qa(
-                self.wxstring(req, "q" + str(q) + "_s") + " " +
-                self.wxstring(req, "q" + str(q) + "_question"),
-                get_from_dict(answer_dicts[q - 1], getattr(self, "q" + str(q)))
+                self.wxstring(req, "q" + str(q) + "_s")
+                + " "
+                + self.wxstring(req, "q" + str(q) + "_question"),
+                get_from_dict(
+                    answer_dicts[q - 1], getattr(self, "q" + str(q))
+                ),
             )
         return """
             <div class="{CssClass.SUMMARY}">
@@ -193,11 +225,11 @@ class Hama(TaskHasPatientMixin, TaskHasClinicianMixin, Task,
             tr_is_complete=self.get_is_complete_tr(req),
             total_score=tr(
                 req.sstring(SS.TOTAL_SCORE),
-                answer(score) + " / {}".format(self.MAX_SCORE)
+                answer(score) + " / {}".format(self.MAX_SCORE),
             ),
             symptom_severity=tr_qa(
                 self.wxstring(req, "symptom_severity") + " <sup>[1]</sup>",
-                severity
+                severity,
             ),
             q_a=q_a,
         )
