@@ -65,41 +65,61 @@ from camcops_server.cc_modules.cc_trackerhelpers import (
 # =============================================================================
 
 MAX_SCORE = (
-    4 * 15 -  # Q1-15 scored 0-5
-    (2 * 6) +  # except Q4-6, 12-14 scored 0-2
-    2 * 2  # Q16-17
+    4 * 15
+    - (2 * 6)  # Q1-15 scored 0-5
+    + 2 * 2  # except Q4-6, 12-14 scored 0-2  # Q16-17
 )  # ... and not scored beyond Q17... total 52
 
 
 class HamdMetaclass(DeclarativeMeta):
     # noinspection PyInitNewSignature
-    def __init__(cls: Type['Hamd'],
-                 name: str,
-                 bases: Tuple[Type, ...],
-                 classdict: Dict[str, Any]) -> None:
+    def __init__(
+        cls: Type["Hamd"],
+        name: str,
+        bases: Tuple[Type, ...],
+        classdict: Dict[str, Any],
+    ) -> None:
         add_multiple_columns(
-            cls, "q", 1, 15,
+            cls,
+            "q",
+            1,
+            15,
             comment_fmt="Q{n}, {s} (scored 0-4, except 0-2 for "
-                        "Q4-6/12-14, higher worse)",
-            minimum=0, maximum=4,  # amended below
+            "Q4-6/12-14, higher worse)",
+            minimum=0,
+            maximum=4,  # amended below
             comment_strings=[
-                "depressed mood", "guilt", "suicide", "early insomnia",
-                "middle insomnia", "late insomnia", "work/activities",
-                "psychomotor retardation", "agitation",
-                "anxiety, psychological", "anxiety, somatic",
+                "depressed mood",
+                "guilt",
+                "suicide",
+                "early insomnia",
+                "middle insomnia",
+                "late insomnia",
+                "work/activities",
+                "psychomotor retardation",
+                "agitation",
+                "anxiety, psychological",
+                "anxiety, somatic",
                 "somatic symptoms, gastointestinal",
-                "somatic symptoms, general", "genital symptoms",
-                "hypochondriasis"
-            ]
+                "somatic symptoms, general",
+                "genital symptoms",
+                "hypochondriasis",
+            ],
         )
         add_multiple_columns(
-            cls, "q", 19, 21,
+            cls,
+            "q",
+            19,
+            21,
             comment_fmt="Q{n} (not scored), {s} (0-4 for Q19, "
-                        "0-3 for Q20, 0-2 for Q21, higher worse)",
-            minimum=0, maximum=4,  # below
-            comment_strings=["depersonalization/derealization",
-                             "paranoid symptoms",
-                             "obsessional/compulsive symptoms"]
+            "0-3 for Q20, 0-2 for Q21, higher worse)",
+            minimum=0,
+            maximum=4,  # below
+            comment_strings=[
+                "depersonalization/derealization",
+                "paranoid symptoms",
+                "obsessional/compulsive symptoms",
+            ],
         )
         # Now fix the wrong bits. Hardly elegant!
         for qnum in (4, 5, 6, 12, 13, 14, 21):
@@ -112,11 +132,13 @@ class HamdMetaclass(DeclarativeMeta):
         super().__init__(name, bases, classdict)
 
 
-class Hamd(TaskHasPatientMixin, TaskHasClinicianMixin, Task,
-           metaclass=HamdMetaclass):
+class Hamd(
+    TaskHasPatientMixin, TaskHasClinicianMixin, Task, metaclass=HamdMetaclass
+):
     """
     Server implementation of the HAM-D task.
     """
+
     __tablename__ = "hamd"
     shortname = "HAM-D"
     provides_trackers = True
@@ -124,43 +146,54 @@ class Hamd(TaskHasPatientMixin, TaskHasClinicianMixin, Task,
     NSCOREDQUESTIONS = 17
     NQUESTIONS = 21
     TASK_FIELDS = strseq("q", 1, NQUESTIONS) + [
-        "whichq16", "q16a", "q16b", "q17", "q18a", "q18b"
+        "whichq16",
+        "q16a",
+        "q16b",
+        "q17",
+        "q18a",
+        "q18b",
     ]
 
     whichq16 = CamcopsColumn(
-        "whichq16", Integer,
+        "whichq16",
+        Integer,
         permitted_value_checker=ZERO_TO_ONE_CHECKER,
         comment="Method of assessing weight loss (0 = A, by history; "
-                "1 = B, by measured change)"
+        "1 = B, by measured change)",
     )
     q16a = CamcopsColumn(
-        "q16a", Integer,
+        "q16a",
+        Integer,
         permitted_value_checker=ZERO_TO_THREE_CHECKER,
         comment="Q16A, weight loss, by history (0 none - 2 definite,"
-                " or 3 not assessed [not scored])"
+        " or 3 not assessed [not scored])",
     )
     q16b = CamcopsColumn(
-        "q16b", Integer,
+        "q16b",
+        Integer,
         permitted_value_checker=ZERO_TO_THREE_CHECKER,
         comment="Q16B, weight loss, by measurement (0 none - "
-                "2 more than 2lb, or 3 not assessed [not scored])"
+        "2 more than 2lb, or 3 not assessed [not scored])",
     )
     q17 = CamcopsColumn(
-        "q17", Integer,
+        "q17",
+        Integer,
         permitted_value_checker=ZERO_TO_TWO_CHECKER,
-        comment="Q17, lack of insight (0-2, higher worse)"
+        comment="Q17, lack of insight (0-2, higher worse)",
     )
     q18a = CamcopsColumn(
-        "q18a", Integer,
+        "q18a",
+        Integer,
         permitted_value_checker=ZERO_TO_TWO_CHECKER,
         comment="Q18A (not scored), diurnal variation, presence "
-                "(0 none, 1 worse AM, 2 worse PM)"
+        "(0 none, 1 worse AM, 2 worse PM)",
     )
     q18b = CamcopsColumn(
-        "q18b", Integer,
+        "q18b",
+        Integer,
         permitted_value_checker=ZERO_TO_TWO_CHECKER,
         comment="Q18B (not scored), diurnal variation, severity "
-                "(0-2, higher more severe)"
+        "(0-2, higher more severe)",
     )
 
     @staticmethod
@@ -169,40 +202,52 @@ class Hamd(TaskHasPatientMixin, TaskHasClinicianMixin, Task,
         return _("Hamilton Rating Scale for Depression")
 
     def get_trackers(self, req: CamcopsRequest) -> List[TrackerInfo]:
-        return [TrackerInfo(
-            value=self.total_score(),
-            plot_label="HAM-D total score",
-            axis_label=f"Total score (out of {MAX_SCORE})",
-            axis_min=-0.5,
-            axis_max=MAX_SCORE + 0.5,
-            horizontal_lines=[22.5, 19.5, 14.5, 7.5],
-            horizontal_labels=[
-                TrackerLabel(25, self.wxstring(req, "severity_verysevere")),
-                TrackerLabel(21, self.wxstring(req, "severity_severe")),
-                TrackerLabel(17, self.wxstring(req, "severity_moderate")),
-                TrackerLabel(11, self.wxstring(req, "severity_mild")),
-                TrackerLabel(3.75, self.wxstring(req, "severity_none")),
-            ]
-        )]
+        return [
+            TrackerInfo(
+                value=self.total_score(),
+                plot_label="HAM-D total score",
+                axis_label=f"Total score (out of {MAX_SCORE})",
+                axis_min=-0.5,
+                axis_max=MAX_SCORE + 0.5,
+                horizontal_lines=[22.5, 19.5, 14.5, 7.5],
+                horizontal_labels=[
+                    TrackerLabel(
+                        25, self.wxstring(req, "severity_verysevere")
+                    ),
+                    TrackerLabel(21, self.wxstring(req, "severity_severe")),
+                    TrackerLabel(17, self.wxstring(req, "severity_moderate")),
+                    TrackerLabel(11, self.wxstring(req, "severity_mild")),
+                    TrackerLabel(3.75, self.wxstring(req, "severity_none")),
+                ],
+            )
+        ]
 
     def get_clinical_text(self, req: CamcopsRequest) -> List[CtvInfo]:
         if not self.is_complete():
             return CTV_INCOMPLETE
-        return [CtvInfo(content=(
-            f"HAM-D total score {self.total_score()}/{MAX_SCORE} "
-            f"({self.severity(req)})"
-        ))]
+        return [
+            CtvInfo(
+                content=(
+                    f"HAM-D total score {self.total_score()}/{MAX_SCORE} "
+                    f"({self.severity(req)})"
+                )
+            )
+        ]
 
     def get_summaries(self, req: CamcopsRequest) -> List[SummaryElement]:
         return self.standard_task_summary_fields() + [
-            SummaryElement(name="total",
-                           coltype=Integer(),
-                           value=self.total_score(),
-                           comment=f"Total score (/{MAX_SCORE})"),
-            SummaryElement(name="severity",
-                           coltype=SummaryCategoryColType,
-                           value=self.severity(req),
-                           comment="Severity"),
+            SummaryElement(
+                name="total",
+                coltype=Integer(),
+                value=self.total_score(),
+                comment=f"Total score (/{MAX_SCORE})",
+            ),
+            SummaryElement(
+                name="severity",
+                coltype=SummaryCategoryColType,
+                value=self.severity(req),
+                comment="Severity",
+            ),
         ]
 
     # noinspection PyUnresolvedReferences
@@ -214,8 +259,11 @@ class Hamd(TaskHasPatientMixin, TaskHasClinicianMixin, Task,
         if self.q1 == 0:
             # Special limited-information completeness
             return True
-        if self.q2 is not None and self.q3 is not None \
-                and (self.q2 + self.q3 == 0):
+        if (
+            self.q2 is not None
+            and self.q3 is not None
+            and (self.q2 + self.q3 == 0)
+        ):
             # Special limited-information completeness
             return True
         # Otherwise, any null values cause problems
@@ -223,8 +271,9 @@ class Hamd(TaskHasPatientMixin, TaskHasClinicianMixin, Task,
             return False
         for i in range(1, self.NSCOREDQUESTIONS + 1):
             if i == 16:
-                if (self.whichq16 == 0 and self.q16a is None) \
-                        or (self.whichq16 == 1 and self.q16b is None):
+                if (self.whichq16 == 0 and self.q16a is None) or (
+                    self.whichq16 == 1 and self.q16b is None
+                ):
                     return False
             else:
                 if getattr(self, "q" + str(i)) is None:
@@ -260,25 +309,35 @@ class Hamd(TaskHasPatientMixin, TaskHasClinicianMixin, Task,
         score = self.total_score()
         severity = self.severity(req)
         task_field_list_for_display = (
-            strseq("q", 1, 15) +
-            [
+            strseq("q", 1, 15)
+            + [
                 "whichq16",
                 "q16a" if self.whichq16 == 0 else "q16b",  # funny one
                 "q17",
                 "q18a",
-                "q18b"
-            ] +
-            strseq("q", 19, 21)
+                "q18b",
+            ]
+            + strseq("q", 19, 21)
         )
         answer_dicts_dict = {}
         for q in task_field_list_for_display:
             d = {None: None}
             for option in range(0, 5):
-                if (q == "q4" or q == "q5" or q == "q6" or q == "q12" or
-                        q == "q13" or q == "q14" or q == "q17" or
-                        q == "q18" or q == "q21") and option > 2:
+                if (
+                    q == "q4"
+                    or q == "q5"
+                    or q == "q6"
+                    or q == "q12"
+                    or q == "q13"
+                    or q == "q14"
+                    or q == "q17"
+                    or q == "q18"
+                    or q == "q21"
+                ) and option > 2:
                     continue
-                d[option] = self.wxstring(req, "" + q + "_option" + str(option))
+                d[option] = self.wxstring(
+                    req, "" + q + "_option" + str(option)
+                )
             answer_dicts_dict[q] = d
         q_a = ""
         for q in task_field_list_for_display:
@@ -291,11 +350,12 @@ class Hamd(TaskHasPatientMixin, TaskHasClinicianMixin, Task,
                     col = getattr(self.__class__, q)  # type: CamcopsColumn
                     rangestr = " <sup>range {}–{}</sup>".format(
                         col.permitted_value_checker.minimum,
-                        col.permitted_value_checker.maximum
+                        col.permitted_value_checker.maximum,
                     )
                 qstr = self.wxstring(req, "" + q + "_s") + rangestr
-            q_a += tr_qa(qstr, get_from_dict(answer_dicts_dict[q],
-                                             getattr(self, q)))
+            q_a += tr_qa(
+                qstr, get_from_dict(answer_dicts_dict[q], getattr(self, q))
+            )
         return """
             <div class="{CssClass.SUMMARY}">
                 <table class="{CssClass.SUMMARY}">
@@ -326,22 +386,25 @@ class Hamd(TaskHasPatientMixin, TaskHasClinicianMixin, Task,
             tr_is_complete=self.get_is_complete_tr(req),
             total_score=tr(
                 req.sstring(SS.TOTAL_SCORE) + " <sup>[1]</sup>",
-                answer(score) + " / {}".format(MAX_SCORE)
+                answer(score) + " / {}".format(MAX_SCORE),
             ),
             severity=tr_qa(
-                self.wxstring(req, "severity") + " <sup>[2]</sup>",
-                severity
+                self.wxstring(req, "severity") + " <sup>[2]</sup>", severity
             ),
             q_a=q_a,
         )
 
     def get_snomed_codes(self, req: CamcopsRequest) -> List[SnomedExpression]:
-        codes = [SnomedExpression(req.snomed(SnomedLookup.HAMD_PROCEDURE_ASSESSMENT))]  # noqa
+        codes = [
+            SnomedExpression(
+                req.snomed(SnomedLookup.HAMD_PROCEDURE_ASSESSMENT)
+            )
+        ]
         if self.is_complete():
-            codes.append(SnomedExpression(
-                req.snomed(SnomedLookup.HAMD_SCALE),
-                {
-                    req.snomed(SnomedLookup.HAMD_SCORE): self.total_score(),
-                }
-            ))
+            codes.append(
+                SnomedExpression(
+                    req.snomed(SnomedLookup.HAMD_SCALE),
+                    {req.snomed(SnomedLookup.HAMD_SCORE): self.total_score()},
+                )
+            )
         return codes
