@@ -62,7 +62,7 @@ from camcops_server.cc_modules.cc_trackerhelpers import TrackerInfo
 
 
 PV_MAIN = [0, 1, 2, 3, 4, 9]
-PV_PROBLEMTYPE = ['A', 'B', 'C', 'D', 'E', 'F', 'G', 'H', 'I', 'J']
+PV_PROBLEMTYPE = ["A", "B", "C", "D", "E", "F", "G", "H", "I", "J"]
 
 FOOTNOTE_SCORING = """
     [1] 0 = no problem;
@@ -84,8 +84,7 @@ class HonosBase(TaskHasPatientMixin, TaskHasClinicianMixin, Task):
     provides_trackers = True
 
     period_rated = Column(
-        "period_rated", UnicodeText,
-        comment="Period being rated"
+        "period_rated", UnicodeText, comment="Period being rated"
     )
 
     COPYRIGHT_DIV = f"""
@@ -100,28 +99,36 @@ class HonosBase(TaskHasPatientMixin, TaskHasClinicianMixin, Task):
     MAX_SCORE = None  # type: int  # must be overridden
 
     def get_trackers(self, req: CamcopsRequest) -> List[TrackerInfo]:
-        return [TrackerInfo(
-            value=self.total_score(),
-            plot_label=f"{self.shortname} total score",
-            axis_label=f"Total score (out of {self.MAX_SCORE})",
-            axis_min=-0.5,
-            axis_max=self.MAX_SCORE + 0.5
-        )]
+        return [
+            TrackerInfo(
+                value=self.total_score(),
+                plot_label=f"{self.shortname} total score",
+                axis_label=f"Total score (out of {self.MAX_SCORE})",
+                axis_min=-0.5,
+                axis_max=self.MAX_SCORE + 0.5,
+            )
+        ]
 
     def get_clinical_text(self, req: CamcopsRequest) -> List[CtvInfo]:
         if not self.is_complete():
             return CTV_INCOMPLETE
-        return [CtvInfo(content=(
-            f"{self.shortname} total score "
-            f"{self.total_score()}/{self.MAX_SCORE}"
-        ))]
+        return [
+            CtvInfo(
+                content=(
+                    f"{self.shortname} total score "
+                    f"{self.total_score()}/{self.MAX_SCORE}"
+                )
+            )
+        ]
 
     def get_summaries(self, req: CamcopsRequest) -> List[SummaryElement]:
         return self.standard_task_summary_fields() + [
-            SummaryElement(name="total",
-                           coltype=Integer(),
-                           value=self.total_score(),
-                           comment=f"Total score (/{self.MAX_SCORE})"),
+            SummaryElement(
+                name="total",
+                coltype=Integer(),
+                value=self.total_score(),
+                comment=f"Total score (/{self.MAX_SCORE})",
+            )
         ]
 
     def _total_score_for_fields(self, fieldnames: List[str]) -> int:
@@ -151,14 +158,20 @@ class HonosBase(TaskHasPatientMixin, TaskHasClinicianMixin, Task):
 # HoNOS
 # =============================================================================
 
+
 class HonosMetaclass(DeclarativeMeta):
     # noinspection PyInitNewSignature
-    def __init__(cls: Type['Honos'],
-                 name: str,
-                 bases: Tuple[Type, ...],
-                 classdict: Dict[str, Any]) -> None:
+    def __init__(
+        cls: Type["Honos"],
+        name: str,
+        bases: Tuple[Type, ...],
+        classdict: Dict[str, Any],
+    ) -> None:
         add_multiple_columns(
-            cls, "q", 1, cls.NQUESTIONS,
+            cls,
+            "q",
+            1,
+            cls.NQUESTIONS,
             pv=PV_MAIN,
             comment_fmt="Q{n}, {s} (0-4, higher worse)",
             comment_strings=[
@@ -174,32 +187,33 @@ class HonosMetaclass(DeclarativeMeta):
                 "activities of daily living",
                 "problems with living conditions",
                 "occupation/activities",
-            ]
+            ],
         )
         super().__init__(name, bases, classdict)
 
 
-class Honos(HonosBase,
-            metaclass=HonosMetaclass):
+class Honos(HonosBase, metaclass=HonosMetaclass):
     """
     Server implementation of the HoNOS task.
     """
+
     __tablename__ = "honos"
     shortname = "HoNOS"
     info_filename_stem = "honos"
 
     q8problemtype = CamcopsColumn(
-        "q8problemtype", CharColType,
+        "q8problemtype",
+        CharColType,
         permitted_value_checker=PermittedValueChecker(
-            permitted_values=PV_PROBLEMTYPE),
+            permitted_values=PV_PROBLEMTYPE
+        ),
         comment="Q8: type of problem (A phobic; B anxiety; "
-                "C obsessive-compulsive; D mental strain/tension; "
-                "E dissociative; F somatoform; G eating; H sleep; "
-                "I sexual; J other, specify)"
+        "C obsessive-compulsive; D mental strain/tension; "
+        "E dissociative; F somatoform; G eating; H sleep; "
+        "I sexual; J other, specify)",
     )
     q8otherproblem = Column(
-        "q8otherproblem", UnicodeText,
-        comment="Q8: other problem: specify"
+        "q8otherproblem", UnicodeText, comment="Q8: other problem: specify"
     )
 
     NQUESTIONS = 12
@@ -219,8 +233,12 @@ class Honos(HonosBase,
             return False
         if self.q8 != 0 and self.q8 != 9 and self.q8problemtype is None:
             return False
-        if self.q8 != 0 and self.q8 != 9 and self.q8problemtype == "J" \
-                and self.q8otherproblem is None:
+        if (
+            self.q8 != 0
+            and self.q8 != 9
+            and self.q8problemtype == "J"
+            and self.q8otherproblem is None
+        ):
             return False
         return self.period_rated is not None
 
@@ -242,13 +260,13 @@ class Honos(HonosBase,
         for i in range(1, 8 + 1):
             one_to_eight += tr_qa(
                 self.get_q(req, i),
-                self.get_answer(req, i, getattr(self, "q" + str(i)))
+                self.get_answer(req, i, getattr(self, "q" + str(i))),
             )
         nine_onwards = ""
         for i in range(9, self.NQUESTIONS + 1):
             nine_onwards += tr_qa(
                 self.get_q(req, i),
-                self.get_answer(req, i, getattr(self, "q" + str(i)))
+                self.get_answer(req, i, getattr(self, "q" + str(i))),
             )
 
         h = """
@@ -278,18 +296,18 @@ class Honos(HonosBase,
             tr_is_complete=self.get_is_complete_tr(req),
             total_score=tr(
                 req.sstring(SS.TOTAL_SCORE),
-                answer(self.total_score()) + f" / {self.MAX_SCORE}"
+                answer(self.total_score()) + f" / {self.MAX_SCORE}",
+            ),
+            period_rated=tr_qa(
+                self.wxstring(req, "period_rated"), self.period_rated
             ),
-            period_rated=tr_qa(self.wxstring(req, "period_rated"),
-                               self.period_rated),
             one_to_eight=one_to_eight,
             q8problemtype=tr_qa(
                 self.wxstring(req, "q8problemtype_s"),
-                get_from_dict(q8_problem_type_dict, self.q8problemtype)
+                get_from_dict(q8_problem_type_dict, self.q8problemtype),
             ),
             q8otherproblem=tr_qa(
-                self.wxstring(req, "q8otherproblem_s"),
-                self.q8otherproblem
+                self.wxstring(req, "q8otherproblem_s"), self.q8otherproblem
             ),
             nine_onwards=nine_onwards,
             FOOTNOTE_SCORING=FOOTNOTE_SCORING,
@@ -299,26 +317,58 @@ class Honos(HonosBase,
 
     # noinspection PyUnresolvedReferences
     def get_snomed_codes(self, req: CamcopsRequest) -> List[SnomedExpression]:
-        codes = [SnomedExpression(req.snomed(SnomedLookup.HONOSWA_PROCEDURE_ASSESSMENT))]  # noqa
+        codes = [
+            SnomedExpression(
+                req.snomed(SnomedLookup.HONOSWA_PROCEDURE_ASSESSMENT)
+            )
+        ]
         if self.is_complete():
-            codes.append(SnomedExpression(
-                req.snomed(SnomedLookup.HONOSWA_SCALE),
-                {
-                    req.snomed(SnomedLookup.HONOSWA_SCORE): self.total_score(),
-                    req.snomed(SnomedLookup.HONOSWA_1_OVERACTIVE_SCORE): self.q1,  # noqa
-                    req.snomed(SnomedLookup.HONOSWA_2_SELFINJURY_SCORE): self.q2,  # noqa
-                    req.snomed(SnomedLookup.HONOSWA_3_SUBSTANCE_SCORE): self.q3,  # noqa
-                    req.snomed(SnomedLookup.HONOSWA_4_COGNITIVE_SCORE): self.q4,  # noqa
-                    req.snomed(SnomedLookup.HONOSWA_5_PHYSICAL_SCORE): self.q5,
-                    req.snomed(SnomedLookup.HONOSWA_6_PSYCHOSIS_SCORE): self.q6,  # noqa
-                    req.snomed(SnomedLookup.HONOSWA_7_DEPRESSION_SCORE): self.q7,  # noqa
-                    req.snomed(SnomedLookup.HONOSWA_8_OTHERMENTAL_SCORE): self.q8,  # noqa
-                    req.snomed(SnomedLookup.HONOSWA_9_RELATIONSHIPS_SCORE): self.q9,  # noqa
-                    req.snomed(SnomedLookup.HONOSWA_10_ADL_SCORE): self.q10,
-                    req.snomed(SnomedLookup.HONOSWA_11_LIVINGCONDITIONS_SCORE): self.q11,  # noqa
-                    req.snomed(SnomedLookup.HONOSWA_12_OCCUPATION_SCORE): self.q12,  # noqa
-                }
-            ))
+            codes.append(
+                SnomedExpression(
+                    req.snomed(SnomedLookup.HONOSWA_SCALE),
+                    {
+                        req.snomed(
+                            SnomedLookup.HONOSWA_SCORE
+                        ): self.total_score(),
+                        req.snomed(
+                            SnomedLookup.HONOSWA_1_OVERACTIVE_SCORE
+                        ): self.q1,  # noqa
+                        req.snomed(
+                            SnomedLookup.HONOSWA_2_SELFINJURY_SCORE
+                        ): self.q2,  # noqa
+                        req.snomed(
+                            SnomedLookup.HONOSWA_3_SUBSTANCE_SCORE
+                        ): self.q3,  # noqa
+                        req.snomed(
+                            SnomedLookup.HONOSWA_4_COGNITIVE_SCORE
+                        ): self.q4,  # noqa
+                        req.snomed(
+                            SnomedLookup.HONOSWA_5_PHYSICAL_SCORE
+                        ): self.q5,
+                        req.snomed(
+                            SnomedLookup.HONOSWA_6_PSYCHOSIS_SCORE
+                        ): self.q6,  # noqa
+                        req.snomed(
+                            SnomedLookup.HONOSWA_7_DEPRESSION_SCORE
+                        ): self.q7,  # noqa
+                        req.snomed(
+                            SnomedLookup.HONOSWA_8_OTHERMENTAL_SCORE
+                        ): self.q8,  # noqa
+                        req.snomed(
+                            SnomedLookup.HONOSWA_9_RELATIONSHIPS_SCORE
+                        ): self.q9,  # noqa
+                        req.snomed(
+                            SnomedLookup.HONOSWA_10_ADL_SCORE
+                        ): self.q10,
+                        req.snomed(
+                            SnomedLookup.HONOSWA_11_LIVINGCONDITIONS_SCORE
+                        ): self.q11,  # noqa
+                        req.snomed(
+                            SnomedLookup.HONOSWA_12_OCCUPATION_SCORE
+                        ): self.q12,  # noqa
+                    },
+                )
+            )
         return codes
 
 
@@ -326,14 +376,20 @@ class Honos(HonosBase,
 # HoNOS 65+
 # =============================================================================
 
+
 class Honos65Metaclass(DeclarativeMeta):
     # noinspection PyInitNewSignature
-    def __init__(cls: Type['Honos65'],
-                 name: str,
-                 bases: Tuple[Type, ...],
-                 classdict: Dict[str, Any]) -> None:
+    def __init__(
+        cls: Type["Honos65"],
+        name: str,
+        bases: Tuple[Type, ...],
+        classdict: Dict[str, Any],
+    ) -> None:
         add_multiple_columns(
-            cls, "q", 1, cls.NQUESTIONS,
+            cls,
+            "q",
+            1,
+            cls.NQUESTIONS,
             pv=PV_MAIN,
             comment_fmt="Q{n}, {s} (0-4, higher worse)",
             comment_strings=[  # not exactly identical to HoNOS
@@ -349,32 +405,33 @@ class Honos65Metaclass(DeclarativeMeta):
                 "activities of daily living",
                 "living conditions",
                 "occupation/activities",
-            ]
+            ],
         )
         super().__init__(name, bases, classdict)
 
 
-class Honos65(HonosBase,
-              metaclass=Honos65Metaclass):
+class Honos65(HonosBase, metaclass=Honos65Metaclass):
     """
     Server implementation of the HoNOS 65+ task.
     """
+
     __tablename__ = "honos65"
     shortname = "HoNOS 65+"
     info_filename_stem = "honos"
 
     q8problemtype = CamcopsColumn(
-        "q8problemtype", CharColType,
+        "q8problemtype",
+        CharColType,
         permitted_value_checker=PermittedValueChecker(
-            permitted_values=PV_PROBLEMTYPE),
+            permitted_values=PV_PROBLEMTYPE
+        ),
         comment="Q8: type of problem (A phobic; B anxiety; "
-                "C obsessive-compulsive; D stress; "  # NB slight difference: D
-                "E dissociative; F somatoform; G eating; H sleep; "
-                "I sexual; J other, specify)"
+        "C obsessive-compulsive; D stress; "  # NB slight difference: D
+        "E dissociative; F somatoform; G eating; H sleep; "
+        "I sexual; J other, specify)",
     )
     q8otherproblem = Column(
-        "q8otherproblem", UnicodeText,
-        comment="Q8: other problem: specify"
+        "q8otherproblem", UnicodeText, comment="Q8: other problem: specify"
     )
 
     NQUESTIONS = 12
@@ -394,8 +451,12 @@ class Honos65(HonosBase,
             return False
         if self.q8 != 0 and self.q8 != 9 and self.q8problemtype is None:
             return False
-        if self.q8 != 0 and self.q8 != 9 and self.q8problemtype == "J" \
-                and self.q8otherproblem is None:
+        if (
+            self.q8 != 0
+            and self.q8 != 9
+            and self.q8problemtype == "J"
+            and self.q8otherproblem is None
+        ):
             return False
         return self.period_rated is not None
 
@@ -417,13 +478,13 @@ class Honos65(HonosBase,
         for i in range(1, 8 + 1):
             one_to_eight += tr_qa(
                 self.get_q(req, i),
-                self.get_answer(req, i, getattr(self, "q" + str(i)))
+                self.get_answer(req, i, getattr(self, "q" + str(i))),
             )
         nine_onwards = ""
         for i in range(9, Honos.NQUESTIONS + 1):
             nine_onwards += tr_qa(
                 self.get_q(req, i),
-                self.get_answer(req, i, getattr(self, "q" + str(i)))
+                self.get_answer(req, i, getattr(self, "q" + str(i))),
             )
 
         h = """
@@ -453,18 +514,18 @@ class Honos65(HonosBase,
             tr_is_complete=self.get_is_complete_tr(req),
             total_score=tr(
                 req.sstring(SS.TOTAL_SCORE),
-                answer(self.total_score()) + f" / {self.MAX_SCORE}"
+                answer(self.total_score()) + f" / {self.MAX_SCORE}",
+            ),
+            period_rated=tr_qa(
+                self.wxstring(req, "period_rated"), self.period_rated
             ),
-            period_rated=tr_qa(self.wxstring(req, "period_rated"),
-                               self.period_rated),
             one_to_eight=one_to_eight,
             q8problemtype=tr_qa(
                 self.wxstring(req, "q8problemtype_s"),
-                get_from_dict(q8_problem_type_dict, self.q8problemtype)
+                get_from_dict(q8_problem_type_dict, self.q8problemtype),
             ),
             q8otherproblem=tr_qa(
-                self.wxstring(req, "q8otherproblem_s"),
-                self.q8otherproblem
+                self.wxstring(req, "q8otherproblem_s"), self.q8otherproblem
             ),
             nine_onwards=nine_onwards,
             FOOTNOTE_SCORING=FOOTNOTE_SCORING,
@@ -473,14 +534,22 @@ class Honos65(HonosBase,
         return h
 
     def get_snomed_codes(self, req: CamcopsRequest) -> List[SnomedExpression]:
-        codes = [SnomedExpression(req.snomed(SnomedLookup.HONOS65_PROCEDURE_ASSESSMENT))]  # noqa
+        codes = [
+            SnomedExpression(
+                req.snomed(SnomedLookup.HONOS65_PROCEDURE_ASSESSMENT)
+            )
+        ]
         if self.is_complete():
-            codes.append(SnomedExpression(
-                req.snomed(SnomedLookup.HONOS65_SCALE),
-                {
-                    req.snomed(SnomedLookup.HONOS65_SCORE): self.total_score(),
-                }
-            ))
+            codes.append(
+                SnomedExpression(
+                    req.snomed(SnomedLookup.HONOS65_SCALE),
+                    {
+                        req.snomed(
+                            SnomedLookup.HONOS65_SCORE
+                        ): self.total_score()
+                    },
+                )
+            )
         return codes
 
 
@@ -488,14 +557,20 @@ class Honos65(HonosBase,
 # HoNOSCA
 # =============================================================================
 
+
 class HonoscaMetaclass(DeclarativeMeta):
     # noinspection PyInitNewSignature
-    def __init__(cls: Type['Honosca'],
-                 name: str,
-                 bases: Tuple[Type, ...],
-                 classdict: Dict[str, Any]) -> None:
+    def __init__(
+        cls: Type["Honosca"],
+        name: str,
+        bases: Tuple[Type, ...],
+        classdict: Dict[str, Any],
+    ) -> None:
         add_multiple_columns(
-            cls, "q", 1, cls.NQUESTIONS,
+            cls,
+            "q",
+            1,
+            cls.NQUESTIONS,
             pv=PV_MAIN,
             comment_fmt="Q{n}, {s} (0-4, higher worse)",
             comment_strings=[
@@ -514,16 +589,16 @@ class HonoscaMetaclass(DeclarativeMeta):
                 "school attendance",
                 "problems with knowledge/understanding of child's problems",
                 "lack of information about services",
-            ]
+            ],
         )
         super().__init__(name, bases, classdict)
 
 
-class Honosca(HonosBase,
-              metaclass=HonoscaMetaclass):
+class Honosca(HonosBase, metaclass=HonoscaMetaclass):
     """
     Server implementation of the HoNOSCA task.
     """
+
     __tablename__ = "honosca"
     shortname = "HoNOSCA"
     info_filename_stem = "honos"
@@ -543,12 +618,13 @@ class Honosca(HonosBase,
     def longname(req: "CamcopsRequest") -> str:
         _ = req.gettext
         return _(
-            "Health of the Nation Outcome Scales, Children and Adolescents")
+            "Health of the Nation Outcome Scales, Children and Adolescents"
+        )
 
     def is_complete(self) -> bool:
         return (
-            self.all_fields_not_none(self.TASK_FIELDS) and
-            self.field_contents_valid()
+            self.all_fields_not_none(self.TASK_FIELDS)
+            and self.field_contents_valid()
         )
 
     def section_a_score(self) -> int:
@@ -562,13 +638,13 @@ class Honosca(HonosBase,
         for i in range(1, 13 + 1):
             section_a += tr_qa(
                 self.get_q(req, i),
-                self.get_answer(req, i, getattr(self, "q" + str(i)))
+                self.get_answer(req, i, getattr(self, "q" + str(i))),
             )
         section_b = ""
         for i in range(14, self.NQUESTIONS + 1):
             section_b += tr_qa(
                 self.get_q(req, i),
-                self.get_answer(req, i, getattr(self, "q" + str(i)))
+                self.get_answer(req, i, getattr(self, "q" + str(i))),
             )
 
         h = """
@@ -600,25 +676,26 @@ class Honosca(HonosBase,
             tr_is_complete=self.get_is_complete_tr(req),
             total_score=tr(
                 req.sstring(SS.TOTAL_SCORE),
-                answer(self.total_score()) + f" / {self.MAX_SCORE}"
+                answer(self.total_score()) + f" / {self.MAX_SCORE}",
             ),
             section_a_total=tr(
                 self.wxstring(req, "section_a_total"),
-                answer(self.section_a_score()) +
-                f" / {self.MAX_SECTION_A}"
+                answer(self.section_a_score()) + f" / {self.MAX_SECTION_A}",
             ),
             section_b_total=tr(
                 self.wxstring(req, "section_b_total"),
-                answer(self.section_b_score()) +
-                f" / {self.MAX_SECTION_B}"
+                answer(self.section_b_score()) + f" / {self.MAX_SECTION_B}",
+            ),
+            period_rated=tr_qa(
+                self.wxstring(req, "period_rated"), self.period_rated
             ),
-            period_rated=tr_qa(self.wxstring(req, "period_rated"),
-                               self.period_rated),
             section_a_subhead=subheading_spanning_two_columns(
-                self.wxstring(req, "section_a_title")),
+                self.wxstring(req, "section_a_title")
+            ),
             section_a=section_a,
             section_b_subhead=subheading_spanning_two_columns(
-                self.wxstring(req, "section_b_title")),
+                self.wxstring(req, "section_b_title")
+            ),
             section_b=section_b,
             FOOTNOTE_SCORING=FOOTNOTE_SCORING,
             copyright_div=self.COPYRIGHT_DIV,
@@ -626,18 +703,26 @@ class Honosca(HonosBase,
         return h
 
     def get_snomed_codes(self, req: CamcopsRequest) -> List[SnomedExpression]:
-        codes = [SnomedExpression(req.snomed(SnomedLookup.HONOSCA_PROCEDURE_ASSESSMENT))]  # noqa
+        codes = [
+            SnomedExpression(
+                req.snomed(SnomedLookup.HONOSCA_PROCEDURE_ASSESSMENT)
+            )
+        ]
         if self.is_complete():
             a = self.section_a_score()
             b = self.section_b_score()
             total = a + b
-            codes.append(SnomedExpression(
-                req.snomed(SnomedLookup.HONOSCA_SCALE),
-                {
-                    req.snomed(SnomedLookup.HONOSCA_SCORE): total,
-                    req.snomed(SnomedLookup.HONOSCA_SECTION_A_SCORE): a,
-                    req.snomed(SnomedLookup.HONOSCA_SECTION_B_SCORE): b,
-                    req.snomed(SnomedLookup.HONOSCA_SECTION_A_PLUS_B_SCORE): total,  # noqa
-                }
-            ))
+            codes.append(
+                SnomedExpression(
+                    req.snomed(SnomedLookup.HONOSCA_SCALE),
+                    {
+                        req.snomed(SnomedLookup.HONOSCA_SCORE): total,
+                        req.snomed(SnomedLookup.HONOSCA_SECTION_A_SCORE): a,
+                        req.snomed(SnomedLookup.HONOSCA_SECTION_B_SCORE): b,
+                        req.snomed(
+                            SnomedLookup.HONOSCA_SECTION_A_PLUS_B_SCORE
+                        ): total,  # noqa
+                    },
+                )
+            )
         return codes
