@@ -67,174 +67,203 @@ from camcops_server.cc_modules.cc_text import SS
 # Icd10Manic
 # =============================================================================
 
+
 class Icd10Manic(TaskHasClinicianMixin, TaskHasPatientMixin, Task):
     """
     Server implementation of the ICD10-MANIC task.
     """
+
     __tablename__ = "icd10manic"
     shortname = "ICD10-MANIC"
     info_filename_stem = "icd"
 
     mood_elevated = CamcopsColumn(
-        "mood_elevated", Boolean,
+        "mood_elevated",
+        Boolean,
         permitted_value_checker=BIT_CHECKER,
         comment="The mood is 'elevated' [hypomania] or 'predominantly "
-                "elevated [or] expansive' [mania] to a degree that is "
-                "definitely abnormal for the individual concerned."
+        "elevated [or] expansive' [mania] to a degree that is "
+        "definitely abnormal for the individual concerned.",
     )
     mood_irritable = CamcopsColumn(
-        "mood_irritable", Boolean,
+        "mood_irritable",
+        Boolean,
         permitted_value_checker=BIT_CHECKER,
         comment="The mood is 'irritable' [hypomania] or 'predominantly "
-                "irritable' [mania] to a degree that is definitely abnormal "
-                "for the individual concerned."
+        "irritable' [mania] to a degree that is definitely abnormal "
+        "for the individual concerned.",
     )
 
     distractible = CamcopsColumn(
-        "distractible", Boolean,
+        "distractible",
+        Boolean,
         permitted_value_checker=BIT_CHECKER,
         comment="Difficulty in concentration or distractibility [from "
-                "the criteria for hypomania]; distractibility or constant "
-                "changes in activity or plans [from the criteria for mania]."
+        "the criteria for hypomania]; distractibility or constant "
+        "changes in activity or plans [from the criteria for mania].",
     )
     activity = CamcopsColumn(
-        "activity", Boolean,
+        "activity",
+        Boolean,
         permitted_value_checker=BIT_CHECKER,
-        comment="Increased activity or physical restlessness."
+        comment="Increased activity or physical restlessness.",
     )
     sleep = CamcopsColumn(
-        "sleep", Boolean,
+        "sleep",
+        Boolean,
         permitted_value_checker=BIT_CHECKER,
-        comment="Decreased need for sleep."
+        comment="Decreased need for sleep.",
     )
     talkativeness = CamcopsColumn(
-        "talkativeness", Boolean,
+        "talkativeness",
+        Boolean,
         permitted_value_checker=BIT_CHECKER,
-        comment="Increased talkativeness (pressure of speech)."
+        comment="Increased talkativeness (pressure of speech).",
     )
     recklessness = CamcopsColumn(
-        "recklessness", Boolean,
+        "recklessness",
+        Boolean,
         permitted_value_checker=BIT_CHECKER,
         comment="Mild spending sprees, or other types of reckless or "
-                "irresponsible behaviour [hypomania]; behaviour which is "
-                "foolhardy or reckless and whose risks the subject does not "
-                "recognize e.g. spending sprees, foolish enterprises, "
-                "reckless driving [mania]."
+        "irresponsible behaviour [hypomania]; behaviour which is "
+        "foolhardy or reckless and whose risks the subject does not "
+        "recognize e.g. spending sprees, foolish enterprises, "
+        "reckless driving [mania].",
     )
     social_disinhibition = CamcopsColumn(
-        "social_disinhibition", Boolean,
+        "social_disinhibition",
+        Boolean,
         permitted_value_checker=BIT_CHECKER,
         comment="Increased sociability or over-familiarity [hypomania]; "
-                "loss of normal social inhibitions resulting in behaviour "
-                "which is inappropriate to the circumstances [mania]."
+        "loss of normal social inhibitions resulting in behaviour "
+        "which is inappropriate to the circumstances [mania].",
     )
     sexual = CamcopsColumn(
-        "sexual", Boolean,
+        "sexual",
+        Boolean,
         permitted_value_checker=BIT_CHECKER,
         comment="Increased sexual energy [hypomania]; marked sexual "
-                "energy or sexual indiscretions [mania]."
+        "energy or sexual indiscretions [mania].",
     )
 
     grandiosity = CamcopsColumn(
-        "grandiosity", Boolean,
+        "grandiosity",
+        Boolean,
         permitted_value_checker=BIT_CHECKER,
-        comment="Inflated self-esteem or grandiosity."
+        comment="Inflated self-esteem or grandiosity.",
     )
     flight_of_ideas = CamcopsColumn(
-        "flight_of_ideas", Boolean,
+        "flight_of_ideas",
+        Boolean,
         permitted_value_checker=BIT_CHECKER,
         comment="Flight of ideas or the subjective experience of "
-                "thoughts racing."
+        "thoughts racing.",
     )
 
     sustained4days = CamcopsColumn(
-        "sustained4days", Boolean,
+        "sustained4days",
+        Boolean,
         permitted_value_checker=BIT_CHECKER,
-        comment="Elevated/irritable mood sustained for at least 4 days."
+        comment="Elevated/irritable mood sustained for at least 4 days.",
     )
     sustained7days = CamcopsColumn(
-        "sustained7days", Boolean,
+        "sustained7days",
+        Boolean,
         permitted_value_checker=BIT_CHECKER,
-        comment="Elevated/irritable mood sustained for at least 7 days."
+        comment="Elevated/irritable mood sustained for at least 7 days.",
     )
     admission_required = CamcopsColumn(
-        "admission_required", Boolean,
+        "admission_required",
+        Boolean,
         permitted_value_checker=BIT_CHECKER,
         comment="Elevated/irritable mood severe enough to require "
-                "hospital admission."
+        "hospital admission.",
     )
     some_interference_functioning = CamcopsColumn(
-        "some_interference_functioning", Boolean,
+        "some_interference_functioning",
+        Boolean,
         permitted_value_checker=BIT_CHECKER,
         comment="Some interference with personal functioning "
-                "in daily living."
+        "in daily living.",
     )
     severe_interference_functioning = CamcopsColumn(
-        "severe_interference_functioning", Boolean,
+        "severe_interference_functioning",
+        Boolean,
         permitted_value_checker=BIT_CHECKER,
         comment="Severe interference with personal "
-                "functioning in daily living."
+        "functioning in daily living.",
     )
 
     perceptual_alterations = CamcopsColumn(
-        "perceptual_alterations", Boolean,
+        "perceptual_alterations",
+        Boolean,
         permitted_value_checker=BIT_CHECKER,
         comment="Perceptual alterations (e.g. subjective hyperacusis, "
-                "appreciation of colours as specially vivid, etc.)."
+        "appreciation of colours as specially vivid, etc.).",
     )  # ... not psychotic
     hallucinations_schizophrenic = CamcopsColumn(
-        "hallucinations_schizophrenic", Boolean,
+        "hallucinations_schizophrenic",
+        Boolean,
         permitted_value_checker=BIT_CHECKER,
         comment="Hallucinations that are 'typically schizophrenic' "
-                "(hallucinatory voices giving a running commentary on the "
-                "patient's behaviour, or discussing him between themselves, "
-                "or other types of hallucinatory voices coming from some part "
-                "of the body)."
+        "(hallucinatory voices giving a running commentary on the "
+        "patient's behaviour, or discussing him between themselves, "
+        "or other types of hallucinatory voices coming from some part "
+        "of the body).",
     )
     hallucinations_other = CamcopsColumn(
-        "hallucinations_other", Boolean,
+        "hallucinations_other",
+        Boolean,
         permitted_value_checker=BIT_CHECKER,
-        comment="Hallucinations (of any other kind)."
+        comment="Hallucinations (of any other kind).",
     )
     delusions_schizophrenic = CamcopsColumn(
-        "delusions_schizophrenic", Boolean,
+        "delusions_schizophrenic",
+        Boolean,
         permitted_value_checker=BIT_CHECKER,
         comment="Delusions that are 'typically schizophrenic' (delusions "
-                "of control, influence or passivity, clearly referred to body "
-                "or limb movements or specific thoughts, actions, or "
-                "sensations; delusional perception; persistent delusions of "
-                "other kinds that are culturally inappropriate and completely "
-                "impossible)."
+        "of control, influence or passivity, clearly referred to body "
+        "or limb movements or specific thoughts, actions, or "
+        "sensations; delusional perception; persistent delusions of "
+        "other kinds that are culturally inappropriate and completely "
+        "impossible).",
     )
     delusions_other = CamcopsColumn(
-        "delusions_other", Boolean,
+        "delusions_other",
+        Boolean,
         permitted_value_checker=BIT_CHECKER,
-        comment="Delusions (of any other kind)."
+        comment="Delusions (of any other kind).",
     )
 
     date_pertains_to = Column(
-        "date_pertains_to", Date,
-        comment="Date the assessment pertains to"
-    )
-    comments = Column(
-        "comments", UnicodeText,
-        comment="Clinician's comments"
+        "date_pertains_to", Date, comment="Date the assessment pertains to"
     )
+    comments = Column("comments", UnicodeText, comment="Clinician's comments")
 
     CORE_NAMES = ["mood_elevated", "mood_irritable"]
     HYPOMANIA_MANIA_NAMES = [
-        "distractible", "activity", "sleep",
-        "talkativeness", "recklessness", "social_disinhibition", "sexual"
+        "distractible",
+        "activity",
+        "sleep",
+        "talkativeness",
+        "recklessness",
+        "social_disinhibition",
+        "sexual",
     ]
     MANIA_NAMES = ["grandiosity", "flight_of_ideas"]
     OTHER_CRITERIA_NAMES = [
-        "sustained4days", "sustained7days", "admission_required",
-        "some_interference_functioning", "severe_interference_functioning"
+        "sustained4days",
+        "sustained7days",
+        "admission_required",
+        "some_interference_functioning",
+        "severe_interference_functioning",
     ]
     PSYCHOSIS_NAMES = [
         "perceptual_alterations",  # not psychotic
-        "hallucinations_schizophrenic", "hallucinations_other",
-        "delusions_schizophrenic", "delusions_other"
+        "hallucinations_schizophrenic",
+        "hallucinations_other",
+        "delusions_schizophrenic",
+        "delusions_other",
     ]
 
     @staticmethod
@@ -248,26 +277,34 @@ class Icd10Manic(TaskHasClinicianMixin, TaskHasPatientMixin, Task):
     def get_clinical_text(self, req: CamcopsRequest) -> List[CtvInfo]:
         if not self.is_complete():
             return CTV_INCOMPLETE
-        infolist = [CtvInfo(
-            content="Pertains to: {}. Category: {}.".format(
-                format_datetime(self.date_pertains_to, DateFormat.LONG_DATE),
-                self.get_description(req)
+        infolist = [
+            CtvInfo(
+                content="Pertains to: {}. Category: {}.".format(
+                    format_datetime(
+                        self.date_pertains_to, DateFormat.LONG_DATE
+                    ),
+                    self.get_description(req),
+                )
             )
-        )]
+        ]
         if self.comments:
             infolist.append(CtvInfo(content=ws.webify(self.comments)))
         return infolist
 
     def get_summaries(self, req: CamcopsRequest) -> List[SummaryElement]:
         return self.standard_task_summary_fields() + [
-            SummaryElement(name="category",
-                           coltype=SummaryCategoryColType,
-                           value=self.get_description(req),
-                           comment="Diagnostic category"),
-            SummaryElement(name="psychotic_symptoms",
-                           coltype=Boolean(),
-                           value=self.psychosis_present(),
-                           comment="Psychotic symptoms present?"),
+            SummaryElement(
+                name="category",
+                coltype=SummaryCategoryColType,
+                value=self.get_description(req),
+                comment="Diagnostic category",
+            ),
+            SummaryElement(
+                name="psychotic_symptoms",
+                coltype=Boolean(),
+                value=self.psychosis_present(),
+                comment="Psychotic symptoms present?",
+            ),
         ]
 
     # Meets criteria? These also return null for unknown.
@@ -281,8 +318,10 @@ class Icd10Manic(TaskHasClinicianMixin, TaskHasPatientMixin, Task):
             return None  # might be manic psychosis
         if self.hallucinations_schizophrenic or self.delusions_schizophrenic:
             return True
-        if (self.hallucinations_schizophrenic is None or
-                self.delusions_schizophrenic is None):
+        if (
+            self.hallucinations_schizophrenic is None
+            or self.delusions_schizophrenic is None
+        ):
             return None
         return False
 
@@ -300,15 +339,19 @@ class Icd10Manic(TaskHasClinicianMixin, TaskHasPatientMixin, Task):
         x = self.meets_criteria_mania_ignoring_psychosis()
         if not x:
             return x
-        if (self.hallucinations_schizophrenic is None or
-                self.delusions_schizophrenic is None or
-                self.hallucinations_other is None or
-                self.delusions_other is None):
+        if (
+            self.hallucinations_schizophrenic is None
+            or self.delusions_schizophrenic is None
+            or self.hallucinations_other is None
+            or self.delusions_other is None
+        ):
             return None
-        if (self.hallucinations_schizophrenic or
-                self.delusions_schizophrenic or
-                self.hallucinations_other or
-                self.delusions_other):
+        if (
+            self.hallucinations_schizophrenic
+            or self.delusions_schizophrenic
+            or self.hallucinations_other
+            or self.delusions_other
+        ):
             return False
         return True
 
@@ -318,10 +361,12 @@ class Icd10Manic(TaskHasClinicianMixin, TaskHasPatientMixin, Task):
             return False
         if is_false(self.sustained7days) and is_false(self.admission_required):
             return False
-        t = self.count_booleans(self.HYPOMANIA_MANIA_NAMES) + \
-            self.count_booleans(self.MANIA_NAMES)
-        u = self.n_fields_none(self.HYPOMANIA_MANIA_NAMES) + \
-            self.n_fields_none(self.MANIA_NAMES)
+        t = self.count_booleans(
+            self.HYPOMANIA_MANIA_NAMES
+        ) + self.count_booleans(self.MANIA_NAMES)
+        u = self.n_fields_none(
+            self.HYPOMANIA_MANIA_NAMES
+        ) + self.n_fields_none(self.MANIA_NAMES)
         if self.mood_elevated and (t + u < 3):
             # With elevated mood, need at least 3 symptoms
             return False
@@ -331,11 +376,15 @@ class Icd10Manic(TaskHasClinicianMixin, TaskHasPatientMixin, Task):
         if is_false(self.severe_interference_functioning):
             return False
         # OK. When can we say "yes"?
-        if ((self.mood_elevated or self.mood_irritable) and
-                (self.sustained7days or self.admission_required) and
-                ((self.mood_elevated and t >= 3) or
-                    (self.mood_irritable and t >= 4)) and
-                self.severe_interference_functioning):
+        if (
+            (self.mood_elevated or self.mood_irritable)
+            and (self.sustained7days or self.admission_required)
+            and (
+                (self.mood_elevated and t >= 3)
+                or (self.mood_irritable and t >= 4)
+            )
+            and self.severe_interference_functioning
+        ):
             return True
         return None
 
@@ -355,10 +404,12 @@ class Icd10Manic(TaskHasClinicianMixin, TaskHasPatientMixin, Task):
         if is_false(self.some_interference_functioning):
             return False
         # OK. When can we say "yes"?
-        if ((self.mood_elevated or self.mood_irritable) and
-                self.sustained4days and
-                t >= 3 and
-                self.some_interference_functioning):
+        if (
+            (self.mood_elevated or self.mood_irritable)
+            and self.sustained4days
+            and t >= 3
+            and self.some_interference_functioning
+        ):
             return True
         return None
 
@@ -372,15 +423,19 @@ class Icd10Manic(TaskHasClinicianMixin, TaskHasPatientMixin, Task):
         return None
 
     def psychosis_present(self) -> Optional[bool]:
-        if (self.hallucinations_other or
-                self.hallucinations_schizophrenic or
-                self.delusions_other or
-                self.delusions_schizophrenic):
+        if (
+            self.hallucinations_other
+            or self.hallucinations_schizophrenic
+            or self.delusions_other
+            or self.delusions_schizophrenic
+        ):
             return True
-        if (self.hallucinations_other is None or
-                self.hallucinations_schizophrenic is None or
-                self.delusions_other is None or
-                self.delusions_schizophrenic is None):
+        if (
+            self.hallucinations_other is None
+            or self.hallucinations_schizophrenic is None
+            or self.delusions_other is None
+            or self.delusions_schizophrenic is None
+        ):
             return None
         return False
 
@@ -400,9 +455,9 @@ class Icd10Manic(TaskHasClinicianMixin, TaskHasPatientMixin, Task):
 
     def is_complete(self) -> bool:
         return (
-            self.date_pertains_to is not None and
-            self.meets_criteria_none() is not None and
-            self.field_contents_valid()
+            self.date_pertains_to is not None
+            and self.meets_criteria_none() is not None
+            and self.field_contents_valid()
         )
 
     def text_row(self, req: CamcopsRequest, wstringname: str) -> str:
@@ -410,7 +465,8 @@ class Icd10Manic(TaskHasClinicianMixin, TaskHasPatientMixin, Task):
 
     def row_true_false(self, req: CamcopsRequest, fieldname: str) -> str:
         return self.get_twocol_bool_row_true_false(
-            req, fieldname, self.wxstring(req, "" + fieldname))
+            req, fieldname, self.wxstring(req, "" + fieldname)
+        )
 
     def get_task_html(self, req: CamcopsRequest) -> str:
         h = """
@@ -433,24 +489,27 @@ class Icd10Manic(TaskHasClinicianMixin, TaskHasPatientMixin, Task):
                 </tr>
         """.format(
             clinician_comments=self.get_standard_clinician_comments_block(
-                req, self.comments),
+                req, self.comments
+            ),
             CssClass=CssClass,
             tr_is_complete=self.get_is_complete_tr(req),
             date_pertains_to=tr_qa(
                 req.wappstring(AS.DATE_PERTAINS_TO),
-                format_datetime(self.date_pertains_to,
-                                DateFormat.LONG_DATE, default=None)
+                format_datetime(
+                    self.date_pertains_to, DateFormat.LONG_DATE, default=None
+                ),
             ),
             category=tr_qa(
                 req.sstring(SS.CATEGORY) + " <sup>[1,2]</sup>",
-                self.get_description(req)
+                self.get_description(req),
             ),
             psychotic_symptoms=tr_qa(
                 self.wxstring(req, "psychotic_symptoms") + " <sup>[2]</sup>",
-                get_present_absent_none(req, self.psychosis_present())
+                get_present_absent_none(req, self.psychosis_present()),
             ),
             icd10_symptomatic_disclaimer=req.wappstring(
-                AS.ICD10_SYMPTOMATIC_DISCLAIMER),
+                AS.ICD10_SYMPTOMATIC_DISCLAIMER
+            ),
         )
 
         h += self.text_row(req, "core")
