@@ -27,6 +27,10 @@ camcops_server/tasks/khandaker_insight_medical.py
 
 """
 
+# =============================================================================
+# Imports
+# =============================================================================
+
 from typing import Any, Dict, Tuple, Type
 
 import cardinal_pythonlib.rnc_web as ws
@@ -45,6 +49,11 @@ from camcops_server.cc_modules.cc_sqla_coltypes import BoolColumn
 from camcops_server.cc_modules.cc_task import Task, TaskHasPatientMixin
 
 
+# =============================================================================
+# Constants
+# =============================================================================
+
+
 class KQInfo(object):
     def __init__(self, stem: str, heading_xml: str = "") -> None:
         self.fieldname_yn = stem + "_yn"
@@ -88,24 +97,32 @@ X_COMMENT_HINT = "comment_hint"
 # Khandaker_1_MedicalHistory
 # =============================================================================
 
+
 class KhandakerInsightMedicalMetaclass(DeclarativeMeta):
     # noinspection PyInitNewSignature
-    def __init__(cls: Type['KhandakerInsightMedical'],
-                 name: str,
-                 bases: Tuple[Type, ...],
-                 classdict: Dict[str, Any]) -> None:
+    def __init__(
+        cls: Type["KhandakerInsightMedical"],
+        name: str,
+        bases: Tuple[Type, ...],
+        classdict: Dict[str, Any],
+    ) -> None:
         for qinfo in QUESTIONS:
             setattr(cls, qinfo.fieldname_yn, BoolColumn(qinfo.fieldname_yn))
-            setattr(cls, qinfo.fieldname_comment,
-                    Column(qinfo.fieldname_comment, UnicodeText))
+            setattr(
+                cls,
+                qinfo.fieldname_comment,
+                Column(qinfo.fieldname_comment, UnicodeText),
+            )
         super().__init__(name, bases, classdict)
 
 
-class KhandakerInsightMedical(TaskHasPatientMixin, Task,
-                              metaclass=KhandakerInsightMedicalMetaclass):
+class KhandakerInsightMedical(
+    TaskHasPatientMixin, Task, metaclass=KhandakerInsightMedicalMetaclass
+):
     """
     Server implementation of the Khandaker_1_MedicalHistory task.
     """
+
     __tablename__ = "khandaker_1_medicalhistory"  # NB historical name
     shortname = "Khandaker_Insight_Medical"
     info_filename_stem = "khandaker_insight_medical"
