@@ -78,15 +78,22 @@ WORDLIST = ["FACE", "VELVET", "CHURCH", "DAISY", "RED"]
 # MoCA
 # =============================================================================
 
+
 class MocaMetaclass(DeclarativeMeta):
     # noinspection PyInitNewSignature
-    def __init__(cls: Type['Moca'],
-                 name: str,
-                 bases: Tuple[Type, ...],
-                 classdict: Dict[str, Any]) -> None:
+    def __init__(
+        cls: Type["Moca"],
+        name: str,
+        bases: Tuple[Type, ...],
+        classdict: Dict[str, Any],
+    ) -> None:
         add_multiple_columns(
-            cls, "q", 1, cls.NQUESTIONS,
-            minimum=0, maximum=1,  # see below
+            cls,
+            "q",
+            1,
+            cls.NQUESTIONS,
+            minimum=0,
+            maximum=1,  # see below
             comment_fmt="{s}",
             comment_strings=[
                 "Q1 (VSE/path) (0-1)",
@@ -117,48 +124,62 @@ class MocaMetaclass(DeclarativeMeta):
                 "Q26 (orientation/day) (0-1)",
                 "Q27 (orientation/place) (0-1)",
                 "Q28 (orientation/city) (0-1)",
-            ]
+            ],
         )
         # Fix maximum for Q12:
         # noinspection PyUnresolvedReferences
         cls.q12.set_permitted_value_checker(ZERO_TO_THREE_CHECKER)
 
         add_multiple_columns(
-            cls, "register_trial1_", 1, 5,
+            cls,
+            "register_trial1_",
+            1,
+            5,
             pv=PV.BIT,
             comment_fmt="Registration, trial 1 (not scored), {n}: {s} "
-                        "(0 or 1)",
-            comment_strings=WORDLIST
+            "(0 or 1)",
+            comment_strings=WORDLIST,
         )
         add_multiple_columns(
-            cls, "register_trial2_", 1, 5,
+            cls,
+            "register_trial2_",
+            1,
+            5,
             pv=PV.BIT,
             comment_fmt="Registration, trial 2 (not scored), {n}: {s} "
-                        "(0 or 1)",
-            comment_strings=WORDLIST
+            "(0 or 1)",
+            comment_strings=WORDLIST,
         )
         add_multiple_columns(
-            cls, "recall_category_cue_", 1, 5,
+            cls,
+            "recall_category_cue_",
+            1,
+            5,
             pv=PV.BIT,
             comment_fmt="Recall with category cue (not scored), {n}: {s} "
-                        "(0 or 1)",
-            comment_strings=WORDLIST
+            "(0 or 1)",
+            comment_strings=WORDLIST,
         )
         add_multiple_columns(
-            cls, "recall_mc_cue_", 1, 5,
+            cls,
+            "recall_mc_cue_",
+            1,
+            5,
             pv=PV.BIT,
             comment_fmt="Recall with multiple-choice cue (not scored), "
-                        "{n}: {s} (0 or 1)",
-            comment_strings=WORDLIST
+            "{n}: {s} (0 or 1)",
+            comment_strings=WORDLIST,
         )
         super().__init__(name, bases, classdict)
 
 
-class Moca(TaskHasPatientMixin, TaskHasClinicianMixin, Task,
-           metaclass=MocaMetaclass):
+class Moca(
+    TaskHasPatientMixin, TaskHasClinicianMixin, Task, metaclass=MocaMetaclass
+):
     """
     Server implementation of the MoCA task.
     """
+
     __tablename__ = "moca"
     shortname = "MoCA"
     provides_trackers = True
@@ -167,33 +188,43 @@ class Moca(TaskHasPatientMixin, TaskHasClinicianMixin, Task,
     prohibits_research = True
 
     education12y_or_less = CamcopsColumn(
-        "education12y_or_less", Integer,
+        "education12y_or_less",
+        Integer,
         permitted_value_checker=BIT_CHECKER,
-        comment="<=12 years of education (0 no, 1 yes)"
+        comment="<=12 years of education (0 no, 1 yes)",
     )
     trailpicture_blobid = CamcopsColumn(
-        "trailpicture_blobid", Integer,
-        is_blob_id_field=True, blob_relationship_attr_name="trailpicture",
-        comment="BLOB ID of trail picture"
+        "trailpicture_blobid",
+        Integer,
+        is_blob_id_field=True,
+        blob_relationship_attr_name="trailpicture",
+        comment="BLOB ID of trail picture",
     )
     cubepicture_blobid = CamcopsColumn(
-        "cubepicture_blobid", Integer,
-        is_blob_id_field=True, blob_relationship_attr_name="cubepicture",
-        comment="BLOB ID of cube picture"
+        "cubepicture_blobid",
+        Integer,
+        is_blob_id_field=True,
+        blob_relationship_attr_name="cubepicture",
+        comment="BLOB ID of cube picture",
     )
     clockpicture_blobid = CamcopsColumn(
-        "clockpicture_blobid", Integer,
-        is_blob_id_field=True, blob_relationship_attr_name="clockpicture",
-        comment="BLOB ID of clock picture"
-    )
-    comments = Column(
-        "comments", UnicodeText,
-        comment="Clinician's comments"
+        "clockpicture_blobid",
+        Integer,
+        is_blob_id_field=True,
+        blob_relationship_attr_name="clockpicture",
+        comment="BLOB ID of clock picture",
     )
+    comments = Column("comments", UnicodeText, comment="Clinician's comments")
 
-    trailpicture = blob_relationship("Moca", "trailpicture_blobid")  # type: Optional[Blob]  # noqa
-    cubepicture = blob_relationship("Moca", "cubepicture_blobid")  # type: Optional[Blob]  # noqa
-    clockpicture = blob_relationship("Moca", "clockpicture_blobid")  # type: Optional[Blob]  # noqa
+    trailpicture = blob_relationship(
+        "Moca", "trailpicture_blobid"
+    )  # type: Optional[Blob]  # noqa
+    cubepicture = blob_relationship(
+        "Moca", "cubepicture_blobid"
+    )  # type: Optional[Blob]  # noqa
+    clockpicture = blob_relationship(
+        "Moca", "clockpicture_blobid"
+    )  # type: Optional[Blob]  # noqa
 
     NQUESTIONS = 28
     MAX_SCORE = 30
@@ -213,44 +244,55 @@ class Moca(TaskHasPatientMixin, TaskHasClinicianMixin, Task,
         return _("Montreal Cognitive Assessment")
 
     def get_trackers(self, req: CamcopsRequest) -> List[TrackerInfo]:
-        return [TrackerInfo(
-            value=self.total_score(),
-            plot_label="MOCA total score",
-            axis_label=f"Total score (out of {self.MAX_SCORE})",
-            axis_min=-0.5,
-            axis_max=(self.MAX_SCORE + 0.5),
-            horizontal_lines=[25.5],
-            horizontal_labels=[
-                TrackerLabel(26, req.sstring(SS.NORMAL),
-                             LabelAlignment.bottom),
-                TrackerLabel(25, req.sstring(SS.ABNORMAL),
-                             LabelAlignment.top),
-            ]
-        )]
+        return [
+            TrackerInfo(
+                value=self.total_score(),
+                plot_label="MOCA total score",
+                axis_label=f"Total score (out of {self.MAX_SCORE})",
+                axis_min=-0.5,
+                axis_max=(self.MAX_SCORE + 0.5),
+                horizontal_lines=[25.5],
+                horizontal_labels=[
+                    TrackerLabel(
+                        26, req.sstring(SS.NORMAL), LabelAlignment.bottom
+                    ),
+                    TrackerLabel(
+                        25, req.sstring(SS.ABNORMAL), LabelAlignment.top
+                    ),
+                ],
+            )
+        ]
 
     def get_clinical_text(self, req: CamcopsRequest) -> List[CtvInfo]:
         if not self.is_complete():
             return CTV_INCOMPLETE
-        return [CtvInfo(
-            content=f"MOCA total score {self.total_score()}/{self.MAX_SCORE}"
-        )]
+        return [
+            CtvInfo(
+                content=f"MOCA total score "
+                f"{self.total_score()}/{self.MAX_SCORE}"
+            )
+        ]
 
     def get_summaries(self, req: CamcopsRequest) -> List[SummaryElement]:
         return self.standard_task_summary_fields() + [
-            SummaryElement(name="total",
-                           coltype=Integer(),
-                           value=self.total_score(),
-                           comment=f"Total score (/{self.MAX_SCORE})"),
-            SummaryElement(name="category",
-                           coltype=String(50),
-                           value=self.category(req),
-                           comment="Categorization"),
+            SummaryElement(
+                name="total",
+                coltype=Integer(),
+                value=self.total_score(),
+                comment=f"Total score (/{self.MAX_SCORE})",
+            ),
+            SummaryElement(
+                name="category",
+                coltype=String(50),
+                value=self.category(req),
+                comment="Categorization",
+            ),
         ]
 
     def is_complete(self) -> bool:
         return (
-            self.all_fields_not_none(self.QFIELDS) and
-            self.field_contents_valid()
+            self.all_fields_not_none(self.QFIELDS)
+            and self.field_contents_valid()
         )
 
     def total_score(self) -> int:
@@ -286,8 +328,11 @@ class Moca(TaskHasPatientMixin, TaskHasClinicianMixin, Task,
 
     def category(self, req: CamcopsRequest) -> str:
         totalscore = self.total_score()
-        return (req.sstring(SS.NORMAL) if totalscore >= 26
-                else req.sstring(SS.ABNORMAL))
+        return (
+            req.sstring(SS.NORMAL)
+            if totalscore >= 26
+            else req.sstring(SS.ABNORMAL)
+        )
 
     # noinspection PyUnresolvedReferences
     def get_task_html(self, req: CamcopsRequest) -> str:
@@ -317,53 +362,80 @@ class Moca(TaskHasPatientMixin, TaskHasClinicianMixin, Task,
                 </tr>
         """.format(
             clinician_comments=self.get_standard_clinician_comments_block(
-                req, self.comments),
+                req, self.comments
+            ),
             CssClass=CssClass,
             tr_is_complete=self.get_is_complete_tr(req),
             total_score=tr(
                 req.sstring(SS.TOTAL_SCORE),
-                answer(totalscore) + f" / {self.MAX_SCORE}"
+                answer(totalscore) + f" / {self.MAX_SCORE}",
+            ),
+            category=tr_qa(
+                self.wxstring(req, "category") + " <sup>[1]</sup>", category
             ),
-            category=tr_qa(self.wxstring(req, "category") + " <sup>[1]</sup>",
-                           category),
         )
 
-        h += tr(self.wxstring(req, "subscore_visuospatial"),
-                answer(vsp) + " / 5",
-                tr_class=CssClass.SUBHEADING)
-        h += tr("Path, cube, clock/contour, clock/numbers, clock/hands",
-                ", ".join(answer(x) for x in (self.q1, self.q2, self.q3,
-                                              self.q4, self.q5)))
+        h += tr(
+            self.wxstring(req, "subscore_visuospatial"),
+            answer(vsp) + " / 5",
+            tr_class=CssClass.SUBHEADING,
+        )
+        h += tr(
+            "Path, cube, clock/contour, clock/numbers, clock/hands",
+            ", ".join(
+                answer(x)
+                for x in (self.q1, self.q2, self.q3, self.q4, self.q5)
+            ),
+        )
 
-        h += tr(self.wxstring(req, "subscore_naming"),
-                answer(naming) + " / 3",
-                tr_class=CssClass.SUBHEADING)
-        h += tr("Lion, rhino, camel",
-                ", ".join(answer(x) for x in (self.q6, self.q7, self.q8)))
+        h += tr(
+            self.wxstring(req, "subscore_naming"),
+            answer(naming) + " / 3",
+            tr_class=CssClass.SUBHEADING,
+        )
+        h += tr(
+            "Lion, rhino, camel",
+            ", ".join(answer(x) for x in (self.q6, self.q7, self.q8)),
+        )
 
-        h += tr(self.wxstring(req, "subscore_attention"),
-                answer(attention) + " / 6",
-                tr_class=CssClass.SUBHEADING)
-        h += tr("5 digits forwards, 3 digits backwards, tapping, serial 7s "
-                "[<i>scores 3</i>]",
-                ", ".join(answer(x) for x in (self.q9, self.q10, self.q11,
-                                              self.q12)))
+        h += tr(
+            self.wxstring(req, "subscore_attention"),
+            answer(attention) + " / 6",
+            tr_class=CssClass.SUBHEADING,
+        )
+        h += tr(
+            "5 digits forwards, 3 digits backwards, tapping, serial 7s "
+            "[<i>scores 3</i>]",
+            ", ".join(
+                answer(x) for x in (self.q9, self.q10, self.q11, self.q12)
+            ),
+        )
 
-        h += tr(self.wxstring(req, "subscore_language"),
-                answer(language) + " / 3",
-                tr_class=CssClass.SUBHEADING)
-        h += tr("Repeat sentence 1, repeat sentence 2, fluency to letter ‘F’",
-                ", ".join(answer(x) for x in (self.q13, self.q14, self.q15)))
+        h += tr(
+            self.wxstring(req, "subscore_language"),
+            answer(language) + " / 3",
+            tr_class=CssClass.SUBHEADING,
+        )
+        h += tr(
+            "Repeat sentence 1, repeat sentence 2, fluency to letter ‘F’",
+            ", ".join(answer(x) for x in (self.q13, self.q14, self.q15)),
+        )
 
-        h += tr(self.wxstring(req, "subscore_abstraction"),
-                answer(abstraction) + " / 2",
-                tr_class=CssClass.SUBHEADING)
-        h += tr("Means of transportation, measuring instruments",
-                ", ".join(answer(x) for x in (self.q16, self.q17)))
+        h += tr(
+            self.wxstring(req, "subscore_abstraction"),
+            answer(abstraction) + " / 2",
+            tr_class=CssClass.SUBHEADING,
+        )
+        h += tr(
+            "Means of transportation, measuring instruments",
+            ", ".join(answer(x) for x in (self.q16, self.q17)),
+        )
 
-        h += tr(self.wxstring(req, "subscore_memory"),
-                answer(memory) + " / 5",
-                tr_class=CssClass.SUBHEADING)
+        h += tr(
+            self.wxstring(req, "subscore_memory"),
+            answer(memory) + " / 5",
+            tr_class=CssClass.SUBHEADING,
+        )
         h += tr(
             "Registered on first trial [<i>not scored</i>]",
             ", ".join(
@@ -373,9 +445,9 @@ class Moca(TaskHasPatientMixin, TaskHasClinicianMixin, Task,
                     self.register_trial1_2,
                     self.register_trial1_3,
                     self.register_trial1_4,
-                    self.register_trial1_5
+                    self.register_trial1_5,
                 )
-            )
+            ),
         )
         h += tr(
             "Registered on second trial [<i>not scored</i>]",
@@ -386,17 +458,16 @@ class Moca(TaskHasPatientMixin, TaskHasClinicianMixin, Task,
                     self.register_trial2_2,
                     self.register_trial2_3,
                     self.register_trial2_4,
-                    self.register_trial2_5
+                    self.register_trial2_5,
                 )
-            )
+            ),
         )
         h += tr(
             "Recall FACE, VELVET, CHURCH, DAISY, RED with no cue",
             ", ".join(
-                answer(x) for x in (
-                    self.q18, self.q19, self.q20, self.q21, self.q22
-                )
-            )
+                answer(x)
+                for x in (self.q18, self.q19, self.q20, self.q21, self.q22)
+            ),
         )
         h += tr(
             "Recall with category cue [<i>not scored</i>]",
@@ -407,9 +478,9 @@ class Moca(TaskHasPatientMixin, TaskHasClinicianMixin, Task,
                     self.recall_category_cue_2,
                     self.recall_category_cue_3,
                     self.recall_category_cue_4,
-                    self.recall_category_cue_5
+                    self.recall_category_cue_5,
                 )
-            )
+            ),
         )
         h += tr(
             "Recall with multiple-choice cue [<i>not scored</i>]",
@@ -420,21 +491,29 @@ class Moca(TaskHasPatientMixin, TaskHasClinicianMixin, Task,
                     self.recall_mc_cue_2,
                     self.recall_mc_cue_3,
                     self.recall_mc_cue_4,
-                    self.recall_mc_cue_5
+                    self.recall_mc_cue_5,
                 )
-            )
+            ),
         )
 
-        h += tr(self.wxstring(req, "subscore_orientation"),
-                answer(orientation) + " / 6",
-                tr_class=CssClass.SUBHEADING)
+        h += tr(
+            self.wxstring(req, "subscore_orientation"),
+            answer(orientation) + " / 6",
+            tr_class=CssClass.SUBHEADING,
+        )
         h += tr(
             "Date, month, year, day, place, city",
             ", ".join(
-                answer(x) for x in (
-                    self.q23, self.q24, self.q25, self.q26, self.q27, self.q28
+                answer(x)
+                for x in (
+                    self.q23,
+                    self.q24,
+                    self.q25,
+                    self.q26,
+                    self.q27,
+                    self.q28,
                 )
-            )
+            ),
         )
 
         h += subheading_spanning_two_columns(self.wxstring(req, "education_s"))
@@ -463,18 +542,27 @@ class Moca(TaskHasPatientMixin, TaskHasClinicianMixin, Task,
         """.format(
             CssClass=CssClass,
             tr_subhead_images=subheading_spanning_two_columns(
-                "Images of tests: trail, cube, clock",
-                th_not_td=True),
+                "Images of tests: trail, cube, clock", th_not_td=True
+            ),
             tr_images_1=tr(
-                td(get_blob_img_html(self.trailpicture),
-                   td_class=CssClass.PHOTO, td_width="50%"),
-                td(get_blob_img_html(self.cubepicture),
-                   td_class=CssClass.PHOTO, td_width="50%"),
+                td(
+                    get_blob_img_html(self.trailpicture),
+                    td_class=CssClass.PHOTO,
+                    td_width="50%",
+                ),
+                td(
+                    get_blob_img_html(self.cubepicture),
+                    td_class=CssClass.PHOTO,
+                    td_width="50%",
+                ),
                 literal=True,
             ),
             tr_images_2=tr(
-                td(get_blob_img_html(self.clockpicture),
-                   td_class=CssClass.PHOTO, td_width="50%"),
+                td(
+                    get_blob_img_html(self.clockpicture),
+                    td_class=CssClass.PHOTO,
+                    td_width="50%",
+                ),
                 td("", td_class=CssClass.SUBHEADING),
                 literal=True,
             ),
@@ -482,12 +570,16 @@ class Moca(TaskHasPatientMixin, TaskHasClinicianMixin, Task,
         return h
 
     def get_snomed_codes(self, req: CamcopsRequest) -> List[SnomedExpression]:
-        codes = [SnomedExpression(req.snomed(SnomedLookup.MOCA_PROCEDURE_ASSESSMENT))]  # noqa
+        codes = [
+            SnomedExpression(
+                req.snomed(SnomedLookup.MOCA_PROCEDURE_ASSESSMENT)
+            )
+        ]
         if self.is_complete():
-            codes.append(SnomedExpression(
-                req.snomed(SnomedLookup.MOCA_SCALE),
-                {
-                    req.snomed(SnomedLookup.MOCA_SCORE): self.total_score(),
-                }
-            ))
+            codes.append(
+                SnomedExpression(
+                    req.snomed(SnomedLookup.MOCA_SCALE),
+                    {req.snomed(SnomedLookup.MOCA_SCORE): self.total_score()},
+                )
+            )
         return codes
