@@ -57,17 +57,24 @@ from camcops_server.cc_modules.cc_trackerhelpers import (
 # PHQ-15
 # =============================================================================
 
+
 class Phq15Metaclass(DeclarativeMeta):
     # noinspection PyInitNewSignature
-    def __init__(cls: Type['Phq15'],
-                 name: str,
-                 bases: Tuple[Type, ...],
-                 classdict: Dict[str, Any]) -> None:
+    def __init__(
+        cls: Type["Phq15"],
+        name: str,
+        bases: Tuple[Type, ...],
+        classdict: Dict[str, Any],
+    ) -> None:
         add_multiple_columns(
-            cls, "q", 1, cls.NQUESTIONS,
-            minimum=0, maximum=2,
+            cls,
+            "q",
+            1,
+            cls.NQUESTIONS,
+            minimum=0,
+            maximum=2,
             comment_fmt="Q{n} ({s}) (0 not bothered at all - "
-                        "2 bothered a lot)",
+            "2 bothered a lot)",
             comment_strings=[
                 "stomach pain",
                 "back pain",
@@ -84,16 +91,16 @@ class Phq15Metaclass(DeclarativeMeta):
                 "nausea/indigestion",
                 "energy",
                 "sleep",
-            ]
+            ],
         )
         super().__init__(name, bases, classdict)
 
 
-class Phq15(TaskHasPatientMixin, Task,
-            metaclass=Phq15Metaclass):
+class Phq15(TaskHasPatientMixin, Task, metaclass=Phq15Metaclass):
     """
     Server implementation of the PHQ-15 task.
     """
+
     __tablename__ = "phq15"
     shortname = "PHQ-15"
     provides_trackers = True
@@ -124,39 +131,49 @@ class Phq15(TaskHasPatientMixin, Task,
             return True
 
     def get_trackers(self, req: CamcopsRequest) -> List[TrackerInfo]:
-        return [TrackerInfo(
-            value=self.total_score(),
-            plot_label="PHQ-15 total score (rating somatic symptoms)",
-            axis_label=f"Score for Q1-15 (out of {self.MAX_TOTAL})",
-            axis_min=-0.5,
-            axis_max=self.MAX_TOTAL + 0.5,
-            horizontal_lines=[14.5, 9.5, 4.5],
-            horizontal_labels=[
-                TrackerLabel(22, req.sstring(SS.SEVERE)),
-                TrackerLabel(12, req.sstring(SS.MODERATE)),
-                TrackerLabel(7, req.sstring(SS.MILD)),
-                TrackerLabel(2.25, req.sstring(SS.NONE)),
-            ]
-        )]
+        return [
+            TrackerInfo(
+                value=self.total_score(),
+                plot_label="PHQ-15 total score (rating somatic symptoms)",
+                axis_label=f"Score for Q1-15 (out of {self.MAX_TOTAL})",
+                axis_min=-0.5,
+                axis_max=self.MAX_TOTAL + 0.5,
+                horizontal_lines=[14.5, 9.5, 4.5],
+                horizontal_labels=[
+                    TrackerLabel(22, req.sstring(SS.SEVERE)),
+                    TrackerLabel(12, req.sstring(SS.MODERATE)),
+                    TrackerLabel(7, req.sstring(SS.MILD)),
+                    TrackerLabel(2.25, req.sstring(SS.NONE)),
+                ],
+            )
+        ]
 
     def get_clinical_text(self, req: CamcopsRequest) -> List[CtvInfo]:
         if not self.is_complete():
             return CTV_INCOMPLETE
-        return [CtvInfo(content=(
-            f"PHQ-15 total score {self.total_score()}/{self.MAX_TOTAL} "
-            f"({self.severity( req)})"
-        ))]
+        return [
+            CtvInfo(
+                content=(
+                    f"PHQ-15 total score {self.total_score()}/{self.MAX_TOTAL} "  # noqa: E501
+                    f"({self.severity( req)})"
+                )
+            )
+        ]
 
     def get_summaries(self, req: CamcopsRequest) -> List[SummaryElement]:
         return self.standard_task_summary_fields() + [
-            SummaryElement(name="total",
-                           coltype=Integer(),
-                           value=self.total_score(),
-                           comment=f"Total score (/{self.MAX_TOTAL})"),
-            SummaryElement(name="severity",
-                           coltype=SummaryCategoryColType,
-                           value=self.severity(req),
-                           comment="Severity"),
+            SummaryElement(
+                name="total",
+                coltype=Integer(),
+                value=self.total_score(),
+                comment=f"Total score (/{self.MAX_TOTAL})",
+            ),
+            SummaryElement(
+                name="severity",
+                coltype=SummaryCategoryColType,
+                value=self.severity(req),
+                comment="Severity",
+            ),
         ]
 
     def total_score(self) -> int:
@@ -188,13 +205,14 @@ class Phq15(TaskHasPatientMixin, Task,
         severity = self.severity(req)
         answer_dict = {None: None}
         for option in range(0, 3):
-            answer_dict[option] = str(option) + " – " + \
-                self.wxstring(req, "a" + str(option))
+            answer_dict[option] = (
+                str(option) + " – " + self.wxstring(req, "a" + str(option))
+            )
         q_a = ""
         for q in range(1, self.NQUESTIONS + 1):
             q_a += tr_qa(
                 self.wxstring(req, "q" + str(q)),
-                get_from_dict(answer_dict, getattr(self, "q" + str(q)))
+                get_from_dict(answer_dict, getattr(self, "q" + str(q))),
             )
         h = """
             <div class="{CssClass.SUMMARY}">
@@ -225,20 +243,20 @@ class Phq15(TaskHasPatientMixin, Task,
             tr_is_complete=self.get_is_complete_tr(req),
             total_score=tr(
                 req.sstring(SS.TOTAL_SCORE) + " <sup>[1]</sup>",
-                answer(score) + f" / {self.MAX_TOTAL}"
+                answer(score) + f" / {self.MAX_TOTAL}",
             ),
             n_severe_symptoms=tr_qa(
                 self.wxstring(req, "n_severe_symptoms") + " <sup>[2]</sup>",
-                nsevere
+                nsevere,
             ),
             exceeds_somatoform_cutoff=tr_qa(
-                self.wxstring(req, "exceeds_somatoform_cutoff") +
-                " <sup>[3]</sup>",
-                get_yes_no(req, somatoform_likely)
+                self.wxstring(req, "exceeds_somatoform_cutoff")
+                + " <sup>[3]</sup>",
+                get_yes_no(req, somatoform_likely),
             ),
             symptom_severity=tr_qa(
                 self.wxstring(req, "symptom_severity") + " <sup>[4]</sup>",
-                severity
+                severity,
             ),
             q_a=q_a,
         )
