@@ -50,14 +50,20 @@ from camcops_server.cc_modules.cc_text import SS
 
 class ShapsMetaclass(DeclarativeMeta):
     # noinspection PyInitNewSignature
-    def __init__(cls: Type['Shaps'],
-                 name: str,
-                 bases: Tuple[Type, ...],
-                 classdict: Dict[str, Any]) -> None:
+    def __init__(
+        cls: Type["Shaps"],
+        name: str,
+        bases: Tuple[Type, ...],
+        classdict: Dict[str, Any],
+    ) -> None:
 
         add_multiple_columns(
-            cls, "q", 1, cls.N_QUESTIONS,
-            minimum=0, maximum=3,
+            cls,
+            "q",
+            1,
+            cls.N_QUESTIONS,
+            minimum=0,
+            maximum=3,
             comment_fmt="Q{n} - {s}",
             comment_strings=[
                 "television",
@@ -74,15 +80,13 @@ class ShapsMetaclass(DeclarativeMeta):
                 "landscape",
                 "helping",
                 "praise",
-            ]
+            ],
         )
 
         super().__init__(name, bases, classdict)
 
 
-class Shaps(TaskHasPatientMixin,
-            Task,
-            metaclass=ShapsMetaclass):
+class Shaps(TaskHasPatientMixin, Task, metaclass=ShapsMetaclass):
     __tablename__ = "shaps"
     shortname = "SHAPS"
 
@@ -108,9 +112,11 @@ class Shaps(TaskHasPatientMixin,
     def get_summaries(self, req: CamcopsRequest) -> List[SummaryElement]:
         return self.standard_task_summary_fields() + [
             SummaryElement(
-                name="total", coltype=Integer(),
+                name="total",
+                coltype=Integer(),
                 value=self.total_score(),
-                comment=f"Total score (/{self.MAX_SCORE})"),
+                comment=f"Total score (/{self.MAX_SCORE})",
+            )
         ]
 
     def is_complete(self) -> bool:
@@ -122,8 +128,9 @@ class Shaps(TaskHasPatientMixin,
 
     def total_score(self) -> int:
         # Consistent with client implementation
-        return self.count_where(self.ALL_QUESTIONS,
-                                [self.STRONGLY_DISAGREE, self.DISAGREE])
+        return self.count_where(
+            self.ALL_QUESTIONS, [self.STRONGLY_DISAGREE, self.DISAGREE]
+        )
 
     def get_task_html(self, req: CamcopsRequest) -> str:
         strongly_disagree = self.wxstring(req, "strongly_disagree")
@@ -136,18 +143,18 @@ class Shaps(TaskHasPatientMixin,
             self.STRONGLY_DISAGREE: "1 — " + strongly_disagree,
             self.DISAGREE: "1 — " + disagree,
             self.AGREE: "0 — " + agree,
-            self.STRONGLY_OR_DEFINITELY_AGREE: "0 — " + self.wxstring(
-                req, "strongly_agree")
+            self.STRONGLY_OR_DEFINITELY_AGREE: "0 — "
+            + self.wxstring(req, "strongly_agree"),
         }
 
         # Subtle difference in wording when options presented in reverse
         reverse_answer_dict = {
             None: None,
-            self.STRONGLY_OR_DEFINITELY_AGREE: "0 — " + self.wxstring(
-                req, "definitely_agree"),
+            self.STRONGLY_OR_DEFINITELY_AGREE: "0 — "
+            + self.wxstring(req, "definitely_agree"),
             self.AGREE: "0 — " + agree,
             self.DISAGREE: "1 — " + disagree,
-            self.STRONGLY_DISAGREE: "1 — " + strongly_disagree
+            self.STRONGLY_DISAGREE: "1 — " + strongly_disagree,
         }
 
         rows = ""
@@ -186,10 +193,7 @@ class Shaps(TaskHasPatientMixin,
             tr_is_complete=self.get_is_complete_tr(req),
             total_score=tr(
                 req.sstring(SS.TOTAL_SCORE) + " <sup>[1]</sup>",
-                "{} / {}".format(
-                    answer(self.total_score()),
-                    self.MAX_SCORE
-                )
+                "{} / {}".format(answer(self.total_score()), self.MAX_SCORE),
             ),
             rows=rows,
         )
