@@ -79,155 +79,198 @@ class Slums(TaskHasClinicianMixin, TaskHasPatientMixin, Task):
     """
     Server implementation of the SLUMS task.
     """
+
     __tablename__ = "slums"
     shortname = "SLUMS"
     provides_trackers = True
 
     alert = CamcopsColumn(
-        "alert", Integer,
+        "alert",
+        Integer,
         permitted_value_checker=BIT_CHECKER,
-        comment="Is the patient alert? (0 no, 1 yes)")
+        comment="Is the patient alert? (0 no, 1 yes)",
+    )
     highschooleducation = CamcopsColumn(
-        "highschooleducation", Integer,
+        "highschooleducation",
+        Integer,
         permitted_value_checker=BIT_CHECKER,
         comment="Does that patient have at least a high-school level of "
-                "education? (0 no, 1 yes)"
+        "education? (0 no, 1 yes)",
     )
 
     q1 = CamcopsColumn(
-        "q1", Integer,
+        "q1",
+        Integer,
         permitted_value_checker=BIT_CHECKER,
-        comment="Q1 (day) (0-1)"
+        comment="Q1 (day) (0-1)",
     )
     q2 = CamcopsColumn(
-        "q2", Integer,
+        "q2",
+        Integer,
         permitted_value_checker=BIT_CHECKER,
-        comment="Q2 (year) (0-1)"
+        comment="Q2 (year) (0-1)",
     )
     q3 = CamcopsColumn(
-        "q3", Integer,
+        "q3",
+        Integer,
         permitted_value_checker=BIT_CHECKER,
-        comment="Q3 (state) (0-1)"
+        comment="Q3 (state) (0-1)",
     )
     q5a = CamcopsColumn(
-        "q5a", Integer,
+        "q5a",
+        Integer,
         permitted_value_checker=BIT_CHECKER,
-        comment="Q5a (money spent) (0-1)"
+        comment="Q5a (money spent) (0-1)",
     )
     q5b = CamcopsColumn(
-        "q5b", Integer,
+        "q5b",
+        Integer,
         permitted_value_checker=ZERO_OR_TWO_CHECKER,
-        comment="Q5b (money left) (0 or 2)"
+        comment="Q5b (money left) (0 or 2)",
     )  # worth 2 points
     q6 = CamcopsColumn(
-        "q6", Integer,
+        "q6",
+        Integer,
         permitted_value_checker=ZERO_TO_THREE_CHECKER,
-        comment="Q6 (animal naming) (0-3)"
+        comment="Q6 (animal naming) (0-3)",
     )  # from 0 to 3 points
     q7a = CamcopsColumn(
-        "q7a", Integer,
+        "q7a",
+        Integer,
         permitted_value_checker=BIT_CHECKER,
-        comment="Q7a (recall apple) (0-1)"
+        comment="Q7a (recall apple) (0-1)",
     )
     q7b = CamcopsColumn(
-        "q7b", Integer,
+        "q7b",
+        Integer,
         permitted_value_checker=BIT_CHECKER,
-        comment="Q7b (recall pen) (0-1)"
+        comment="Q7b (recall pen) (0-1)",
     )
     q7c = CamcopsColumn(
-        "q7c", Integer,
+        "q7c",
+        Integer,
         permitted_value_checker=BIT_CHECKER,
-        comment="Q7c (recall tie) (0-1)"
+        comment="Q7c (recall tie) (0-1)",
     )
     q7d = CamcopsColumn(
-        "q7d", Integer,
+        "q7d",
+        Integer,
         permitted_value_checker=BIT_CHECKER,
-        comment="Q7d (recall house) (0-1)"
+        comment="Q7d (recall house) (0-1)",
     )
     q7e = CamcopsColumn(
-        "q7e", Integer,
+        "q7e",
+        Integer,
         permitted_value_checker=BIT_CHECKER,
-        comment="Q7e (recall car) (0-1)"
+        comment="Q7e (recall car) (0-1)",
     )
     q8b = CamcopsColumn(
-        "q8b", Integer,
+        "q8b",
+        Integer,
         permitted_value_checker=BIT_CHECKER,
-        comment="Q8b (reverse 648) (0-1)"
+        comment="Q8b (reverse 648) (0-1)",
     )
     q8c = CamcopsColumn(
-        "q8c", Integer,
+        "q8c",
+        Integer,
         permitted_value_checker=BIT_CHECKER,
-        comment="Q8c (reverse 8537) (0-1)"
+        comment="Q8c (reverse 8537) (0-1)",
     )
     q9a = CamcopsColumn(
-        "q9a", Integer,
+        "q9a",
+        Integer,
         permitted_value_checker=ZERO_OR_TWO_CHECKER,
-        comment="Q9a (clock - hour markers) (0 or 2)"
+        comment="Q9a (clock - hour markers) (0 or 2)",
     )  # worth 2 points
     q9b = CamcopsColumn(
-        "q9b", Integer,
+        "q9b",
+        Integer,
         permitted_value_checker=ZERO_OR_TWO_CHECKER,
-        comment="Q9b (clock - time) (0 or 2)"
+        comment="Q9b (clock - time) (0 or 2)",
     )  # worth 2 points
     q10a = CamcopsColumn(
-        "q10a", Integer,
+        "q10a",
+        Integer,
         permitted_value_checker=BIT_CHECKER,
-        comment="Q10a (X in triangle) (0-1)"
+        comment="Q10a (X in triangle) (0-1)",
     )
     q10b = CamcopsColumn(
-        "q10b", Integer,
+        "q10b",
+        Integer,
         permitted_value_checker=BIT_CHECKER,
-        comment="Q10b (biggest figure) (0-1)"
+        comment="Q10b (biggest figure) (0-1)",
     )
     q11a = CamcopsColumn(
-        "q11a", Integer,
+        "q11a",
+        Integer,
         permitted_value_checker=ZERO_OR_TWO_CHECKER,
-        comment="Q11a (story - name) (0 or 2)"
+        comment="Q11a (story - name) (0 or 2)",
     )  # worth 2 points
     q11b = CamcopsColumn(
-        "q11b", Integer,
+        "q11b",
+        Integer,
         permitted_value_checker=ZERO_OR_TWO_CHECKER,
-        comment="Q11b (story - occupation) (0 or 2)"
+        comment="Q11b (story - occupation) (0 or 2)",
     )  # worth 2 points
     q11c = CamcopsColumn(
-        "q11c", Integer,
+        "q11c",
+        Integer,
         permitted_value_checker=ZERO_OR_TWO_CHECKER,
-        comment="Q11c (story - back to work) (0 or 2)"
+        comment="Q11c (story - back to work) (0 or 2)",
     )  # worth 2 points
     q11d = CamcopsColumn(
-        "q11d", Integer,
+        "q11d",
+        Integer,
         permitted_value_checker=ZERO_OR_TWO_CHECKER,
-        comment="Q11d (story - state) (0 or 2)"
+        comment="Q11d (story - state) (0 or 2)",
     )  # worth 2 points
 
     clockpicture_blobid = CamcopsColumn(
-        "clockpicture_blobid", Integer,
-        is_blob_id_field=True, blob_relationship_attr_name="clockpicture",
-        comment="BLOB ID of clock picture"
+        "clockpicture_blobid",
+        Integer,
+        is_blob_id_field=True,
+        blob_relationship_attr_name="clockpicture",
+        comment="BLOB ID of clock picture",
     )
     shapespicture_blobid = CamcopsColumn(
-        "shapespicture_blobid", Integer,
-        is_blob_id_field=True, blob_relationship_attr_name="shapespicture",
-        comment="BLOB ID of shapes picture"
-    )
-    comments = Column(
-        "comments", UnicodeText,
-        comment="Clinician's comments"
+        "shapespicture_blobid",
+        Integer,
+        is_blob_id_field=True,
+        blob_relationship_attr_name="shapespicture",
+        comment="BLOB ID of shapes picture",
     )
+    comments = Column("comments", UnicodeText, comment="Clinician's comments")
 
-    clockpicture = blob_relationship("Slums", "clockpicture_blobid")  # type: Optional[Blob]  # noqa
-    shapespicture = blob_relationship("Slums", "shapespicture_blobid")  # type: Optional[Blob]  # noqa
+    clockpicture = blob_relationship(
+        "Slums", "clockpicture_blobid"
+    )  # type: Optional[Blob]  # noqa
+    shapespicture = blob_relationship(
+        "Slums", "shapespicture_blobid"
+    )  # type: Optional[Blob]  # noqa
 
     PREAMBLE_FIELDS = ["alert", "highschooleducation"]
     SCORED_FIELDS = [
-        "q1", "q2", "q3",
-        "q5a", "q5b",
+        "q1",
+        "q2",
+        "q3",
+        "q5a",
+        "q5b",
         "q6",
-        "q7a", "q7b", "q7c", "q7d", "q7e",
-        "q8b", "q8c",
-        "q9a", "q9b",
-        "q10a", "q10b",
-        "q11a", "q11b", "q11c", "q11d"
+        "q7a",
+        "q7b",
+        "q7c",
+        "q7d",
+        "q7e",
+        "q8b",
+        "q8c",
+        "q9a",
+        "q9b",
+        "q10a",
+        "q10b",
+        "q11a",
+        "q11b",
+        "q11c",
+        "q11d",
     ]
     MAX_SCORE = 30
 
@@ -245,45 +288,53 @@ class Slums(TaskHasClinicianMixin, TaskHasPatientMixin, Task):
             hlines = [24.5, 19.5]
             y_upper = 27.25
             y_middle = 22
-        return [TrackerInfo(
-            value=self.total_score(),
-            plot_label="SLUMS total score",
-            axis_label=f"Total score (out of {self.MAX_SCORE})",
-            axis_min=-0.5,
-            axis_max=self.MAX_SCORE + 0.5,
-            horizontal_lines=hlines,
-            horizontal_labels=[
-                TrackerLabel(y_upper, req.sstring(SS.NORMAL)),
-                TrackerLabel(y_middle, self.wxstring(req, "category_mci")),
-                TrackerLabel(17, self.wxstring(req, "category_dementia")),
-            ]
-        )]
+        return [
+            TrackerInfo(
+                value=self.total_score(),
+                plot_label="SLUMS total score",
+                axis_label=f"Total score (out of {self.MAX_SCORE})",
+                axis_min=-0.5,
+                axis_max=self.MAX_SCORE + 0.5,
+                horizontal_lines=hlines,
+                horizontal_labels=[
+                    TrackerLabel(y_upper, req.sstring(SS.NORMAL)),
+                    TrackerLabel(y_middle, self.wxstring(req, "category_mci")),
+                    TrackerLabel(17, self.wxstring(req, "category_dementia")),
+                ],
+            )
+        ]
 
     def get_clinical_text(self, req: CamcopsRequest) -> List[CtvInfo]:
         if not self.is_complete():
             return CTV_INCOMPLETE
-        return [CtvInfo(
-            content=f"SLUMS total score {self.total_score()}/{self.MAX_SCORE} "
-                    f"({self.category(req)})"
-        )]
+        return [
+            CtvInfo(
+                content=f"SLUMS total score "
+                f"{self.total_score()}/{self.MAX_SCORE} "
+                f"({self.category(req)})"
+            )
+        ]
 
     def get_summaries(self, req: CamcopsRequest) -> List[SummaryElement]:
         return self.standard_task_summary_fields() + [
-            SummaryElement(name="total",
-                           coltype=Integer(),
-                           value=self.total_score(),
-                           comment=f"Total score (/{self.MAX_SCORE})"),
-            SummaryElement(name="category",
-                           coltype=SummaryCategoryColType,
-                           value=self.category(req),
-                           comment="Category"),
+            SummaryElement(
+                name="total",
+                coltype=Integer(),
+                value=self.total_score(),
+                comment=f"Total score (/{self.MAX_SCORE})",
+            ),
+            SummaryElement(
+                name="category",
+                coltype=SummaryCategoryColType,
+                value=self.category(req),
+                comment="Category",
+            ),
         ]
 
     def is_complete(self) -> bool:
         return (
-            self.all_fields_not_none(self.PREAMBLE_FIELDS +
-                                     self.SCORED_FIELDS) and
-            self.field_contents_valid()
+            self.all_fields_not_none(self.PREAMBLE_FIELDS + self.SCORED_FIELDS)
+            and self.field_contents_valid()
         )
 
     def total_score(self) -> int:
@@ -325,44 +376,63 @@ class Slums(TaskHasClinicianMixin, TaskHasPatientMixin, Task):
                 </tr>
         """.format(
             clinician_comments=self.get_standard_clinician_comments_block(
-                req, self.comments),
+                req, self.comments
+            ),
             CssClass=CssClass,
             tr_is_complete=self.get_is_complete_tr(req),
             total_score=tr(
                 req.sstring(SS.TOTAL_SCORE),
-                answer(score) + f" / {self.MAX_SCORE}"
+                answer(score) + f" / {self.MAX_SCORE}",
             ),
             category=tr_qa(
-                req.sstring(SS.CATEGORY) + " <sup>[1]</sup>",
-                category
+                req.sstring(SS.CATEGORY) + " <sup>[1]</sup>", category
             ),
         )
-        h += tr_qa(self.wxstring(req, "alert_s"),
-                   get_yes_no_none(req, self.alert))
-        h += tr_qa(self.wxstring(req, "highschool_s"),
-                   get_yes_no_none(req, self.highschooleducation))
+        h += tr_qa(
+            self.wxstring(req, "alert_s"), get_yes_no_none(req, self.alert)
+        )
+        h += tr_qa(
+            self.wxstring(req, "highschool_s"),
+            get_yes_no_none(req, self.highschooleducation),
+        )
         h += tr_qa(self.wxstring(req, "q1_s"), self.q1)
         h += tr_qa(self.wxstring(req, "q2_s"), self.q2)
         h += tr_qa(self.wxstring(req, "q3_s"), self.q3)
-        h += tr("Q5 <sup>[2]</sup> (money spent, money left "
-                "[<i>scores 2</i>]",
-                ", ".join(answer(x) for x in (self.q5a, self.q5b)))
-        h += tr_qa("Q6 (animal fluency) [<i>≥15 scores 3, 10–14 scores 2, "
-                   "5–9 scores 1, 0–4 scores 0</i>]",
-                   self.q6)
-        h += tr("Q7 (recall: apple, pen, tie, house, car)",
-                ", ".join(answer(x) for x in (self.q7a, self.q7b, self.q7c,
-                                              self.q7d, self.q7e)))
-        h += tr("Q8 (backwards: 648, 8537)",
-                ", ".join(answer(x) for x in (self.q8b, self.q8c)))
-        h += tr("Q9 (clock: hour markers, time [<i>score 2 each</i>]",
-                ", ".join(answer(x) for x in (self.q9a, self.q9b)))
-        h += tr("Q10 (X in triangle; which is biggest?)",
-                ", ".join(answer(x) for x in (self.q10a, self.q10b)))
-        h += tr("Q11 (story: Female’s name? Job? When back to work? "
-                "State she lived in? [<i>score 2 each</i>])",
-                ", ".join(answer(x) for x in (self.q11a, self.q11b,
-                                              self.q11c, self.q11d)))
+        h += tr(
+            "Q5 <sup>[2]</sup> (money spent, money left " "[<i>scores 2</i>]",
+            ", ".join(answer(x) for x in (self.q5a, self.q5b)),
+        )
+        h += tr_qa(
+            "Q6 (animal fluency) [<i>≥15 scores 3, 10–14 scores 2, "
+            "5–9 scores 1, 0–4 scores 0</i>]",
+            self.q6,
+        )
+        h += tr(
+            "Q7 (recall: apple, pen, tie, house, car)",
+            ", ".join(
+                answer(x)
+                for x in (self.q7a, self.q7b, self.q7c, self.q7d, self.q7e)
+            ),
+        )
+        h += tr(
+            "Q8 (backwards: 648, 8537)",
+            ", ".join(answer(x) for x in (self.q8b, self.q8c)),
+        )
+        h += tr(
+            "Q9 (clock: hour markers, time [<i>score 2 each</i>]",
+            ", ".join(answer(x) for x in (self.q9a, self.q9b)),
+        )
+        h += tr(
+            "Q10 (X in triangle; which is biggest?)",
+            ", ".join(answer(x) for x in (self.q10a, self.q10b)),
+        )
+        h += tr(
+            "Q11 (story: Female’s name? Job? When back to work? "
+            "State she lived in? [<i>score 2 each</i>])",
+            ", ".join(
+                answer(x) for x in (self.q11a, self.q11b, self.q11c, self.q11d)
+            ),
+        )
         h += f"""
             </table>
             <table class="{CssClass.TASKDETAIL}">
@@ -370,11 +440,17 @@ class Slums(TaskHasClinicianMixin, TaskHasPatientMixin, Task):
         h += subheading_spanning_two_columns("Images of tests: clock, shapes")
         # noinspection PyTypeChecker
         h += tr(
-            td(get_blob_img_html(self.clockpicture),
-               td_width="50%", td_class=CssClass.PHOTO),
-            td(get_blob_img_html(self.shapespicture),
-               td_width="50%", td_class=CssClass.PHOTO),
-            literal=True
+            td(
+                get_blob_img_html(self.clockpicture),
+                td_width="50%",
+                td_class=CssClass.PHOTO,
+            ),
+            td(
+                get_blob_img_html(self.shapespicture),
+                td_width="50%",
+                td_class=CssClass.PHOTO,
+            ),
+            literal=True,
         )
         h += f"""
             </table>
