@@ -28,22 +28,33 @@ camcops_server/tasks/tests/core10_tests.py
 """
 
 import pendulum
-from camcops_server.cc_modules.cc_patient import Patient
-from camcops_server.tasks.core10 import Core10, Core10Report
 
+from camcops_server.cc_modules.cc_patient import Patient
 from camcops_server.cc_modules.tests.cc_report_tests import (
-    AverageScoreReportTestCase
+    AverageScoreReportTestCase,
 )
+from camcops_server.tasks.core10 import Core10, Core10Report
 
 
 class Core10ReportTestCase(AverageScoreReportTestCase):
     def create_report(self) -> Core10Report:
         return Core10Report(via_index=False)
 
-    def create_task(self, patient: Patient,
-                    q1: int = 0, q2: int = 0, q3: int = 0, q4: int = 0,
-                    q5: int = 0, q6: int = 0, q7: int = 0, q8: int = 0,
-                    q9: int = 0, q10: int = 0, era: str = None) -> None:
+    def create_task(
+        self,
+        patient: Patient,
+        q1: int = 0,
+        q2: int = 0,
+        q3: int = 0,
+        q4: int = 0,
+        q5: int = 0,
+        q6: int = 0,
+        q7: int = 0,
+        q8: int = 0,
+        q9: int = 0,
+        q10: int = 0,
+        era: str = None,
+    ) -> None:
         task = Core10()
         self.apply_standard_task_fields(task)
         task.id = next(self.task_id_sequence)
@@ -77,26 +88,30 @@ class Core10ReportTests(Core10ReportTestCase):
         # Initial average score = (8 + 6 + 4) / 3 = 6
         # Latest average score = (2 + 3 + 4) / 3 = 3
 
-        self.create_task(patient=self.patient_1, q1=4, q2=4,
-                         era="2018-06-01")  # Score 8
-        self.create_task(patient=self.patient_1, q7=1, q8=1,
-                         era="2018-10-04")  # Score 2
+        self.create_task(
+            patient=self.patient_1, q1=4, q2=4, era="2018-06-01"
+        )  # Score 8
+        self.create_task(
+            patient=self.patient_1, q7=1, q8=1, era="2018-10-04"
+        )  # Score 2
 
-        self.create_task(patient=self.patient_2, q3=3, q4=3,
-                         era="2018-05-02")  # Score 6
-        self.create_task(patient=self.patient_2, q3=2, q4=1,
-                         era="2018-10-03")  # Score 3
+        self.create_task(
+            patient=self.patient_2, q3=3, q4=3, era="2018-05-02"
+        )  # Score 6
+        self.create_task(
+            patient=self.patient_2, q3=2, q4=1, era="2018-10-03"
+        )  # Score 3
 
-        self.create_task(patient=self.patient_3, q5=2, q6=2,
-                         era="2018-01-10")  # Score 4
-        self.create_task(patient=self.patient_3, q9=1, q10=3,
-                         era="2018-10-01")  # Score 4
+        self.create_task(
+            patient=self.patient_3, q5=2, q6=2, era="2018-01-10"
+        )  # Score 4
+        self.create_task(
+            patient=self.patient_3, q9=1, q10=3, era="2018-10-01"
+        )  # Score 4
         self.dbsession.commit()
 
     def test_row_has_totals_and_averages(self) -> None:
-        tsv_pages = self.report.get_tsv_pages(req=self.req)
-        # log.info(f"\n{tsv_pages[0]}")
-        # log.info(f"\n{tsv_pages[1]}")
+        pages = self.report.get_spreadsheet_pages(req=self.req)
         expected_rows = [
             [
                 3,  # n initial
@@ -106,19 +121,15 @@ class Core10ReportTests(Core10ReportTestCase):
                 3.0,  # Average progress
             ]
         ]
-        self.assertEqual(tsv_pages[0].plainrows, expected_rows)
+        self.assertEqual(pages[0].plainrows, expected_rows)
 
 
 class Core10ReportEmptyTests(Core10ReportTestCase):
     def test_no_rows_when_no_data(self) -> None:
-        tsv_pages = self.report.get_tsv_pages(req=self.req)
+        pages = self.report.get_spreadsheet_pages(req=self.req)
         no_data = self.report.no_data_value()
-        expected_rows = [
-            [
-                0, 0, no_data, no_data, no_data,
-            ]
-        ]
-        self.assertEqual(tsv_pages[0].plainrows, expected_rows)
+        expected_rows = [[0, 0, no_data, no_data, no_data]]
+        self.assertEqual(pages[0].plainrows, expected_rows)
 
 
 class Core10ReportDoubleCountingTests(Core10ReportTestCase):
@@ -130,22 +141,27 @@ class Core10ReportDoubleCountingTests(Core10ReportTestCase):
         # Initial average score = (8 + 6 + 4) / 3 = 6
         # Latest average score  = (    3 + 3) / 2 = 3
         # Progress avg score    = (    3 + 1) / 2 = 2  ... NOT 3.
-        self.create_task(patient=self.patient_1, q1=4, q2=4,
-                         era="2018-06-01")  # Score 8
+        self.create_task(
+            patient=self.patient_1, q1=4, q2=4, era="2018-06-01"
+        )  # Score 8
 
-        self.create_task(patient=self.patient_2, q3=3, q4=3,
-                         era="2018-05-02")  # Score 6
-        self.create_task(patient=self.patient_2, q3=2, q4=1,
-                         era="2018-10-03")  # Score 3
+        self.create_task(
+            patient=self.patient_2, q3=3, q4=3, era="2018-05-02"
+        )  # Score 6
+        self.create_task(
+            patient=self.patient_2, q3=2, q4=1, era="2018-10-03"
+        )  # Score 3
 
-        self.create_task(patient=self.patient_3, q5=2, q6=2,
-                         era="2018-01-10")  # Score 4
-        self.create_task(patient=self.patient_3, q9=1, q10=2,
-                         era="2018-10-01")  # Score 3
+        self.create_task(
+            patient=self.patient_3, q5=2, q6=2, era="2018-01-10"
+        )  # Score 4
+        self.create_task(
+            patient=self.patient_3, q9=1, q10=2, era="2018-10-01"
+        )  # Score 3
         self.dbsession.commit()
 
     def test_record_does_not_appear_in_first_and_latest(self) -> None:
-        tsv_pages = self.report.get_tsv_pages(req=self.req)
+        pages = self.report.get_spreadsheet_pages(req=self.req)
         expected_rows = [
             [
                 3,  # n initial
@@ -155,7 +171,7 @@ class Core10ReportDoubleCountingTests(Core10ReportTestCase):
                 2.0,  # Average progress
             ]
         ]
-        self.assertEqual(tsv_pages[0].plainrows, expected_rows)
+        self.assertEqual(pages[0].plainrows, expected_rows)
 
 
 class Core10ReportDateRangeTests(Core10ReportTestCase):
@@ -218,39 +234,53 @@ class Core10ReportDateRangeTests(Core10ReportTestCase):
         # 2018-08 average score = (4 + 4 + 4) / 3 = 4
         # 2018-10 average score = (2 + 3 + 4) / 3 = 3
 
-        self.create_task(patient=self.patient_1, q1=4, q2=4,
-                         era="2018-06-01")  # Score 8
-        self.create_task(patient=self.patient_1, q7=3, q8=1,
-                         era="2018-08-01")  # Score 4
-        self.create_task(patient=self.patient_1, q7=1, q8=1,
-                         era="2018-10-01")  # Score 2
+        self.create_task(
+            patient=self.patient_1, q1=4, q2=4, era="2018-06-01"
+        )  # Score 8
+        self.create_task(
+            patient=self.patient_1, q7=3, q8=1, era="2018-08-01"
+        )  # Score 4
+        self.create_task(
+            patient=self.patient_1, q7=1, q8=1, era="2018-10-01"
+        )  # Score 2
 
-        self.create_task(patient=self.patient_2, q3=3, q4=3,
-                         era="2018-06-01")  # Score 6
-        self.create_task(patient=self.patient_2, q3=2, q4=2,
-                         era="2018-08-01")  # Score 4
-        self.create_task(patient=self.patient_2, q3=1, q4=2,
-                         era="2018-10-01")  # Score 3
+        self.create_task(
+            patient=self.patient_2, q3=3, q4=3, era="2018-06-01"
+        )  # Score 6
+        self.create_task(
+            patient=self.patient_2, q3=2, q4=2, era="2018-08-01"
+        )  # Score 4
+        self.create_task(
+            patient=self.patient_2, q3=1, q4=2, era="2018-10-01"
+        )  # Score 3
 
-        self.create_task(patient=self.patient_3, q5=2, q6=2,
-                         era="2018-06-01")  # Score 4
-        self.create_task(patient=self.patient_3, q9=1, q10=3,
-                         era="2018-08-01")  # Score 4
-        self.create_task(patient=self.patient_3, q9=1, q10=3,
-                         era="2018-10-01")  # Score 4
+        self.create_task(
+            patient=self.patient_3, q5=2, q6=2, era="2018-06-01"
+        )  # Score 4
+        self.create_task(
+            patient=self.patient_3, q9=1, q10=3, era="2018-08-01"
+        )  # Score 4
+        self.create_task(
+            patient=self.patient_3, q9=1, q10=3, era="2018-10-01"
+        )  # Score 4
         self.dbsession.commit()
 
-        self.dump_table(Core10.__tablename__, [
-            "_pk", "patient_id", "when_created", "_current",
-        ])
+        self.dump_table(
+            Core10.__tablename__,
+            ["_pk", "patient_id", "when_created", "_current"],
+        )
 
     def test_report_filtered_by_date_range(self) -> None:
         # self.report.start_datetime = pendulum.parse("2018-05-01T00:00:00.000000+00:00")  # noqa
-        self.report.start_datetime = pendulum.parse("2018-06-01T00:00:00.000000+00:00")  # noqa
-        self.report.end_datetime = pendulum.parse("2018-09-01T00:00:00.000000+00:00")  # noqa
+        self.report.start_datetime = pendulum.parse(
+            "2018-06-01T00:00:00.000000+00:00"
+        )
+        self.report.end_datetime = pendulum.parse(
+            "2018-09-01T00:00:00.000000+00:00"
+        )
 
         self.set_echo(True)
-        tsv_pages = self.report.get_tsv_pages(req=self.req)
+        pages = self.report.get_spreadsheet_pages(req=self.req)
         self.set_echo(False)
         expected_rows = [
             [
@@ -261,4 +291,4 @@ class Core10ReportDateRangeTests(Core10ReportTestCase):
                 2.0,  # Average progress
             ]
         ]
-        self.assertEqual(tsv_pages[0].plainrows, expected_rows)
+        self.assertEqual(pages[0].plainrows, expected_rows)
