@@ -64,19 +64,23 @@ from camcops_server.cc_modules.cc_trackerhelpers import TrackerInfo
 # Y-BOCS
 # =============================================================================
 
+
 class YbocsMetaclass(DeclarativeMeta):
     # noinspection PyInitNewSignature
-    def __init__(cls: Type['Ybocs'],
-                 name: str,
-                 bases: Tuple[Type, ...],
-                 classdict: Dict[str, Any]) -> None:
+    def __init__(
+        cls: Type["Ybocs"],
+        name: str,
+        bases: Tuple[Type, ...],
+        classdict: Dict[str, Any],
+    ) -> None:
         cls.TARGET_COLUMNS = []  # type: List[Column]
         for target in ("obsession", "compulsion", "avoidance"):
             for n in range(1, cls.NTARGETS + 1):
                 fname = f"target_{target}_{n}"
                 col = Column(
-                    fname, UnicodeText,
-                    comment=f"Target symptoms: {target} {n}"
+                    fname,
+                    UnicodeText,
+                    comment=f"Target symptoms: {target} {n}",
                 )
                 setattr(cls, fname, col)
                 cls.TARGET_COLUMNS.append(col)
@@ -86,48 +90,52 @@ class YbocsMetaclass(DeclarativeMeta):
                 cls,
                 fname,
                 CamcopsColumn(
-                    fname, Integer,
+                    fname,
+                    Integer,
                     permitted_value_checker=PermittedValueChecker(
-                        minimum=0, maximum=maxscore),
+                        minimum=0, maximum=maxscore
+                    ),
                     comment=f"Q{qnumstr}, {comment} "
-                            f"(0-{maxscore}, higher worse)"
-                )
+                    f"(0-{maxscore}, higher worse)",
+                ),
             )
         super().__init__(name, bases, classdict)
 
 
-class Ybocs(TaskHasClinicianMixin, TaskHasPatientMixin, Task,
-            metaclass=YbocsMetaclass):
+class Ybocs(
+    TaskHasClinicianMixin, TaskHasPatientMixin, Task, metaclass=YbocsMetaclass
+):
     """
     Server implementation of the Y-BOCS task.
     """
+
     __tablename__ = "ybocs"
     shortname = "Y-BOCS"
     provides_trackers = True
 
     NTARGETS = 3
     QINFO = [  # number, max score, minimal comment
-        ('1',  4, "obsessions: time"),
-        ('1b', 4, "obsessions: obsession-free interval"),
-        ('2',  4, "obsessions: interference"),
-        ('3',  4, "obsessions: distress"),
-        ('4',  4, "obsessions: resistance"),
-        ('5',  4, "obsessions: control"),
-        ('6',  4, "compulsions: time"),
-        ('6b', 4, "compulsions: compulsion-free interval"),
-        ('7',  4, "compulsions: interference"),
-        ('8',  4, "compulsions: distress"),
-        ('9',  4, "compulsions: resistance"),
-        ('10', 4, "compulsions: control"),
-        ('11', 4, "insight"),
-        ('12', 4, "avoidance"),
-        ('13', 4, "indecisiveness"),
-        ('14', 4, "overvalued responsibility"),
-        ('15', 4, "slowness"),
-        ('16', 4, "doubting"),
-        ('17', 6, "global severity"),
-        ('18', 6, "global improvement"),
-        ('19', 3, "reliability"),
+        ("1", 4, "obsessions: time"),
+        ("1b", 4, "obsessions: obsession-free interval"),
+        ("2", 4, "obsessions: interference"),
+        ("3", 4, "obsessions: distress"),
+        ("4", 4, "obsessions: resistance"),
+        ("5", 4, "obsessions: control"),
+        ("6", 4, "compulsions: time"),
+        ("6b", 4, "compulsions: compulsion-free interval"),
+        ("7", 4, "compulsions: interference"),
+        ("8", 4, "compulsions: distress"),
+        ("9", 4, "compulsions: resistance"),
+        ("10", 4, "compulsions: control"),
+        ("11", 4, "insight"),
+        ("12", 4, "avoidance"),
+        ("13", 4, "indecisiveness"),
+        ("14", 4, "overvalued responsibility"),
+        ("15", 4, "slowness"),
+        ("16", 4, "doubting"),
+        ("17", 6, "global severity"),
+        ("18", 6, "global improvement"),
+        ("19", 3, "reliability"),
     ]
     QUESTION_FIELDS = ["q" + x[0] for x in QINFO]
     SCORED_QUESTIONS = strseq("q", 1, 10)
@@ -149,21 +157,21 @@ class Ybocs(TaskHasClinicianMixin, TaskHasPatientMixin, Task,
                 plot_label="Y-BOCS total score (lower is better)",
                 axis_label=f"Total score (out of {self.MAX_TOTAL})",
                 axis_min=-0.5,
-                axis_max=self.MAX_TOTAL + 0.5
+                axis_max=self.MAX_TOTAL + 0.5,
             ),
             TrackerInfo(
                 value=self.obsession_score(),
                 plot_label="Y-BOCS obsession score (lower is better)",
                 axis_label=f"Total score (out of {self.MAX_OBS})",
                 axis_min=-0.5,
-                axis_max=self.MAX_OBS + 0.5
+                axis_max=self.MAX_OBS + 0.5,
             ),
             TrackerInfo(
                 value=self.compulsion_score(),
                 plot_label="Y-BOCS compulsion score (lower is better)",
                 axis_label=f"Total score (out of {self.MAX_COM})",
                 axis_min=-0.5,
-                axis_max=self.MAX_COM + 0.5
+                axis_max=self.MAX_COM + 0.5,
             ),
         ]
 
@@ -173,19 +181,19 @@ class Ybocs(TaskHasClinicianMixin, TaskHasPatientMixin, Task,
                 name="total_score",
                 coltype=Integer(),
                 value=self.total_score(),
-                comment=f"Total score (/ {self.MAX_TOTAL})"
+                comment=f"Total score (/ {self.MAX_TOTAL})",
             ),
             SummaryElement(
                 name="obsession_score",
                 coltype=Integer(),
                 value=self.obsession_score(),
-                comment=f"Obsession score (/ {self.MAX_OBS})"
+                comment=f"Obsession score (/ {self.MAX_OBS})",
             ),
             SummaryElement(
                 name="compulsion_score",
                 coltype=Integer(),
                 value=self.compulsion_score(),
-                comment=f"Compulsion score (/ {self.MAX_COM})"
+                comment=f"Compulsion score (/ {self.MAX_COM})",
             ),
         ]
 
@@ -195,14 +203,21 @@ class Ybocs(TaskHasClinicianMixin, TaskHasPatientMixin, Task,
         t = self.total_score()
         o = self.obsession_score()
         c = self.compulsion_score()
-        return [CtvInfo(content=(
-            "Y-BOCS total score {t}/{mt} (obsession {o}/{mo}, "
-            "compulsion {c}/{mc})".format(
-                t=t, mt=self.MAX_TOTAL,
-                o=o, mo=self.MAX_OBS,
-                c=c, mc=self.MAX_COM,
+        return [
+            CtvInfo(
+                content=(
+                    "Y-BOCS total score {t}/{mt} (obsession {o}/{mo}, "
+                    "compulsion {c}/{mc})".format(
+                        t=t,
+                        mt=self.MAX_TOTAL,
+                        o=o,
+                        mo=self.MAX_OBS,
+                        c=c,
+                        mc=self.MAX_COM,
+                    )
+                )
             )
-        ))]
+        ]
 
     def total_score(self) -> int:
         return self.sum_fields(self.SCORED_QUESTIONS)
@@ -214,9 +229,8 @@ class Ybocs(TaskHasClinicianMixin, TaskHasPatientMixin, Task,
         return self.sum_fields(self.COMPULSION_QUESTIONS)
 
     def is_complete(self) -> bool:
-        return (
-            self.field_contents_valid() and
-            self.all_fields_not_none(self.SCORED_QUESTIONS)
+        return self.field_contents_valid() and self.all_fields_not_none(
+            self.SCORED_QUESTIONS
         )
 
     def get_task_html(self, req: CamcopsRequest) -> str:
@@ -229,8 +243,11 @@ class Ybocs(TaskHasClinicianMixin, TaskHasPatientMixin, Task,
             value = getattr(self, fieldname)
             q_a += tr(
                 self.wxstring(req, fieldname + "_title"),
-                answer(self.wxstring(req, fieldname + "_a" + str(value), value)
-                       if value is not None else None)
+                answer(
+                    self.wxstring(req, fieldname + "_a" + str(value), value)
+                    if value is not None
+                    else None
+                ),
             )
         return f"""
             <div class="{CssClass.SUMMARY}">
@@ -275,57 +292,69 @@ class Ybocs(TaskHasClinicianMixin, TaskHasPatientMixin, Task,
 # Y-BOCS-SC
 # =============================================================================
 
+
 class YbocsScMetaclass(DeclarativeMeta):
     # noinspection PyInitNewSignature
-    def __init__(cls: Type['YbocsSc'],
-                 name: str,
-                 bases: Tuple[Type, ...],
-                 classdict: Dict[str, Any]) -> None:
+    def __init__(
+        cls: Type["YbocsSc"],
+        name: str,
+        bases: Tuple[Type, ...],
+        classdict: Dict[str, Any],
+    ) -> None:
         for item in cls.ITEMS:
             setattr(
                 cls,
                 item + cls.SUFFIX_CURRENT,
                 CamcopsColumn(
-                    item + cls.SUFFIX_CURRENT, Boolean,
+                    item + cls.SUFFIX_CURRENT,
+                    Boolean,
                     permitted_value_checker=BIT_CHECKER,
-                    comment=item + " (current symptom)"
-                )
+                    comment=item + " (current symptom)",
+                ),
             )
             setattr(
                 cls,
                 item + cls.SUFFIX_PAST,
                 CamcopsColumn(
-                    item + cls.SUFFIX_PAST, Boolean,
+                    item + cls.SUFFIX_PAST,
+                    Boolean,
                     permitted_value_checker=BIT_CHECKER,
-                    comment=item + " (past symptom)"
-                )
+                    comment=item + " (past symptom)",
+                ),
             )
             setattr(
                 cls,
                 item + cls.SUFFIX_PRINCIPAL,
                 CamcopsColumn(
-                    item + cls.SUFFIX_PRINCIPAL, Boolean,
+                    item + cls.SUFFIX_PRINCIPAL,
+                    Boolean,
                     permitted_value_checker=BIT_CHECKER,
-                    comment=item + " (principal symptom)"
-                )
+                    comment=item + " (principal symptom)",
+                ),
             )
             if item.endswith(cls.SUFFIX_OTHER):
                 setattr(
                     cls,
                     item + cls.SUFFIX_DETAIL,
                     Column(
-                        item + cls.SUFFIX_DETAIL, UnicodeText,
-                        comment=item + " (details)"
-                    )
+                        item + cls.SUFFIX_DETAIL,
+                        UnicodeText,
+                        comment=item + " (details)",
+                    ),
                 )
         super().__init__(name, bases, classdict)
 
 
-class YbocsSc(TaskHasClinicianMixin, TaskHasPatientMixin, Task,
-              metaclass=YbocsScMetaclass):
+class YbocsSc(
+    TaskHasClinicianMixin,
+    TaskHasPatientMixin,
+    Task,
+    metaclass=YbocsScMetaclass,
+):
     """
     Server implementation of the Y-BOCS-SC task.
     """
+
     __tablename__ = "ybocssc"
     shortname = "Y-BOCS-SC"
     extrastring_taskname = "ybocs"  # shares with Y-BOCS
@@ -352,7 +381,7 @@ class YbocsSc(TaskHasClinicianMixin, TaskHasPatientMixin, Task,
         "com_counting",
         "com_arranging",
         "com_hoarding",
-        "com_misc"
+        "com_misc",
     ]
     ITEMS = [
         "obs_aggressive_harm_self",
@@ -365,7 +394,6 @@ class YbocsSc(TaskHasClinicianMixin, TaskHasPatientMixin, Task,
         "obs_aggressive_accident",
         "obs_aggressive_responsible",
         "obs_aggressive_other",
-
         "obs_contamination_bodily_waste",
         "obs_contamination_dirt",
         "obs_contamination_environmental",
@@ -376,22 +404,17 @@ class YbocsSc(TaskHasClinicianMixin, TaskHasPatientMixin, Task,
         "obs_contamination_others_ill",
         "obs_contamination_feeling",
         "obs_contamination_other",
-
         "obs_sexual_forbidden",
         "obs_sexual_children_incest",
         "obs_sexual_homosexuality",
         "obs_sexual_to_others",
         "obs_sexual_other",
-
         "obs_hoarding_other",
-
         "obs_religious_sacrilege",
         "obs_religious_morality",
         "obs_religious_other",
-
         "obs_symmetry_with_magical",
         "obs_symmetry_without_magical",
-
         "obs_misc_know_remember",
         "obs_misc_fear_saying",
         "obs_misc_fear_not_saying",
@@ -403,17 +426,14 @@ class YbocsSc(TaskHasClinicianMixin, TaskHasPatientMixin, Task,
         "obs_misc_colours",
         "obs_misc_superstitious",
         "obs_misc_other",
-
         "obs_somatic_illness",
         "obs_somatic_appearance",
         "obs_somatic_other",
-
         "com_cleaning_handwashing",
         "com_cleaning_toileting",
         "com_cleaning_cleaning_items",
         "com_cleaning_other_contaminant_avoidance",
         "com_cleaning_other",
-
         "com_checking_locks_appliances",
         "com_checking_not_harm_others",
         "com_checking_not_harm_self",
@@ -421,17 +441,12 @@ class YbocsSc(TaskHasClinicianMixin, TaskHasPatientMixin, Task,
         "com_checking_no_mistake",
         "com_checking_somatic",
         "com_checking_other",
-
         "com_repeat_reread_rewrite",
         "com_repeat_routine",
         "com_repeat_other",
-
         "com_counting_other",
-
         "com_arranging_other",
-
         "com_hoarding_other",
-
         "com_misc_mental_rituals",
         "com_misc_lists",
         "com_misc_tell_ask",
@@ -444,7 +459,7 @@ class YbocsSc(TaskHasClinicianMixin, TaskHasPatientMixin, Task,
         "com_misc_superstitious",
         "com_misc_trichotillomania",
         "com_misc_self_harm",
-        "com_misc_other"
+        "com_misc_other",
     ]
 
     @staticmethod
@@ -468,7 +483,9 @@ class YbocsSc(TaskHasClinicianMixin, TaskHasPatientMixin, Task,
         return [
             CtvInfo(content=f"Current symptoms: {', '.join(current_list)}"),
             CtvInfo(content=f"Past symptoms: {', '.join(past_list)}"),
-            CtvInfo(content=f"Principal symptoms: {', '.join(principal_list)}"),  # noqa
+            CtvInfo(
+                content=f"Principal symptoms: {', '.join(principal_list)}"
+            ),
         ]
 
     # noinspection PyMethodOverriding
@@ -488,27 +505,37 @@ class YbocsSc(TaskHasClinicianMixin, TaskHasPatientMixin, Task,
         """
         for group in self.GROUPS:
             h += subheading_spanning_four_columns(
-                self.wxstring(req, self.SC_PREFIX + group))
+                self.wxstring(req, self.SC_PREFIX + group)
+            )
             for item in self.ITEMS:
                 if not item.startswith(group):
                     continue
                 h += tr(
                     self.wxstring(req, self.SC_PREFIX + item),
-                    answer(get_ternary(getattr(self,
-                                               item + self.SUFFIX_CURRENT),
-                                       value_true="Current",
-                                       value_false="",
-                                       value_none="")),
-                    answer(get_ternary(getattr(self,
-                                               item + self.SUFFIX_PAST),
-                                       value_true="Past",
-                                       value_false="",
-                                       value_none="")),
-                    answer(get_ternary(getattr(self,
-                                               item + self.SUFFIX_PRINCIPAL),
-                                       value_true="Principal",
-                                       value_false="",
-                                       value_none="")),
+                    answer(
+                        get_ternary(
+                            getattr(self, item + self.SUFFIX_CURRENT),
+                            value_true="Current",
+                            value_false="",
+                            value_none="",
+                        )
+                    ),
+                    answer(
+                        get_ternary(
+                            getattr(self, item + self.SUFFIX_PAST),
+                            value_true="Past",
+                            value_false="",
+                            value_none="",
+                        )
+                    ),
+                    answer(
+                        get_ternary(
+                            getattr(self, item + self.SUFFIX_PRINCIPAL),
+                            value_true="Principal",
+                            value_false="",
+                            value_none="",
+                        )
+                    ),
                 )
                 if item.endswith(self.SUFFIX_OTHER):
                     h += f"""
