@@ -56,17 +56,12 @@ from semantic_version import Version
 log = logging.getLogger(__name__)
 
 
-REPOSITORY = "https://github.com/RudolfCardinal/camcops"
+REPOSITORY = "https://github.com/ucam-department-of-psychiatry/camcops"
 
 
 def main() -> None:
     log.info(f"Checking repository: {REPOSITORY}")
-    cmdargs = [
-        "git",
-        "ls-remote",
-        "--tag",
-        REPOSITORY
-    ]
+    cmdargs = ["git", "ls-remote", "--tag", REPOSITORY]
     output = subprocess.check_output(cmdargs).decode(sys.getdefaultencoding())
     log.debug(f"Tags found:\n{output}")
     version_strings = [
